/*******************************************************************************
	Define program that prepares the standard iebaltab balance table 
	but adds to it columns for additional tests beyond just the joint F.
	It also changes the table to tabular format in latex.
	It takes into account two sections and stacks the second as a new panel.

	Outline:
	** 1) variable names 
	** 2) F-tests
	** 3) Other pvalues
	** 4) t-tests
	** 5) postprocess balance table
*******************************************************************************/

pause on

capture prog drop tex_stack_iebaltab
prog define tex_stack_iebaltab
	syntax,  treat_var(string) table_name(string) table_title(string) seg1(string) 	///
			 cluster_var(string)													///
			[table_note1(string) table_note2(string) table_note3(string) 			///
			 table_note4(string) table_note5(string) table_note6(string) 			///
			 table_note7(string) table_note8(string) 								///
						  seg1_header(string) seg1_condi(string) seg1_nclus(string) seg1_wei(string) nobs_row1(string) ///
			 seg2(string) seg2_header(string) seg2_condi(string) seg2_nclus(string) seg2_wei(string) nobs_row2(string) ///
			 seg3(string) seg3_header(string) seg3_condi(string) seg3_nclus(string) seg3_wei(string) nobs_row3(string) ///
			 seg4(string) seg4_header(string) seg4_condi(string) seg4_nclus(string) seg4_wei(string) nobs_row4(string) ///
			 indentthese(string) 	///
			 permute_pvalue(string)	///
			 no_strata(string)   	///
			 no_onerow(string)   	/// 
			 QUIetly]
	
	
	nois dis as text "	- Running do-file: tex_stack_iebaltab"

`quietly' {
	
	// count number of treatment groups	
	qui distinct `treat_var'
    local nv_t = r(ndistinct)
	
	if !inlist(`nv_t', 2, 4) {
		nois dis as error "The number of treatment groups should be 2 or 4"
	}
	
	// do not run f tests if only one control group and one treatment group 
	if `nv_t' == 2 local f_test 0
	else 		   local f_test 1
		
		
	forvalues i = 1/26 {
		if "`seg`i''" != "" local segs `segs' seg`i'
	}
	
	local seg_n : word count `segs'

	** 1) variable names 
	// generate dataset with variable names and labels to match in merge later
	foreach segment in `segs' {
		local i 1
		foreach var in ``segment'' {
			local var_`i' "`var'"
			local lab_`i' : var label `var'
			local i = `i' + 1
		}
		preserve // branch off and generate new dataset with these locals
			clear
			local var_n : word count ``segment''
			set obs `var_n'
			gen varname = ""
			gen varlab = ""
			forval i = 1/`var_n' {
				replace varname = "`var_`i''" in `i'
				replace varlab = "`lab_`i''" in `i'
			}
			tempfile var_names_and_labs_`segment'
			save 	`var_names_and_labs_`segment''
		restore
	}

		
	foreach segment in `segs' {
		
		local within_seg_n 0
		
		
		** 2) F-tests
		
		// sample condition for additional tests
		if "``segment'_condi'" != "" local spe_cond ``segment'_condi'
		else                         local spe_cond
		
		// Weights 
		if "${w_lvl}" == "village" 	local weight_var weight_vil 
		if "${w_lvl}" == "overall" 	local weight_var weight_ovrl
		if "${w_lvl}" == "prop_g2" 	local weight_var weight_g2
		                 
		if `f_test' == 1 {
			foreach var in ``segment'' {
				 
				** -----| 2.1)  run regression 1 for special stats
				if "`no_strata'" == "" {
					qui areg `var' i.`treat_var' `spe_cond', cluster(`cluster_var') absorb(strata)
				}
				else {
					qui reg `var' i.`treat_var' `spe_cond', cluster(`cluster_var')
				}
				// capture p-value for model F-test
				qui test i1.treatment = i2.treatment = i3.treatment
				local F_test_joint : di %15.3fc `r(p)'
				
				** -----| 2.2)  run regression 1 for special stats
				if "`no_strata'" == "" {
					qui areg `var' treat_dum `spe_cond', cluster(`cluster_var') absorb(strata)
				}
				else {
					qui reg `var' treat_dum `spe_cond', cluster(`cluster_var')	
				}
				mat my_reg = r(table)
				local F_test_tdum = my_reg[4,1]
				local F_test_tdum : di %15.3fc `F_test_tdum'
				
				mat other_tests = (`F_test_joint', `F_test_tdum')
				matrix colnames other_tests = joint_f pooled_f
				matrix rownames other_tests = "`var'"
				
				// Concatenate p-vals within each SPEC
				if (`within_seg_n' == 0) matrix other_tests_long = other_tests  // start matrix for 1st var in section 
				if (`within_seg_n' >  0) matrix other_tests_long = other_tests_long \ other_tests  // then append to p_collect

				local within_seg_n = `within_seg_n' + 1
			}
			preserve
				clear
				svmat2 other_tests_long, rnames(varname) names(col)
				order varname, first
				
				tempfile var_names_and_tests_`segment_`segment'
				save 	`var_names_and_tests_`segment''
			restore
		}
		
		** 3) t-tests: compute pvalue for pair-wise stats
		if `nv_t' == 2  & "`permute_pvalue'" != "" {
			local within_seg_n 0
			foreach var in ``segment'' {
				ritest `treat_var' _b[`treat_var']/_se[`treat_var'], reps(${n_reps}) 	///
				seed(${n_seed}) strata(strata) cluster(`cluster_var') nodots force: 	///
				reg `var' `treat_var' i.strata [pw = `weight_var'] `spe_cond', cluster(`cluster_var')
					
				local pairwise_permute = r(p)[1,1]
				mat pairwise_permute = (`pairwise_permute')
				matrix colnames pairwise_permute = permutation_pval
				matrix rownames pairwise_permute = "`var'"
					
				// Concatenate p-vals within each SPEC
				if (`within_seg_n' == 0) matrix pairwise_permute_long = pairwise_permute  // start matrix for 1st var in section 
				if (`within_seg_n' >  0) matrix pairwise_permute_long = pairwise_permute_long \ pairwise_permute  // then append to p_collect

				local within_seg_n = `within_seg_n' + 1
			}
			preserve
				clear
				svmat2 pairwise_permute_long, rnames(varname) names(col)
				order varname, first
				
				gen permutation_pval_ast     = "*" if permutation_pval < 0.10
				replace permutation_pval_ast = "**"  if permutation_pval < 0.05
				replace permutation_pval_ast = "***" if permutation_pval < 0.01
				
				gen permutation_pval_text = string(permutation_pval, "%6.3f") + permutation_pval_ast
				drop permutation_pval permutation_pval_ast
				
				tempfile permute_`segment'
				save 	`permute_`segment''
			restore
		}
		
		// define local for footnote resizing and use below for small edit
		if `nv_t' == 2 {
			local footnote_resize 1.20
		}
		else {
			local footnote_resize 1.325
		}
		
		
		** 4) t-tests: run iebaltab for pair-wise stats
		if "`no_onerow'" == "" 		local onerow_option = "onerow"
		else                   		local onerow_option
		
		preserve
		// sample condition for iebaltab
		if "``segment'_condi'" != "" keep ``segment'_condi' 

		iebaltab ``segment'' `spe_cond' 			///
			[pw = `weight_var'], 					/// 						
			grpvar(`treat_var') 					///
			savetex(${output_balance}/`table_name'_`segment') ///
			`strata_option'    					    ///
			vce(cluster `cluster_var')  			///
			stats(pair(p))							/// show p-values instead of t-test diffs
			addnote("\textit{Notes}:"               ///
					"`table_note1'" 				///
					"`table_note2'" 				///
					"`table_note3'"   				///
					"`table_note4'"   				///
					"`table_note5'"   				///
					"`table_note6'"   				///
					"`table_note7'"                 ///
					"`table_note8'") 				///
			texnotewidth(`footnote_resize') 		///	
			nonote                                  ///
			rowvarlabels 							/// use variable labels
			`onerow_option'						 	///
			replace 
			
		restore 
	}
	

	** 6)  postprocess balance table
	 foreach segment in `segs' {
	   
		local seg_ct = `seg_ct' + 1

		import delimited "${output_balance}/`table_name'_`segment'.tex", clear
	
		// concatenate tex info into one column keeping commas intact since -import- parses at commas
		fix_import
		
		// drop package des
		gen rank = _n 
		qui sum rank if strpos(text, "begin{tabular") > 0
		local here = `r(mean)'
		drop if rank < `here'
		replace rank = rank - `here' + 1
		
		// remove backslash before $
		// need double slash "\\" inside stata to catch single \
		replace text = subinstr(text, "\\$", "$", .) if strpos(text, "\\$") > 0 
		
		// merge in additional stats
		split text, parse("&")
		gen varlab = strtrim(text1)
		
		// adjust observations and clusters value 		
		local range_lo = 1 + `nv_t' + 1 
		scalar range_pair = (exp(lnfactorial(`nv_t'))/(exp(lnfactorial(2))*exp(lnfactorial(`nv_t'-2))))
		local range_pair : di %8.0g scalar(range_pair)
		local range_hi = 1 + `nv_t' + `range_pair'
		local range_max = `range_hi' + 2*`f_test'		
		
		if "`no_onerow'" == "" {
			
		}
		else { // no build for treatment == 2 yet but it is possible with locals defined above
			nois dis "No no_onerow option built for treatment == 2"
			qui sum rank if strpos(text1, "Variable") > 0 
			local rank_var = `r(mean)'
			
			// need to drop N and clusters columns and then resize the dataset 
			forvalues i = 1 3 : `= (`range_hi' - 1) * 2 - 1' {
				local j = `i' + 1
				replace text`j' = "" if rank >= `rank_var'
			}
			forvalues i = 2/`range_hi' {
				local j = 2 * `i' - 1
				replace text`i' = text`j' if rank >= `rank_var'
				replace text`i' = subinstr(text`i', "\multicolumn{2}{c}{", "\multicolumn{1}{c}{", .) 
			}
			if "``segment'_nclus'" != "" {
				forvalues i = 2/`range_hi' {
					drop if strpos(text`i', "(0.000)") > 0
					replace text`i' = subinstr(text`i', ".000", "", .)
					replace text`i' = subinstr(text`i', ".v ", "", .)
					replace text`i' = subinstr(text`i', ".n ", "", .)					
				}
			}
			
			forvalues i = `= `range_hi' + 1' / `= `range_hi' * 2 - 1' {
				drop text`i'
			} 
			replace text`range_lo' = subinstr(text`range_lo', "\multicolumn{`= (`range_pair') * 2'}{c}{", "\multicolumn{`range_pair'}{c}{", .) 
			
			local ltx_col_old = "l"
			forvalues i = 2 / `= `range_hi' * 2 - 1' {
				local ltx_col_old `ltx_col_old' c
			}
			local ltx_col_old = subinstr("`ltx_col_old'", " ", "", .)
			
			local ltx_col_new = "l"
			forvalues i = 1 / `= `range_hi' - 1' {
				local ltx_col_new `ltx_col_new' c
			}
			local ltx_col_new = subinstr("`ltx_col_new'", " ", "", .)
			
			replace text1 = subinstr(text1, "`ltx_col_old'", "`ltx_col_new'", .) 
			replace text1 = subinstr(text1, "\multicolumn{`= `range_hi' + `nv_t''}", "\multicolumn{`range_hi'}", .)
		}

		if `f_test' == 1 {
			merge m:1 varlab  using "`var_names_and_labs_`segment''", gen(_mnames)
			sort rank 
		
			merge m:1 varname using "`var_names_and_tests_`segment''", gen(_mstats)
			
			if "``segment'_nclus'" != "" replace pooled_f = . // get rid of absurd pooled f tests for constant vars 
		}
		if `nv_t' == 2  & "`permute_pvalue'" != "" {
			merge m:1 varlab  using "`var_names_and_labs_`segment''", gen(_mnames)
			sort rank 
		
			merge m:1 varname using "`permute_`segment''", gen(_mstats)			
		}
		sort rank 	
		
		// rename observations and clusters labels
		if "`no_onerow'" == "" {
			qui sum rank if strpos(text, "clusters") > 0 
			local rank_cluster = `r(mean)'
			replace text1 = "N" if rank == `rank_cluster' - 1 
			replace text1 = "Clusters" if rank == `rank_cluster'
		}
				
		if "`no_onerow'" == "" {
			forvalues i = `range_lo'/`range_hi' {
				replace text`i' = "" if rank == `rank_cluster' - 1 
				replace text`i' = "" if rank == `rank_cluster'  
			}
		}
		
		// fix decimal places on new f-tests
		if `f_test' == 1 {
			foreach var in joint_f pooled_f {
				gen `var'_txt = string(`var')
				replace `var'_txt = `var'_txt + "0" if strlen(`var'_txt) == 3 // if dp = 2
				replace `var'_txt = `var'_txt + "*" if `var' < 0.1  // give it a star
				replace `var'_txt = `var'_txt + "*" if `var' < 0.05 // give it another
				replace `var'_txt = `var'_txt + "*" if `var' < 0.01 // and another
				replace `var'_txt = "" if `var'_txt == "." // clear empty cells
				replace `var'_txt = " 0" + `var'_txt if `var'_txt != "" // add "ones" zero
				drop `var'
			}
		
			drop varlab varname _mnames _mstats // drop variables used in merge
		
			ds text*
			local varneeded : word count `r(varlist)'
			local varneeded = `varneeded' - 1 
			split text`varneeded', parse(" ")
			replace text`varneeded' = text`varneeded'1
			drop text`varneeded'1
		
		
			// adjust column headers for new and old stats
			replace joint_f_txt  = " P-value " if text`varneeded'3 != "" & ///
												strpos(text`varneeded'3, "\\") <= 0
			replace pooled_f_txt = " P-value " if text`varneeded'3 != "" & ///
												strpos(text`varneeded'3, "\\") <= 0		
		
			forval i = 1/`=_N' { 
				// new stats
				local joint_entry
				local joint_entry `"`=joint_f_txt[`i']'"'
				local change_i2 = `i' - 2
				local change_i1 = `i' - 1
				if strpos("`joint_entry'", "P-value") > 0 {
					replace joint_f_txt  = " \multicolumn{1}{c}{Joint F-test} " in `change_i1'
					replace joint_f_txt  = " \multicolumn{1}{c}{(5)} " in `change_i2'
					replace pooled_f_txt  = " \multicolumn{1}{c}{Pooled F-test} \\" in `change_i1'
					replace pooled_f_txt  = " \multicolumn{1}{c}{(6)} " in `change_i2'
				}		
			
				// old stats
				qui ds text? text?? // list parsed vars
				local words : word count `r(varlist)'
				forval j = 1/`words' { // foreach var 
					local entry
					local entry `"`=text`j'[`i']'"'
					local this "text`j'"
					if (strpos("`entry'", "Mean/SE") > 0) local swaplist : list swaplist | this
				}
				foreach var in `swaplist' {
					local entry
					local entry `"`=`var'[`i']'"'
					local entry1
					local entry1 `"`=`var'[`i'-1]'"'
					local entry2
					local entry2 `"`=`var'[`i'-2]'"'
				
					if strpos("`entry'", "Mean/SE") > 0 {
						dis "`entry1'"
						dis "`entry'"
						dis "`entry2'"
					
						replace `var' = "`entry1'" in `change_i2'
						replace `var' = "`entry'" in `change_i1'
						replace `var' = "`entry2'" in `i'
					}
				}
			}
		
		
			ds text`varneeded'?
			egen conc_text_needed = concat(`r(varlist)'), punct(" ")
			replace pooled_f_txt = pooled_f_txt + " " + conc_text_needed
			drop text`varneeded'?

			// remove line ending from old column header list and add it to 
			local varneeded_new = `varneeded' - 5
			replace text`varneeded_new' = subinstr(text`varneeded_new', "  \\", " ", .)
		
			// change table settings to accomodate 2 new columns
			replace text1 = subinstr(text1, "lcccccccccc", "lcccccccccccc", 1) // add two c's
		
			// insert line under p-value row
			// adjust pooled values 
			replace text`varneeded_new' = subinstr(text`varneeded_new', "P-value", "\multicolumn{6}{c}{P-value}", .)
			forvalues i = `=`varneeded' - 4'/`varneeded' {
				replace text`i' = subinstr(text`i', "P-value", " ", .)
			} 
			replace text = subinstr(text, "P-value", "p-value", .)
			replace text = text + "\cmidrule(lr){6-11}" if strpos(text, "\multicolumn{6}{c}{p-value}") > 0 
		}
		
		replace text`range_lo' = subinstr(text`range_lo', "Pairwise t-test", "Pairwise T-test", .) // adjust label
		
		// merge permutation pvalues 
		if `nv_t' == 2  & "`permute_pvalue'" != "" {
			gen permutation_pval_text_se = "[" + permutation_pval_text[_n-1] + "]" if permutation_pval_text[_n-1] != ""
			replace text`range_hi' = permutation_pval_text_se + text`range_hi' 
			keep text - varlab
			replace text`range_lo' = subinstr(text`range_lo', "P-value", "Asymp/[Perm] P-values", .) // adjust label
		}
		 
		// fix se rows 
		sort rank
		if `f_test' == 1 {
			gen se_rows = 1 if strpos(text`range_hi', "\\") > 0 
			replace text`range_hi' = "" if se_rows == 1 
			if "``segment'_nclus'" == "" {
				replace pooled_f_txt = " \\ [1ex]" if se_rows == 1 
			}
			else {
				replace pooled_f_txt = " \\" if se_rows == 1 
			}
		}
		// fix cluster and N lines 
		if `f_test' == 1 {
			if "`no_onerow'" == "" {
			replace pooled_f_txt = pooled_f_txt + "\\" if rank == `rank_cluster' - 1 | ///
														  rank == `rank_cluster' 
			gen rows_spe = 1 if se_rows == 1               | /// 
								rank == `rank_cluster' - 1 | ///
								rank == `rank_cluster' 				
			}
			else {
				gen rows_spe = 1 if se_rows == 1 
			}
			drop conc_text_needed se_rows 
		}
		else {
			if "`no_onerow'" == "" {
			replace text`range_hi' = text`range_hi' + "\\" if rank == `rank_cluster' - 1 | ///
														      rank == `rank_cluster'
			gen rows_spe = 1 if rank == `rank_cluster' - 1 | ///
								rank == `rank_cluster' 	
			drop varlab 
			}
			else {
			gen rows_spe = 0
			}
			drop varlab
		}

							 
		// bring it all together
		drop rank  
		gen text_new = text1
		ds text text1 text_new rows_spe, not
		foreach var in `r(varlist)' {
			// adjust cluster, N lines and se lines 
			replace text_new = text_new + " & "  + `var' if strtrim(`var') != "" | rows_spe == 1
		}
		replace text_new = stritrim(text_new) 
		drop rows_spe
									   
		// make footnote wider (13 instead of 11 because 1 var, 4 Ts, 6  T-tests, and 2 new F-tests)
		replace text_new = subinstr(text_new, "\multicolumn{`range_hi'}{@{} p{`footnote_resize'\textwidth}}", ///
											  "\multicolumn{`range_max'}{@{} p{`footnote_resize'\textwidth}}", .)
		
		// change format from tabular to longtable
		replace text_new = subinstr(text_new, "\begin{tabular}{@{\extracolsep{5pt}}", ///
											  "\begin{longtable}{", .)
		
		// indent rows that need to be indented
		foreach lab in `indentthese' {
			replace text_new = subinstr(text_new, "`lab' &", "\hspace{0.25cm} `lab' &", .) 
		}
		
		keep text_new
		rename text_new text
	
		// stack other segments below seg1
		if `seg_ct' == 1 {	
			 
			// opening and closing
			gen rank = _n
			replace text = subinstr(text, "\end{tabular}", "\end{longtable}", .) if rank == _N
			insobs 1, before(2) // second obs
			replace text = "\caption{`table_title'}        \label{tab:`table_name'} \\" if text == ""
			insobs 1, before(7) // second obs
			replace text = "\endfirsthead" if text == ""
			drop rank
			gen rank = _n
			gen dup_rows = 1 if strpos(text, "\multicolumn{1}{c}{(1)-(2)}") > 0 | ///
								strpos(text, "Pairwise T-test") > 0 | ///
								strpos(text, "Mean/(SE)") > 0 
								
			expand 2 if dup_rows == 1, gen(dup_these)
			qui sum rank if strpos(text, "endfirsthead")
			local under_here `r(mean)'
			replace rank = `r(mean)' + rank / 100 if dup_these == 1
			sort rank
			insobs 1, after(10)
			replace text = "\endhead" if text == ""
			insobs 1, before(8)
			replace text = "\multicolumn{`range_max'}{c}{{\bfseries `table_title' -- continued from previous page}} \\ \hline" if text == ""
			insobs 1, after(12)
			replace text = "\\" if text == ""
			insobs 1, after(13)
			replace text = "\multicolumn{`range_max'}{c}{{Continued on next page}} \\ \hline" if text == ""
			insobs 1, after(14)
			replace text = "\endfoot" if text == ""
			
			// pull up note
			gen move_note = 1 if strpos(text, "This is the note") > 0
			qui sum rank if move_note == 1
			local note_n `r(mean)'
			replace move_note = 1 if rank == `note_n' - 1
			replace move_note = 1 if rank == `note_n' + 1
		
			// capture location to which to move
			drop rank dup_*
			gen rank = _n
			qui sum rank if strpos(text, "\endfoot") > 0
			replace rank = `r(mean)' + rank/100 if move_note == 1
			sort rank
			
			drop rank move_note
			gen rank = _n
			qui sum rank if strpos(text, "textit{Notes") > 0
			
			local here = `r(mean)'
			insobs 1, after(`here')
			
			replace text = "\endlastfoot" if text == ""
			
			local new = `here' + 1
			insobs 1, after(`new')
			replace text = "%\\" if text == "" // "\\"
			
			// panel header for first segment
			drop rank 
			gen rank = _n
			qui sum rank if strpos(text, "\endlastfoot") > 0
			local here = `r(mean)'
			insobs 1, after(`=`here'+1')
			replace text = "\multicolumn{`range_max'}{l}{\textbf{`seg`seg_ct'_header'}} \\" if text == ""
			
			
			// drop line between balance and observations clusters lines
			if "`no_onerow'" == "" {
				qui sum rank if strpos(text, "Clusters ") > 0 
				local row_drop = `r(mean)' - 2
				drop if rank == `row_drop'
			}
			
			// insert nobs line 
			drop rank
			gen rank = _n
			qui sum rank if strpos(text, "\end{longtable}") > 0
			local here = `r(mean)'
			insobs 1, after(`=`here'-1')			
			replace text = "`nobs_row`seg_ct''" if text == ""
			drop if text == "" 
			
			replace text = trim(itrim(text))
			
			keep text
		}
		else {
			
			// stack under seg1
			gen rank = _n 
			
			if "`no_onerow'" == "" {
				sum rank if strpos(text, "N &") > 0
				local bound_up = `r(mean)' - 2 
				sum rank if strpos(text, "Variable &") > 0
				local bound_lo = `r(mean)' + 1 			
			}
			else {
				sum rank if strpos(text, "%%% This is the note.") > 0
				local bound_up = `r(mean)' - 2 
				sum rank if strpos(text, "Variable &") > 0
				local bound_lo = `r(mean)' + 1 					
			}
			
			keep if (rank <= `bound_up' & rank >= `bound_lo') | /// stats
							strpos(text, "N &") > 0 | 			/// sample size
							strpos(text, "Clusters") > 0 		// no. of clusters					
			

			keep text 		
			insobs 1, before(1) // insert a panel header for new segment 
			replace text = "\hline \\ \multicolumn{`range_max'}{l}{\textbf{`seg`seg_ct'_header'}} \\" in 1
			insobs 1, before(1) // insert a panel header for new segment 
			replace text = "%\\" in 1 // "\\"
			
			tempfile seg_stats
			save 	`seg_stats'
			
			
			// import previous segment
			local seg_pre = `seg_ct' - 1
			import delimited "${output_balance}/`table_name'_seg`seg_pre'_fixed.tex", clear
			fix_import
			
			append using `seg_stats'
			replace text = trim(itrim(text))
			
			// move end{longtable} to new bottom
			drop if strpos(text, "\end{longtable}")
			insobs 1
			replace text = "\end{longtable}" in `=_N'

			/*
			// drop first set of "N" and "clusters" if they are duplicated
			if "`no_onerow'" == "" {
			egen dup = tag(text) 
			gen rank = _n
			byso text : egen drophigh = rank(rank), field
			levelsof drophigh
			sort rank
			drop if drophigh == 2 & (strpos(text, "N &") > 0 | 	/// sample size
									 strpos(text, "Clusters") > 0) // clusters
			}
			*/	
			
			// insert nobs line 
			gen rank = _n
			qui sum rank if strpos(text, "\end{longtable}") > 0
			local here = `r(mean)'
			insobs 1, after(`=`here'-1')			
			replace text = "`nobs_row`seg_ct''" if text == ""
			drop if text == "" 
			
			keep text	
		}
		
		
		// save
		
		outfile using "${output_balance}/`table_name'_`segment'_fixed.tex", noquote wide replace
		
		if `seg_ct' == `seg_n' { 
			
			outfile using "${output_balance}/`table_name'_allsegments_final.tex", noquote wide replace
			
			// also save in reproducibility folder
			outfile using "${output_balance}/`table_name'_si1.tex", noquote wide replace
		}	
	}
} // end quietly

end
