/*****************************************************************************
Title: 01_clean_preparation
Prepare Chad Followup Data
	Outline:
	1. Prepare household data
	2. Prepare household member data
	3. Prepare data by survey section and save each file in long and wide format
*****************************************************************************/
	   
	****************************************************************************
	*--------------------- I. Prepare household data --------------------------*
	****************************************************************************

	*a. prep main file
	*----------------- 
	
	* Variable types changed during SurveyCTO import -- fix
	use "${deidentified_${phase}}/TCHAD_IE Follow-up 1_deid.dta", clear
	drop if 		hhid==. // those observations are empty.

	qui ds 				activity*  plot_name*, has(type numeric)
	foreach var in `r(varlist)' {
		tostring 	`var', replace
	}

	tempfile 		main_file
	save 			`main_file'

	** use hhid to merge with CT beneficiaries dataset
	merge 1:1 hhid using "${ed}/sample_${ph}.dta", gen(_treat_status)
	keep if 	_treat_status==3
	drop strata

	*prep intro
	gen 		__PRELOADED__ = "Preloaded informtation"
	order		__PRELOADED__, before(p_region_code)

	label var 	p_region_code 			"Preloaded region"
	label var 	p_sousprefecture_code 	"Preloaded sous-prefecture"
	label var 	p_sousprefecture_txt  	"Preloaded sous-prefecture"
	label var 	p_canton_code 			"Preloaded canton"
	label var 	p_village_code 			"Preloaded village"
	label var 	p_hhsize 				"Preloaded household size"
	label var 	p_benef_pos 			"Preloaded  position"
	label var	tel_works 				"Preloaded phone works"

	*save
	compress
	save "${intermediate_${phase}}/chad_main_2021", replace

	preserve
		keep 		hhid - list_chef benef  treatVill pm_treatment treatment_status 
		rename 		list_chef chef_pos
		label var	chef_pos 				"(Updated) Head of household position in household roster"
		label drop 	benef
		rename 		benef benef_pos
		label var	benef_pos "(Updated) CT Beneficiary position in household roster"
		gen 		benef_diff = 0 
		replace 	benef_diff = 1 if benef_pos != p_benef_pos
		label var 	benef_diff "(Updated) CT Beneficiary different from preloaded beneficiary"

		compress
		save "${intermediate_${phase}}/chad_hh_2021", replace
	restore
	
	
	****************************************************************************
	*----------------- II. Prepare household member data --------------------- *  
	****************************************************************************

	// put both surveycto loops over members together in same file (rpt_mem and rpt_mem2)

	// roster: name, age, sex, relation with household head, marital status
	use "${deidentified_${phase}}/TCHAD_IE Follow-up 1-gp_consent-SECTION_roster-rpt_mem.dta", clear

	*get position number of preloaded member
	split 		key, parse([ ])
	destring 	key2, gen(mem_pos)
	label var	mem_pos "Position in Roster"
	so 			hhid mem_pos
	order 		mem_pos, after(hhid)

	** drop variables
	drop 		parent_key key setof* key1 key2
	
	tempfile	 members
	save 		`members'

	*** roster: marital status, education level, physical state/wellbeing
	use "${deidentified_${phase}}/TCHAD_IE Follow-up 1-gp_consent-SECTION_members-rpt_mem2.dta", clear

	** get position number of household member
	split 		key, parse([ ])
	destring 	key2, gen(mem_pos)
	label var 	mem_pos "Position in roster"
	so 			hhid mem_pos
	order 		mem_pos, after(hhid)

	** drop variables
	drop 		parent_key key setof* key1 key2

	tempfile 	members2
	save 		`members2'

	use 		`members'
	merge 1:1 	hhid mem_pos using `members2'

	order 		mem_pos, after(hhid)
	gen 		old_new = ""
	order 		old_new, after(mem_pos)
	replace 	old_new = "pre-loaded" if p_mem_id != ""
	replace 	old_new = "new this round" if p_mem_id == ""
	label var	old_new "preloaded member or new this round"
	drop 		p_mem_id

	***** Merge in beneficiary position
	merge m:1 	hhid using "${intermediate_${phase}}/chad_main_2021", ///
		keepusing(p_benef_pos benef treatment_status consent) gen(_merge2) 
	// Note: 81 hhds not matched (not surveyed actually: 1740-81=1659-1 hhd withou
	drop if 	consent == 0
	drop 		_merge2 consent

	gen 		p_benef = 1  if p_benef_pos ==  mem_pos & (treatment_status == 1 | treatment_status == 2 | treatment_status == 4) 
	order 		p_benef, after(p_marital_code)
	label		variable p_benef "preloaded CT beneficiary?"

	label drop 	benef
	gen 		is_benef = p_benef if mem_pos == benef 
	order 		is_benef, after(posif_chef)
	drop 		benef

	drop 		_merge
	drop 		add_new
		
	*** Labelling
	gen 		__Preloaded__ = "Preloaded member information"
	order 		__Preloaded__
		
	label var 	p_sex 			"Preloaded: sex"
	label var 	p_age 			"Preloaded: age"
	label var 	p_relation_code "Preloaded: relationship to preloaded household head"
	label values p_relation_code relation
	drop 		p_relation_txt
	rename 		p_relation_code p_relation
	label var 	p_marital_code 	"Preloaded: marital status"
	label values p_marital_code marital
	label var	still_member 	"Preloaded member is still a member of household"
	label var 	not_member_why 	"Why preloaded member not still a member of household"
	label var 	not_member_why_o "Other"

	gen 		__Updated__ = "Updated member information"
	order		__Updated__, before(still_member)
	drop 		posif_here
	order 		is_chef, before(posif_chef)
	label var 	is_chef "Is household head"
	rename 		posif_chef pos_chef
	order 		relation_o, after(relation)
	order 		rank_fem, after(relation_o)

	label var 	sex 			"Sex"
	label var 	age 			"Age"
	label var 	relation 		"Relation to household head"
	label var 	relation_o 		"Other"
	label var 	rank_fem 		"Seniority of wife"
	label var 	new_mem_why 	"Why was this member not preloaded as a household member"
	label var 	pos_chef 		"Chef position if this member is household head"

	label var 	hh_mm_key 		"Household head or beneficiary - key member for SurveyCTO"
	label var 	marital 		"Marital status"
	label var 	spouse_in 		"Is the spouse in the household"
	label var 	spouses 		"Who are the spouses in the household (roster position)"
	label var 	read 			"Can read"
	label var 	read_w 			"What languages can they read"

	compress
	save "${intermediate_${phase}}/members_long.dta", replace

	** add a prefix for reshape
	foreach var of varlist old_new - phy_work {
		rename `var' `var'_
	}
	reshape wide old_new_-phy_work_, i(hhid) j(mem_pos)

	// Save
	compress
	save "${intermediate_${phase}}/members_wide.dta", replace

	
	****************************************************************************
	*----------------- III. Prepare data by survey section ------------------- *
	****************************************************************************
	
	* ------------------------------------------------------------------------ *
	* ---------------------------- Prep Agriculture -------------------------- *
	* ------------------------------------------------------------------------ *
	
	* ------------------------------- Plots ---------------------------------- *
	
	// Main plot list
	use "${deidentified_${phase}}/TCHAD_IE Follow-up 1-gp_consent-SECTION_agriculture-SECTION_plots-rpt_plots.dta", clear
	so  		hhid plot_pos

	** generate key
	split 		key, parse([ ])
	drop 		key1
	destring 	key2, gen(__key__)
	label var 	__key__ "position in roster"
	drop 		parent_key key setofrpt* key2
	order 		__key__, after(hhid)

	compare 	__key__ plot_pos
	list 		hhid if __key__<plot_pos     
	* checking hhds for which  __key__ <plot_pos as shown from compare
	
	** not equal in hhid = 6730, 25431, 25500,  (replace plot_pos = __key__)
	replace 	plot_pos = __key__ 	if 	inlist(hhid, 6730, 25431, 25500)

	** clean strings
	ds, has(type string)
	foreach var in `r(varlist)' {
		replace `var' = trim(itrim(`var'))
	}

	** save
	compress
	tempfile	 main_plotlist
	save 		 `main_plotlist'


	// Rain plot list
	use "${deidentified_${phase}}/TCHAD_IE Follow-up 1-gp_consent-SECTION_agriculture-SECTION_cropsrain1-rpt_plotrain.dta", clear

	* convert variable type for append
	ds 			raincodeorother* rcropname*, has(type numeric)
	foreach var in `r(varlist)' {
		tostring `var', replace
	}

	tempfile 	plotrain2
	save 		`plotrain2'

	** generate key
	split 		key, parse([ ])
	destring 	key2, gen(__key__)
	label var 	__key__ "position in roster"
	order 		__key__, after(hhid)
	*drop parent_key key setofrpt* key1 key2
	drop 		parent_key key setofrpt* 
	so 			hhid __key__

	** ensure rcrop1_o - rcropname10 are strings
	ds 			rcrop1_o - rcropname10, has(type numeric)
	foreach var in `r(varlist)' {
		tostring `var', replace
	}

	** clean strings
	ds, has(type string)
	foreach var in `r(varlist)' {
		replace `var' = trim(itrim(`var'))
	}

	** drop missing observations
	drop if missing(rain_plot_name)

	** save
	compress
	tempfile 	main_rainplotlist
	save 		`main_rainplotlist'


	// Merge main_rainplotlist and main_dryplotlist
	use 		`main_rainplotlist', clear
	tempfile 	merged_plotlist
	save 		`merged_plotlist', replace

	use 		`main_plotlist', clear
	merge 1:1 	hhid __key__ using `merged_plotlist'
	drop 		_merge

	** clean
	drop if 	missing(plot_name)
	drop 		__key__

	** label variables
	label var 	plot_pos 			 "position dans la liste"
	label var 	plot_name 			 "parcelle"
	label var 	plot_ha 			 "taille de parcelle (hectares)"
	label var 	plot_key 			 "parcelle gere ou possede par la beneficiaire ou le chef du menage"
	label var 	plot_israin 		 "rain plot"
	label var 	plotpos_israinandkey "parcelle clef et pluviale"

	forvalues i = 1/60 {
	label var 	days_mem`i' 		 "nombre de jours que personne `i' a travaille sur la parcelle"
	}

	forvalues i = 1/10 {
	label var 	raincodeorother`i' 	 "code ou nom de la culture - pluviale"
	label var 	rcropname`i' 		 "nom de la culture - pluviale"
	}

	label var 	rain_plot_name 		 "parcelle - pluviale"
	label var 	plot_rain_grew 		 "les cultures cultives sur la parcelle pluviale"
	label var 	plot_rain_harv 		 "les cultures recoltes sur la parcelle pluviale"
	label var 	plot_rain_sold 		 "les cultures vendus sur la parcelle pluviale"

	** save long
	compress
	save "${intermediate_${phase}}/main_plotlist_long", replace

	** reshape wide
	ds 			hhid plot_pos, not
	
	foreach var in `r(varlist)' {
		ren `var' `var'_
		local l_`var'_ : variable label `var'_
	}

	* ds hhid plot_pos, not
	* local stubnames "`r(varlist)'"
	* reshape wide `r(varlist)', i(hhid) j(plot_pos)   /// flag error

	ds 			plot_name_*
	local count = wordcount("`r(varlist)'")
	di "`count'"

	forvalues i = 1/`count' {
		foreach varstub in `stubnames' {
			label var `varstub'`i' "`l_`varstub''"
		}
	}

	** save wide
	compress
	save 	"${intermediate_${phase}}/main_plotlist_wide", replace


	* ---------------------------- Rain Crops -------------------------------- *

	// Rain crops 1
	use "${deidentified_${phase}}/TCHAD_IE Follow-up 1-gp_rainkeycond-rpt_rcrops.dta", clear

	** generate plot and crop number using 'key' variable
	split 		key, parse([ ])
	destring 	key2, gen(plot_no)
	destring 	key4, gen(crop_no)
	order 		hhid plot_no crop_no, first
	so 			hhid plot_no crop_no
	drop 		parent_key key setofrpt* key1 key2 key3 key4

	** drop empty observations
	drop if 	missing(rcrop_name)

	** save temporary file
	compress
	tempfile 	rain_crops_1
	save 		`rain_crops_1', replace

	// Rain crops 2
	use "${deidentified_${phase}}/TCHAD_IE Follow-up 1-gp_consent-SECTION_agriculture-SECTION_cropsrain2-rpt_rcrops2.dta", clear

	** generate crop position (position in harvested crop list) from 'key' variable
	split 		key, parse([ ])
	destring 	key2, gen(crop_pos)
	order 		hhid crop_pos, first
	so 			hhid crop_pos
	drop 		parent_key key setofrpt* key1 key2

	** drop empty observations
	drop if 	missing(raincodeorother)
	drop if 	raincodeorother == "."

	** save temporary file
	compress
	tempfile 	rain_crops_2
	save 		`rain_crops_2', replace

	/// MERGE
	
	// 1 - Produce final rain crops 1 dataset
	  
	*take 'crop_pos' variable from rcrops2 dataset to add into rcrops1 dataset
	use 		`rain_crops_2', clear

	keep 		hhid crop_pos rcrop2name

	tempfile 	rcrop2_merge
	save 		`rcrop2_merge'

	use 		`rain_crops_1', clear

	** generate linking variable, "rcrop2name"
	gen 		rcrop2name = rcrop_name

	** merge
	merge m:1 	hhid rcrop2name using `rcrop2_merge'
	* _m = 1 when harvesting hadn't begun or if harvest was entirely lost. Drop if _m == 2.
	drop if 	_merge == 2
	drop 		_merge

	order 		hhid plot_no crop_no crop_pos, first
	so 			hhid plot_no crop_no crop_pos

	* This is the final "rainCrops_1" dataset
	compress
	save 		"${intermediate_${phase}}/raincrops_1_long", replace

	** reshape wide
	gen 		plot_crop_no = string(plot_no)+"_"+string(crop_no)
	order 		plot_crop_no, after(crop_no)
	drop 		plot_no crop_no

	ds 			hhid plot_crop_no, not
	foreach var in `r(varlist)' {
		ren `var' `var'_
	}

	ds 			hhid plot_crop_no, not
	reshape 	wide `r(varlist)', i(hhid) j(plot_crop_no) s

	* In the reshape, the first number in the suffix is the plot number.
	* The second number in the suffix is the crop number

	compress
	save 		"${intermediate_${phase}}/raincrops_1_wide", replace


	// 2 - Produce final rain crops 2 dataset
	  
	* take 'plot_no' from rcrops1 and merge into rcrops2
	use 		"${intermediate_${phase}}/raincrops_1_long", clear

	keep 		hhid rcrop_name plot_no

	** reshape dataset
	* want to reshape dataset into unique household-crop observations.
	byso 		hhid rcrop_name : gen n = _n
	reshape 	wide plot_no , i(hhid rcrop_name) j(n)

	** generate list of plots by crop
	ds 			plot_no*
	foreach var in `r(varlist)' {
		tostring `var', replace
		replace `var' = "" if `var' == "."
	}

	ds 			plot_no*
	egen 		plot_no = concat(`r(varlist)'), punct(" ")

	** save
	keep 		hhid rcrop_name plot_no
	ren 		rcrop_name rcrop2name
	tempfile 	plot_no
	save 		`plot_no', replace

	** add plot_no to rcrops2
	use 		 `rain_crops_2', clear
	merge 1:1	 hhid rcrop2name using `plot_no'
	order 		 hhid crop_pos plot_no, first
	* _m = 2 are crops that were not harvested/sold by the household and are therefore not in rcrops2
	drop if 	 _merge == 2
	drop 		 _merge
	
	* This is the final rain Crops 2 dataset
	compress
	save 		 "${intermediate_${phase}}/raincrops_2_long", replace

	** reshape wide
	ds 			 hhid crop_pos, not
	foreach var in `r(varlist)' {
		ren `var' `var'_
	}

	ds 			 hhid crop_pos, not
	reshape 	 wide `r(varlist)', i(hhid) j(crop_pos)

	compress
	save 		 "${intermediate_${phase}}/raincrops_2_wide", replace


	* ------------------------------------------------------------------------ *
	* ----------------------------- Prep Assets ------------------------------ *
	* ------------------------------------------------------------------------ *
	
	* ------------------------ Agricutural Assets ---------------------------- *

	use "${deidentified_${phase}}/TCHAD_IE Follow-up 1-gp_consent-SECTION_assets-rpt_ag_ass.dta", clear
	so 			hhid ag_ass_pos

	** generate key
	split 		key, parse([ ])
	destring 	key2, gen(__key__)
	label var 	__key__ "position in roster"
	drop 		parent_key key setofrpt* key1 key2
	order 		__key__, after(ag_ass_pos)

	compare	 	__key__ ag_ass_pos
	** equal
	drop 		ag_ass_pos
	so 			hhid __key__

	** rename variables to be consistent
	ren 		ass_ag ag_asset
	ren 		ass_ag_n ag_asset_n
	ren 		ag_ass_name ag_asset_name

	** save long
	compress
	save 		"${intermediate_${phase}}/assets_ag_long", replace

	** reshape wide
	ds 			hhid __key__, not
	foreach var in `r(varlist)' {
		ren `var' `var'_
		local l_`var'_ : variable label `var'_
	}

	ds 			hhid __key__, not
	local 		stubnames "`r(varlist)'"
	reshape 	wide `r(varlist)', i(hhid) j(__key__)

	ds 			ag_asset_name_*
	local count = wordcount("`r(varlist)'")
	display		"`count'"

	forvalues i = 1 / `count' {
		foreach varstub in `stubnames' {
			display "display variable: `varstub'`i'"
			display "display label: `varstub'`i'"
			label variable `varstub'`i' "`l_`varstub''"
		}
	}

	compress
	save "${intermediate_${phase}}/assets_ag_wide", replace

	* ------------------------- Household Assets ----------------------------- *
	
	use "${deidentified_${phase}}/TCHAD_IE Follow-up 1-gp_consent-SECTION_assets-rpt_hh_ass.dta", clear

	** generate key
	split 		key, parse([ ])
	destring 	key2, gen(__key__)
	label var	__key__ "position in roster"
	drop 		parent_key key setofrpt* key1 key2
	order 		__key__, after(ass_hh_pos)

	compare 	__key__ ass_hh_pos
	
	** equal
	drop 		ass_hh_pos
	so 			hhid __key__

	** rename variables to be consistent
	ren 		ass_hh* hh_asset*

	compress
	save 		"${intermediate_${phase}}/assets_hh_long", replace

	** reshape wide, then save labels for after reshape
	ds 			hhid __key__, not
	foreach var in `r(varlist)' {
		ren `var' `var'_
		local l_`var'_ : variable label `var'_
	}

	ds			hhid __key__, not
	local 		stubnames "`r(varlist)'"
	reshape 	wide `r(varlist)', i(hhid) j(__key__)

	ds 			hh_asset_name_*
	local count = wordcount("`r(varlist)'")
	display 	"`count'"

	forvalues i = 1 / `count' {
		foreach varstub in `stubnames' {
			display "display variable: `varstub'`i'"
			display "display label: `varstub'`i'"
			label variable `varstub'`i' "`l_`varstub''"
		}
	}

	compress
	save 		"${intermediate_${phase}}/assets_hh_wide", replace


	* ------------------------------------------------------------------------ *
	* --------------------------- Prep Employment ---------------------------- *
	* ------------------------------------------------------------------------ *
	
	************ ------------------_ BENEFICIARIES  -------------- *************
	****************************************************************************
	
	* ----------------------------- 1. Work  --------------------------------- *
	
	use "${deidentified_${phase}}/TCHAD_IE Follow-up 1_deid.dta", clear

	* keeping only employment section variables: 
	keep hhid wrk_ag30 wrk_ag12 wrk_liv30 wrk_liv12 wrk_sal30 wrk_sal12 		 ///
		 wrk_sal_n wrk_sal wrk_na30 wrk_na12 empl1 empl2 empl3 empl4 empl5 		 ///
		 rpt_sal_count setofrpt_sal resp_empl 									 ///
		 wrk_ag30_chef wrk_ag12_chef wrk_liv30_chef wrk_liv12_chef 				 ///
		 wrk_sal30_chef wrk_sal12_chef wrk_sal_n_chef wrk_sal_chef wrk_na30_chef ///
		 wrk_na12_chef empl1_chef empl2_chef empl3_chef empl4_chef empl5_chef    ///
		 rpt_sal_chef_count setofrpt_sal_chef									 ///
		 list_key n_key keypos1 keypos2 keysex1 keysex2 key 
	
	order 		hhid key, first
	so 			hhid 
	
	ds 			empl1-empl5 empl1_chef-empl5_chef, has(type numeric)
		foreach var in `r(varlist)' {
			tostring `var', replace
			replace `var' = "" if `var' == "."
		}
	
	// drop
	drop 		setofrpt_sal

	// label
	label var 	wrk_sal "Emploi salarié"
    label var 	wrk_sal_chef "Emploi salarié du chef de ménage"
	
	** save long
	compress
	tempfile 	work
	save 		`work', replace

	compress
	save 		"${intermediate_${phase}}/work.dta", replace


	* ------------------- 2. Employment & Salary  ----------------------------- *

	use "${deidentified_${phase}}/TCHAD_IE Follow-up 1-gp_consent-SECTION_emploi-gp_empl_cond-rpt_sal.dta", clear

	drop if 	missing(empl_name) & missing(empl_type)

	** generate key
	split 		key, parse([ ])
	drop 		key1 
	destring 	key2, replace
	assert		key2 == empl_pos

	// drop
	drop 		parent_key key setofrpt_sal key2

	** label variables
	label var 	empl_name "Nom Emploi"
	label var  	empl_type "Type d'Emploi"
	
	save 		"${intermediate_${phase}}/salary_long", replace
		

	************ ------------------ HOUSEHOLD HEAD  -------------- *************
	****************************************************************************
	
	* ----------------------------- 1. Work  --------------------------------- *
	
	// see above

	* ------------------- 2. Employment & Salary  ----------------------------- *

	use "${deidentified_${phase}}/TCHAD_IE Follow-up 1-gp_consent-SECTION_emploi_chef-gp_empl_cond_chef-rpt_sal_chef.dta", clear

	drop if 	missing(empl_name_chef) & missing(empl_type_chef)

	** generate key
	split 		key, parse([ ])
	drop 		key1 
	destring 	key2, replace
	assert		key2 == empl_pos_chef

	// drop
	drop 		parent_key key setofrpt_sal_chef empl_pos_chef

	// order
	order 		hhid key2

	** label variables
	label var 	empl_name_chef "Nom Emploi Chef de Ménage"
	label var  	empl_type_chef "Type d'Emploi Chef de Ménage"
	
	compress
	save 		"${intermediate_${phase}}/salary_long_chef", replace
	
	
	* ------------------------------------------------------------------------ *
	* ----------------------------- Prep Finance ----------------------------- *
	* ------------------------------------------------------------------------ *
	
	* ------------------------------- Credit  -------------------------------- *
	
	use  "${deidentified_${phase}}/TCHAD_IE Follow-up 1-gp_consent-SECTION_finance-PART_credit-rpt_cred.dta", clear
	so 			hhid cred_pos

	** generate key
	split 		key, parse([ ])
	destring 	key2, gen(__key__)
	label var 	__key__ "position in roster"
	drop 		parent_key key setofrpt* key1 key2
	order 		__key__, after(*_pos)
	
	compare 	__key__ *_pos
	** equal
	drop 		*_pos
	so 			hhid __key__

	** gen cred_name_o & label cred_name when cred_pos == 7
	gen 		cred_name_o = cred_name if __key__ == 7
	order 		cred_name_o, after(cred_name)
	replace 	cred_name = "Autre personne ou groupe a specifier" if __key__ == 7

	** save long
	compress
	save 		"${intermediate_${phase}}/credit_long", replace

	** reshape wide
	ds 			hhid __key__, not
	
	foreach var in `r(varlist)' {
		ren `var' `var'_
		local l_`var'_ : variable label `var'_
	}

	ds 			hhid __key__, not
	local 		stubnames "`r(varlist)'"
	reshape 	wide `r(varlist)', i(hhid) j(__key__)

	ds 			cred_name_o_*
	local count = wordcount("`r(varlist)'")
	di 			"`count'"

	forvalues i = 1/`count' {
		foreach varstub in `stubnames' {
			di "display variable: `varstub'`i'"
			di "display label: `varstub'`i'"
			label var `varstub'`i' "`l_`varstub''"
		}
	}

	** save wide
	compress
	save 		"${intermediate_${phase}}/credit_wide", replace


	* ------------------------------ Savings  -------------------------------- *
	
	use "${deidentified_${phase}}/TCHAD_IE Follow-up 1-gp_consent-SECTION_finance-PART_othersave-gp_savemoreinfo.dta", clear
	so 			hhid saves_pos

	** generate key
	split 		key, parse([ ])
	destring 	key2, gen(__key__)
	label var 	__key__ "position in roster"
	drop 		parent_key key setofgp* key1 key2
	order 		__key__, after(saves_pos)

	compare 	__key__ saves_pos
	** equal
	drop 		*_pos
	so 			hhid __key__

	** gen saves_loc_name_o
	gen 		saves_loc_name_o = saves_loc_name if __key__ == 9
	order 		saves_loc_name_o, after(saves_loc_name)
	replace 	saves_loc_name = "Autre endroit a specifier" if __key__ == 8

	** save long
	compress
	save 		"${intermediate_${phase}}/savings_long", replace

	** reshape wide
	ds 			hhid __key__, not
	
	foreach var in `r(varlist)' {
		ren `var' `var'_
		local l_`var'_ : variable label `var'_
	}

	ds 			hhid __key__, not
	local 		stubnames "`r(varlist)'"
	reshape 	wide `r(varlist)', i(hhid) j(__key__)

	ds 			saves_loc_name_o_*
	local count = wordcount("`r(varlist)'")
	di 			"`count'"

	forvalues i = 1/`count' {
		foreach varstub in `stubnames' {
			di "display variable: `varstub'`i'"
			di "display label: `varstub'`i'"
			label var `varstub'`i' "`l_`varstub''"
		}
	}

	** save wide
	compress
	save 		"${intermediate_${phase}}/savings_wide", replace

	
	* ------------------------------ Tontines  ------------------------------- *
	
	use "${deidentified_${phase}}/TCHAD_IE Follow-up 1-gp_consent-SECTION_finance-PART_savgroup-rpt_ton.dta", clear
	
	so 			hhid ton_pos

	** generate key
	split 		key, parse([ ])
	destring 	key2, gen(__key__)
	label var 	__key__ "position in roster"
	drop 		parent_key key setofrpt* key1 key2
	order 		__key__, after(ton_pos)

	compare 	__key__ ton_pos
	** equal
	drop 		ton_pos
	so 			hhid __key__

	** save long
	compress
	save 		"${intermediate_${phase}}/tontines_long", replace

	** reshape wide
	ds 			hhid __key__, not
	
	foreach var in `r(varlist)' {
		ren `var' `var'_
		local l_`var'_ : variable label `var'_
	}

	ds 			hhid __key__, not
	local 		stubnames "`r(varlist)'"
	reshape 	wide `r(varlist)', i(hhid) j(__key__)

	ds 			ton_fr_o_*
	local count = wordcount("`r(varlist)'")
	di 			"`count'"

	forvalues i = 1/`count' {
		foreach varstub in `stubnames' {
			di "display variable: `varstub'`i'"
			di "display label: `varstub'`i'"
			label var `varstub'`i' "`l_`varstub''"
		}
	}

	** save wide
	compress
	save 		"${intermediate_${phase}}/tontines_wide", replace

	
	* ------------------------------------------------------------------------ *
	* --------------------------- Prep Consumption --------------------------- *
	* ------------------------------------------------------------------------ *
	
	
	* --------------------------- Food Consumption --------------------------- *
	
	**append consum2
	use "${deidentified_${phase}}/TCHAD_IE Follow-up 1-gp_consent-SECTION_foodconsumption-rpt_consum2.dta", clear
	so 			hhid consum2_pos

	tempfile 	consum2
	save 		`consum2', replace

	use "${deidentified_${phase}}/TCHAD_IE Follow-up 1-gp_consent-SECTION_foodconsumption-rpt_consum1.dta", clear
	so		 	hhid consum1_pos
	
	keep 		hhid consum1_pos consum1_name consum

	** rename for merge
	ren 		consum1_pos consum2_pos

	merge 1:m 	hhid consum2_pos using `consum2'
	l 			hhid consum2_pos if _merge != 3
	drop 		_merge

	duplicates 	t hhid consum2_pos, gen(dup)

	** generate key
	split 		key, parse([ ])
	destring 	key2, gen(food_loop)
	so 			hhid food_loop
	order		food_loop, after(hhid)
	drop 		parent_key key setofrpt* key1 key2

	/** Cleaning:
	2 cases where with extra obs: food_loop != consum2_pos: hhid=25911 & hhid=26347
	**/
	drop if 	food_loop == 34 & consum2_pos == 35 & inlist(hhid, 25911)
	drop if 	food_loop == 33 & consum2_pos == 35 & inlist(hhid, 26347)
	replace consum_bot = 0.25 if consum2_pos == 35 & inlist(hhid, 6461)
	
	drop 		food_loop // because consum2_pos is actually the correct code
	replace 	consum2_name = consum1_name if missing(consum2_name) & !missing(consum1_name)
	replace 	consum2_ate = consum if missing(consum2_ate) & !missing(consum)
	drop 		dup consum1_name consum

	** rename variables
	ren 		*consum2_* *consum_*

	** reshape wide
	ds 			hhid consum_pos, not
	
	foreach var in `r(varlist)' {
		ren `var' `var'_
		local l_`var'_ : variable label `var'_
	}

	duplicates  t hhid consum_pos, gen(dup)
	byso 	    hhid consum_pos : gen n = _n
	drop if     dup > 0 & n > 1
	drop 		dup n

	ds 			hhid consum_pos, not
	local 		stubnames "`r(varlist)'"
	reshape 	wide `r(varlist)', i(hhid) j(consum_pos)

	ds 			consum_name_*
	local count = wordcount("`r(varlist)'")
	di		 	"`count'"

	forvalues i = 1 / `count' {
		foreach varstub in `stubnames' {
			di "display variable: `varstub'`i'"
			di "display label: `varstub'`i'"
			label var `varstub'`i' "`l_`varstub''"
		}
	}

	**save wide
	compress
	save 		"${intermediate_${phase}}/foodconsumption_wide", replace

	**reshape back to long
	reshape 	long
	ren 		*_ *

	compress
	save 		"${intermediate_${phase}}/foodconsumption_long", replace


	* ------------------------- Non-Food Consumption ------------------------- *
	
	// celebrations 1
	use  "${deidentified_${phase}}/TCHAD_IE Follow-up 1-gp_consent-SECTION_nfconsumption-gp_cel-rpt_cel1.dta", clear
	so 			hhid cel1_pos

	** generate key
	split 		key, parse([ ])
	destring 	key2, gen(__key__)
	label var 	__key__ "position in roster"
	drop 		parent_key key setofrpt* key1 key2
	order 		__key__, after(cel1_pos)

	compare 	__key__ cel1_pos
	** equivalent
	drop 		cel1_pos
	so 			hhid __key__

	** save
	compress
	tempfile 	cel1
	save 		`cel1', replace

	// celebrations 2
	use "${deidentified_${phase}}/TCHAD_IE Follow-up 1-gp_consent-SECTION_nfconsumption-gp_cel-rpt_cel2.dta", clear
	so 			hhid cel2_pos

	** generate key
	split 		key, parse([ ])
	destring 	key2, gen(__key__)
	label var 	__key__ "position in roster"
	drop 		parent_key key setofrpt* key1 key2
	order 		__key__, after(cel2_pos)

	compare 	cel2_pos __key__
	** equivalent
	drop 		cel2_pos
	so 			hhid __key__

	** save
	compress
	tempfile 	cel2
	save		`cel2', replace

	** MERGE
	use 		`cel1', clear
	merge 1:1 	hhid __key__ using `cel2'
	drop 		_merge

	** save long
	compress
	save 		"${intermediate_${phase}}/nf_celebrations_long", replace

	** reshape wide
	ds 			hhid __key__, not
	
	foreach var in `r(varlist)' {
		ren `var' `var'_
		local l_`var'_ : variable label `var'_
	}

	ds 			hhid __key__, not
	local stubnames "`r(varlist)'"
	reshape wide `r(varlist)', i(hhid) j(__key__)

	ds 			cel1_name_*
	
	local count = wordcount("`r(varlist)'")
	di 			"`count'"

	forvalues i = 1/`count' {
		foreach varstub in `stubnames' {
			di "display variable: `varstub'`i'"
			di "display label: `varstub'`i'"
			label var `varstub'`i' "`l_`varstub''"
		}
	}

	** save wide
	compress
	save 		"${intermediate_${phase}}/nf_celebrations_wide", replace

	
	// Non-food consumption
	use "${deidentified_${phase}}/TCHAD_IE Follow-up 1-gp_consent-SECTION_nfconsumption-gp_nonfood-rpt_nonfood.dta", clear
	so 			hhid nonfood_pos

	** generate key
	split 		key, parse([ ])
	destring 	key2, gen(__key__)
	label var 	__key__ "position in roster"
	drop 		parent_key key setofrpt* key1 key2
	order 		__key__, after(nonfood_pos)

	compare 	__key__ nonfood_pos
	** equal
	drop 		nonfood_pos
	so 			hhid __key__

	** clean string variables
	ds, has(type string)
	
	foreach var in `r(varlist)' {
		replace `var' = trim(itrim(`var'))
	}

	** save long
	compress
	save 		"${intermediate_${phase}}/nonfood_consumption_long", replace

	** reshape wide
	ds 			hhid __key__, not
	
	foreach var in `r(varlist)' {
		ren `var' `var'_
		local l_`var'_ : variable label `var'_
	}

	ds 			hhid __key__, not
	local 		stubnames "`r(varlist)'"
	reshape 	wide `r(varlist)', i(hhid) j(__key__)

	ds 			nonfood_name_*
	local count = wordcount("`r(varlist)'")
	di 			"`count'"

	forvalues i = 1/`count' {
		foreach varstub in `stubnames' {
			di "display variable: `varstub'`i'"
			di "display label: `varstub'`i'"
			label var `varstub'`i' "`l_`varstub''"
		}
	}

	** save wide
	compress
	save 		"${intermediate_${phase}}/nonfood_consumption_wide", replace

	// repair consumption
	use "${deidentified_${phase}}/TCHAD_IE Follow-up 1-gp_consent-SECTION_housing-r_improve.dta", clear

	split key, parse([ ])
	destring key2, gen(improve_pos)

	drop key* setof* parent_key
	
	isid hhid improve_pos	
	sort hhid improve_pos	
	order hhid improve_pos, first
	
	compress
	save "${intermediate_${phase}}/repair_consumption_long", replace
	
	
	* ------------------------------------------------------------------------ *
	* ---------------------------- Prep Livestock ---------------------------- *
	* ------------------------------------------------------------------------ *
	
	use "${deidentified_${phase}}/TCHAD_IE Follow-up 1-gp_consent-SECTION_livestock-rpt_ani1.dta", clear

	split 		key, parse([ ])
	drop 		key1

	ren 		key2 livestock_pos
	destring 	livestock_pos, replace
	so 			hhid livestock_pos
	order 		livestock_pos, after(hhid)
	drop 		parent_key key setofrpt*

	drop 		ani1_pos			// identical to livestock_pos 
	drop 		ani_manage_members_19 ani_manage_members_20 ani_manage_members_21 ///
				ani_manage_members_22 ani_manage_members_23 ani_manage_members_24 ///
				ani_manage_members_25 ani_manage_members_26 ani_manage_members_27 ///
				ani_manage_members_28 ani_manage_members_29 ani_manage_members_30 ///
				ani_manage_members_31 ani_manage_members_32 ani_manage_members_33 ///
				ani_manage_members_34 ani_manage_members_35 ani_manage_members_36 ///
				ani_manage_members_37 ani_manage_members_38 ani_manage_members_39 ///
				ani_manage_members_40 ani_manage_members_41 ani_manage_members_42 ///
				ani_manage_members_43 ani_manage_members_44 ani_manage_members_45 ///
				ani_manage_members_46 ani_manage_members_47 ani_manage_members_48 ///
				ani_manage_members_49 ani_manage_members_50 ani_manage_members_51 ///
				ani_manage_members_52 ani_manage_members_53 ani_manage_members_54 ///
				ani_manage_members_55 ani_manage_members_56 ani_manage_members_57 ///
				ani_manage_members_58 ani_manage_members_59 ani_manage_members_60
				

	drop if has_livestock == 0
	save 		"${intermediate_${phase}}/livestock_long", replace

	** reshape wide, then save labels for after reshape   
	ds 			hhid livestock_pos, not
	
	foreach var in `r(varlist)' {
		ren `var' `var'_
		local l_`var'_ : variable label `var'_
	}

	ds 			hhid livestock_pos, not
	local 		stubnames "`r(varlist)'"
	reshape 	wide `r(varlist)', i(hhid) j(livestock_pos)

	ds 			ani1_name_*
	local count = wordcount("`r(varlist)'")
	display 	"`count'"

	forvalues i = 1/`count' {
		foreach varstub in `stubnames' {
			display "display variable: `varstub'`i'"
			display "display label: `varstub'`i'"
			label variable `varstub'`i' "`l_`varstub''"
		}
	}

	save 		"${intermediate_${phase}}/livestock_wide", replace
	
	
	// ownership and sale value
	use "${deidentified_${phase}}/TCHAD_IE Follow-up 1-gp_consent-SECTION_livestock-r_four.dta", clear
	duplicates drop

	split key, parse([ ])
	drop key1
	ren key2 liv_mm_pos2
	destring liv_mm_pos2, replace
	order hhid liv_mm_pos2
	drop parent_key key setofr_four 
	assert liv_mm_pos2 == liv_mm_pos if liv_mm_pos != .

	drop liv_mm_pos2 // identical to liv_mm_pos
	sort hhid liv_mm_pos
	order hhid liv_mm_pos

	assert betail_mois == . if liv_mm_pos == . // time variables conditional on liv_mm_pos != .
	drop if liv_mm_pos == .

	label var liv_mm_pos 	"HH member Position"
	label var liv_mm_age 	"HH member age"
	label var betail_mois 	"No. of months HH member spent on livestock in last 12 months"
	label var betail_jours 	"No. of days/month HH member spent on livestock"
	label var betail_heures	"No. of hours/day HH member spent on livestock"

	save "${intermediate_${phase}}/livestock_mem_wrk_long", replace

	* ------------------------------------------------------------------------ *
	* ---------------------------- Prep Business ----------------------------- *
	* ------------------------------------------------------------------------ *
	
	use "${deidentified_${phase}}/TCHAD_IE Follow-up 1_deid.dta", clear

	
keep hhid start_na bus1_food bus1_tail bus1_constr bus1_comm bus1_prof bus1_serv bus1_trans bus1_art bus1_extra bus1_food_pos bus1_tail_pos bus1_constr_pos bus1_comm_pos bus1_prof_pos bus1_serv_pos bus1_trans_pos bus1_art_pos bus1_extra_pos bus_def_type_list act_n activity1 activity1_type activity2 activity2_type activity3 activity3_type activity4 activity4_type activity5 activity5_type activity6 activity6_type activity7 activity7_type activity8 activity8_type activity9 activity9_type activity10 activity10_type activity11 activity11_type activity12 activity12_type activity13 activity13_type activity14 activity14_type activity15 activity15_type activity16 activity16_type activity17 activity17_type activity18 activity18_type activity19 activity19_type activity20 activity20_type
	
	** dropping variables with all missing values 
	missings dropvars, force

	compress
	save 		"${intermediate_${phase}}/chad_business", replace


	* ------------------------------------------------------------------------ *
	
	use "${deidentified_${phase}}/TCHAD_IE Follow-up 1-gp_consent-SECTION_na-gp_bus2-rpt_bus2.dta", clear

	** generate key
	split 		key, parse([ ])
	drop 		key1
	ren 		key2 __key__
	label var 	__key__ "position in roster"
	destring 	__key__, replace
	so 			hhid __key__
	drop 		parent_key key setofrpt_*
	order 		__key__, after(hhid)
	so 			hhid __key__
	
	drop bus2_own_14 bus2_own_15 bus2_own_16 bus2_own_17 bus2_own_18 bus2_own_19 ///
		 bus2_own_20 bus2_own_21 bus2_own_22 bus2_own_23 bus2_own_24 bus2_own_25 ///
		 bus2_own_26 bus2_own_27 bus2_own_28 bus2_own_29 bus2_own_30 bus2_own_31 ///
		 bus2_own_32 bus2_own_33 bus2_own_34 bus2_own_35 bus2_own_36 bus2_own_37 ///
		 bus2_own_38 bus2_own_39 bus2_own_40 bus2_own_41 bus2_own_42 bus2_own_43 ///
		 bus2_own_44 bus2_own_45 bus2_own_46 bus2_own_47 bus2_own_48 bus2_own_49 ///
		 bus2_own_50 bus2_own_51 bus2_own_52 bus2_own_53 bus2_own_54 bus2_own_55 ///
		 bus2_own_56 bus2_own_57 bus2_own_58 bus2_own_59 bus2_own_60
		 
	drop bus2_manage_14 bus2_manage_15 bus2_manage_16 bus2_manage_17 bus2_manage_18 ///
		 bus2_manage_19 bus2_manage_20 bus2_manage_21 bus2_manage_22 bus2_manage_23 ///
		 bus2_manage_24 bus2_manage_25 bus2_manage_26 bus2_manage_27 bus2_manage_28 ///
		 bus2_manage_29 bus2_manage_30 bus2_manage_31 bus2_manage_32 bus2_manage_33 ///
		 bus2_manage_34 bus2_manage_35 bus2_manage_36 bus2_manage_37 bus2_manage_38 ///
		 bus2_manage_39 bus2_manage_40 bus2_manage_41 bus2_manage_42 bus2_manage_43 ///
		 bus2_manage_44 bus2_manage_45 bus2_manage_46 bus2_manage_47 bus2_manage_48 ///
		 bus2_manage_49 bus2_manage_50 bus2_manage_51 bus2_manage_52 bus2_manage_53 ///
		 bus2_manage_54 bus2_manage_55 bus2_manage_56 bus2_manage_57 bus2_manage_58 ///
		 bus2_manage_59 bus2_manage_60	 
		  
	drop bus2_manage_members_17 bus2_manage_members_18 bus2_manage_members_19 ///
		 bus2_manage_members_20 bus2_manage_members_21 bus2_manage_members_22 ///
		 bus2_manage_members_23 bus2_manage_members_24 bus2_manage_members_25 ///
		 bus2_manage_members_26 bus2_manage_members_27 bus2_manage_members_28 ///
		 bus2_manage_members_29 bus2_manage_members_30 bus2_manage_members_31 ///
		 bus2_manage_members_32 bus2_manage_members_33 bus2_manage_members_34 ///
		 bus2_manage_members_35 bus2_manage_members_36 bus2_manage_members_37 ///
		 bus2_manage_members_38 bus2_manage_members_39 bus2_manage_members_40 ///
		 bus2_manage_members_41 bus2_manage_members_42 bus2_manage_members_43 ///
		 bus2_manage_members_44 bus2_manage_members_45 bus2_manage_members_46 ///
		 bus2_manage_members_47 bus2_manage_members_48 bus2_manage_members_49 ///
		 bus2_manage_members_50 bus2_manage_members_51 bus2_manage_members_52 ///
		 bus2_manage_members_53 bus2_manage_members_54 bus2_manage_members_55 ///
		 bus2_manage_members_56 bus2_manage_members_57 bus2_manage_members_58 ///
		 bus2_manage_members_59 bus2_manage_members_60
		 	 
	drop bus2_workers_17 bus2_workers_18 bus2_workers_19 bus2_workers_20 ///
		 bus2_workers_21 bus2_workers_22 bus2_workers_23 bus2_workers_24 ///
		 bus2_workers_25 bus2_workers_26 bus2_workers_27 bus2_workers_28 ///
		 bus2_workers_29 bus2_workers_30 bus2_workers_31 bus2_workers_32 ///
		 bus2_workers_33 bus2_workers_34 bus2_workers_35 bus2_workers_36 ///
		 bus2_workers_37 bus2_workers_38 bus2_workers_39 bus2_workers_40 ///
		 bus2_workers_41 bus2_workers_42 bus2_workers_43 bus2_workers_44 ///
		 bus2_workers_45 bus2_workers_46 bus2_workers_47 bus2_workers_48 ///
		 bus2_workers_49 bus2_workers_50 bus2_workers_51 bus2_workers_52 ///
		 bus2_workers_53 bus2_workers_54 bus2_workers_55 bus2_workers_56 ///
		 bus2_workers_57 bus2_workers_58 bus2_workers_59 bus2_workers_60
		 
		 
	drop actdays_mem16 actdays_mem17 actdays_mem18 actdays_mem19 actdays_mem20 ///
		 actdays_mem21 actdays_mem22 actdays_mem23 actdays_mem24 actdays_mem25 ///
		 actdays_mem26 actdays_mem27 actdays_mem28 actdays_mem29 actdays_mem30 ///
		 actdays_mem31 actdays_mem32 actdays_mem33 actdays_mem34 actdays_mem35 ///
		 actdays_mem36 actdays_mem37 actdays_mem38 actdays_mem39 actdays_mem40 ///
		 actdays_mem41 actdays_mem42 actdays_mem43 actdays_mem44 actdays_mem45 ///
		 actdays_mem46 actdays_mem47 actdays_mem48 actdays_mem49 actdays_mem50
		 	 
	drop resp_bus2_14 resp_bus2_15 resp_bus2_16 resp_bus2_17 resp_bus2_18 ///
		 resp_bus2_19 resp_bus2_20 resp_bus2_21 resp_bus2_22 resp_bus2_23 ///
		 resp_bus2_24 resp_bus2_25 resp_bus2_26 resp_bus2_27 resp_bus2_28 ///
		 resp_bus2_29 resp_bus2_30 resp_bus2_31 resp_bus2_32 resp_bus2_33 ///
		 resp_bus2_34 resp_bus2_35 resp_bus2_36 resp_bus2_37 resp_bus2_38 ///
		 resp_bus2_39 resp_bus2_40 resp_bus2_41 resp_bus2_42 resp_bus2_43 ///
		 resp_bus2_44 resp_bus2_45 resp_bus2_46 resp_bus2_47 resp_bus2_48 ///
		 resp_bus2_49 resp_bus2_50 resp_bus2_51 resp_bus2_52 resp_bus2_53 ///
		 resp_bus2_54 resp_bus2_55 resp_bus2_56 resp_bus2_57 resp_bus2_58 ///
		 resp_bus2_59 resp_bus2_60 bus2_date
		 
	** relabel actdays_mem
	forvalues i = 1/15 {
	label var 	actdays_mem`i' "nombre de jours membre `i' a travaille les 30 derniers jours dans l'activite"
	}
	
	** relabel business owner
		forvalues i = 0/13 {
	label var 	bus2_own_`i' "Le membre `i' du ménage est propriétaire de l'activité"
	}
	
		
	** relabel business manager
		forvalues i = 0/13 {
	label var 	bus2_manage_`i' "Le membre `i' du ménage gère l'activité"
	}

		** relabel other business manager
		forvalues i = 0/13 {
	label var 	bus2_manage_members_`i' "`i' est un autre membre qui gère l'activité"
	}

			** relabel business worker
		forvalues i = 0/13 {
	label var 	bus2_workers_`i' "Le membre `i' travaille dans l'activité"
	}

	** save
	compress
	save 		"${intermediate_${phase}}/business_long", replace

	** reshape wide
	ds 			hhid __key__, not
	foreach var in `r(varlist)' {
		ren `var' `var'_
		}

	ds 			hhid __key__, not
	reshape 	wide `r(varlist)', i(hhid) j(__key__)

	** save
	compress
	save 		"${intermediate_${phase}}/business_wide", replace


	* ------------------------------------------------------------------------ *
	* ---------------------------- Prep Transfers ---------------------------- *
	* ------------------------------------------------------------------------ *

	use "${deidentified_${phase}}/TCHAD_IE Follow-up 1-gp_consent-SECTION_transfers-rpt_trans.dta", clear
	duplicates drop 

	order key, last
	split key, parse([ ])
	drop key key1
	destring key2, gen(trans_pos2)
	drop key2
	label variable trans_pos2 "Location Position"
	sort hhid trans_pos2
	order hhid trans_pos2
	drop parent_key setofrpt_trans
	// assert trans_pos == trans_pos2
	// br if trans_pos != trans_pos2

	ds *__1
	foreach var in `r(varlist)' { // foreach of these repetitive variables
	// 	dis as result "`var'"
		local actual_var = substr("`var'", 1, strpos("`var'","__")-1)
		dis as result "`actual_var'"
		
		confirm variable `actual_var' // confirm that the text version exists
		local vartype : type `actual_var'
		local vartype = substr("`vartype'",1,3)
	// 	dis as error "`vartype'"
		assert "`vartype'" == "str"
		drop `actual_var'__? `actual_var'_? `actual_var'_??
	}
	// 53 variables dropped
	
	capture assert trans_pos == trans_pos2
	if _rc != 0 {
		foreach var in trans_rel trans_why trans_invill consum_nf_val_cur trans_amt trans_freq {
			assert `var' == . if trans_pos != trans_pos2
		}
	}	
	assert trans_who == "" if trans_rel == . // observations in broken loop are empty
	br if trans_pos != trans_pos2 // trans_pos has broken loop

	label var trans_who "19.04 Transfer: Who is the beneficiary of this transfer?"
	label var trans_rel "19.05 For the sender, what is the relationship with the beneficiary?"
	label var trans_why "19.06 What is the main reason for the transfer?"
	label var trans_invill "19.06b Does the sender live in this village / neighborhood?"
	label var trans_why_o "What other reason?"
	label var trans_amt "19.07 What is the amount of the transfer sent each time?"
	label var trans_freq "If irregular, use last transfer and choose irregular frequency"

	compress
	save "${intermediate_${phase}}/transfers_long.dta", replace


	** reshape wide
	ds 			hhid trans_pos, not
	foreach var in `r(varlist)' {
		ren `var' `var'_
		local l_`var'_ : variable label `var'_
	}

	ds 			hhid trans_pos, not
	local 		stubnames "`r(varlist)'"
	reshape 	wide `r(varlist)', i(hhid) j(trans_pos)

	ds 			trans_*
	local count = wordcount("`r(varlist)'")/2
	di 			"`count'"

	forvalues i = 1/12 {
		foreach varstub in `stubnames' {
			di "display variable: `varstub'`i'"
			di "display label: `varstub'`i'"
			label var `varstub'`i' "`l_`varstub''"
		}
	}

	** save wide
	compress
	save 		"${intermediate_${phase}}/transfers_wide", replace
	
	
	***** Finance (transfers sent)
	********************************************************************************
	
	use "${deidentified_${phase}}/TCHAD_IE Follow-up 1-gp_consent-SECTION_cashtrans-rpt_trans_send.dta", clear
	duplicates drop 

	order key, last
	split key, parse([ ])
	drop key key1
	destring key2, gen(trans_pos_send2)
	drop key2
	label variable trans_pos_send2 "Location Position"
	sort hhid trans_pos_send2
	order hhid trans_pos_send2
	// assert trans_pos_send == trans_pos_send2 // broken loop for hhid == 289759
	// br if trans_pos_send != trans_pos_send2
	drop trans_pos_send parent_key setofrpt_trans_send

	ds *__1
	foreach var in `r(varlist)' { // foreach of these repetitive variables
	// 	dis as result "`var'"
		local actual_var = substr("`var'", 1, strpos("`var'","__")-1)
		dis as result "`actual_var'"
		
		confirm variable `actual_var' // confirm that the text version exists
		local vartype : type `actual_var'
		local vartype = substr("`vartype'",1,3)
	// 	dis as error "`vartype'"
		assert "`vartype'" == "str"
		drop `actual_var'__? `actual_var'_? `actual_var'_??
	}
	// 53 variables dropped

	label var trans_who_send "19.1: Who is the sender of this transfer?"
	label var trans_rel_send "19.11 For containers outside the household, what is the relationship with the sender?"
	label var trans_why_send "19.12 What is the main reason for the transfer?"
	label var trans_send_invill "19.12b Does the beneficiary live in this village / neighborhood?"
	label var trans_why_o_send "What other reason?"
	label var trans_amt_send "19.13 What is the amount of the transfer sent each time"
	label var trans_freq_send "If irregular, use last transfer and choose irregular frequency"

	compress
	save "${intermediate_${phase}}/transfers_sent_long.dta", replace

	
	* ------------------------------------------------------------------------ *
	* ------------------------------- Prep Shocks ---------------------------- *
	* ------------------------------------------------------------------------ *
	
	use "${deidentified_${phase}}/TCHAD_IE Follow-up 1-gp_consent-SECTION_shocks-rpt_shocks2.dta", clear
	so hhid shock_pos2

	** generate key
	split key, parse([ ])
	destring key2, gen(__key__)
	label var __key__ "position in roster"
	drop parent_key key setofrpt* key1 key2
	order __key__, after(shock_pos2)

	compare __key__ shock_pos2
	** equal
	drop __key__
	so hhid shock_pos2

	** save long
	compress
	save "${intermediate_${phase}}/shocks_long", replace

	** reshape wide
	ds hhid shock_pos2, not
	foreach var in `r(varlist)' {
		ren `var' `var'_
		local l_`var'_ : variable label `var'_
	}

	ds hhid shock_pos2, not
	local stubnames "`r(varlist)'"
	reshape wide `r(varlist)', i(hhid) j(shock_pos2)

	ds shock_askabout_*
	local count = wordcount("`r(varlist)'")
	di "`count'"

	forvalues i = 1/`count' {
		foreach varstub in `stubnames' {
			di "display variable: `varstub'`i'"
			di "display label: `varstub'`i'"
			label var `varstub'`i' "`l_`varstub''"
		}
	}

	** save wide
	compress
	save "${intermediate_${phase}}/shocks_wide", replace

	
	* ------------------------------------------------------------------------ *
	* ----------------------------- Prep Programs ---------------------------- *
	* ------------------------------------------------------------------------ *
	
	use "${deidentified_${phase}}/TCHAD_IE Follow-up 1-gp_consent-SECTION_programs-rpt_prog.dta", clear
	so 			hhid prog_pos

	** generate key
	split 		key, parse([ ])
	destring	key2, gen(__key__)
	label var 	__key__ "position in roster"
	drop 		parent_key key setofrpt* key1 key2
	order 		__key__, after(prog_pos)

	compare 	__key__ prog_pos
	** equal
	drop 		__key__
	so 			hhid prog_pos

	** save long
	compress
	save 		"${intermediate_${phase}}/programs_long", replace

	** reshape wide
	ds 			hhid prog_pos, not
	
	foreach var in `r(varlist)' {
		ren `var' `var'_
		local l_`var'_ : variable label `var'_
	}

	ds 			hhid prog_pos, not
	local 		stubnames "`r(varlist)'"
	reshape 	wide `r(varlist)', i(hhid) j(prog_pos)

	ds 			prog_type_o_*
	local count = wordcount("`r(varlist)'")
	di 			"`count'"

	forvalues i = 1/`count' {
		foreach varstub in `stubnames' {
			di "display variable: `varstub'`i'"
			di "display label: `varstub'`i'"
			label var `varstub'`i' "`l_`varstub''"
		}
	}

	** save wide
	compress
	save 	"${intermediate_${phase}}/programs_wide", replace
