     ***************************************************************************
	*																		  *
	*		  			BUSINESS OUTCOMES									  *
	*																		  *
	***************************************************************************
		
    /*		
	** PURPOSE: 	Clean and contruct non-ag business outcomes
					
	Outline:
	        - Business types 
	        - Activities, HH level 
	        - HH head level 
	        - Count of household non-agricultural business in last 12 months 
	        - Whether household has any non-agricultural business
	        - HH started a business within the last 12 months
	        - Abandoned a non-agricultural activity in last 24 months
	        - Total investments in non-agricultural businesses, beneficiary
	        - Estimated business profits, household level 
	        - New vs old business
    */

	****************************************************************************
	
********************************************************************************
*** B.3 Business types 
********************************************************************************

// hh-level dataset showing total number of busineses per household and type of business

if "$ph" == "bl" {
	use "${intermediate_${phase}}/chad_business.dta", clear
}
else if "$ph" == "fu" {
	use "${intermediate_${phase}}/chad_main_${phase_yr}.dta", clear
	drop if consent == 0
}

if "$ph" == "bl" {
	sort hhid bus_pos

	** bus_food
	gen bus_food_d = (bus_d == 1) if bus_pos == 1
	** bus_maker
	gen bus_tail_d = (bus_d == 1) if bus_pos == 2
	** bus_constr
	gen bus_constr_d = (bus_d == 1) if bus_pos == 3
	** bus_comm
	gen bus_comm_d = (bus_d == 1) if bus_pos == 4
	** bus_prof
	gen bus_prof_d = (bus_d == 1) if bus_pos == 5
	** bus_trans
	gen bus_trans_d = (bus_d == 1) if bus_pos == 6
	** bus_serv
	gen bus_serv_d = (bus_d == 1) if bus_pos == 7
	** bus_art
	gen bus_art_d = (bus_d == 1) if bus_pos == 8
	** bus_extra
	gen bus_extra_d = (bus_d == 1) if bus_pos == 9
	
	** bus_n
	bysort hhid: egen act_n = total(bus_n) // number of business at HH level
	drop bus_n
	label variable act_n "total number of household businesses"
	

	// number of business of each type at HH level (at FU these HH level vars are surveyed directly)
	foreach type in food tail constr comm prof trans serv art extra {
		bysort hhid: egen bus1_`type' = max(bus_`type'_d ) // rename bus_tpe to bus1_type to make consistent with raw FU Vars
	}
	
	// label HH-level dummy vars
	label var bus1_food    "HH business at ${phase}: transformation of food, 12 months"
	label var bus1_tail    "HH business at ${phase}: clothes or shoes, 12 months"
	label var bus1_constr  "HH business at ${phase}: construction, carpentry, 12 months"
	label var bus1_comm    "HH business at ${phase}: petty trade, 12 months"
	label var bus1_prof    "HH business at ${phase}: liberal profession, 12 months"
	label var bus1_trans   "HH business at ${phase}: transport, 12 months"
	label var bus1_serv    "HH business at ${phase}: other services, 12 months"
	label var bus1_art     "HH business at ${phase}: artisan, 12 months"
	label var bus1_extra   "HH business at ${phase}: other, 12 months"

	// step aside to collect: hhid bus2_pos activity activity_type
	preserve
		keep if bus_d != 0
		// try to match with bus2_pos
		keep hhid bus_pos bus_type bus_d bus_name_no*
		isid hhid bus_pos
		reshape long bus_name_no, i(hhid  bus_pos) j(bustype_ct)
		replace bustype_ct = bustype_ct / 10 // need this to count business below (egen bus2_pos)
		keep if bus_name_no != "" & bus_name_no != "." // . if no xth business at all
		
		// keep business with empty name
		byso hhid  bus_type : gen trackthis = bustype_ct + bus_pos + bus_type
		byso hhid  (trackthis) : egen bus2_pos = rank(trackthis), track
		
		sort hhid bus2_pos
		egen tag = tag(hhid bus2_pos)
		assert tag == 1
		drop tag
		isid hhid bus2_pos
		
		rename bus2_pos __key__
		merge 1:1 hhid  __key__ using "${intermediate_${phase}}/business_long.dta", keepusing(bus2_name)
		assert bus_name_no == bus2_name
		
		rename (__key__ bus_type bus2_name) (bus2_pos activity_type activity)
		
		keep hhid  bus2_pos activity activity_type
		order hhid bus2_pos activity activity_type
		tempfile bus_types
		save 	`bus_types' // ID = hhid bus2_pos
	restore
	
	keep hhid act_n bus1_food bus1_tail bus1_constr bus1_comm bus1_prof bus1_trans bus1_serv bus1_art bus1_extra
	duplicates drop
	isid hhid
}

* grouped enterprise variables (required in survey)
gen bus_group_1 = (bus1_trans == 1 | bus1_serv == 1)
label var bus_group_1 "Household activity: transport + other services, 12 months"
gen bus_group_2 = (bus1_art == 1 | bus1_tail == 1 | bus1_food == 1 | bus1_comm == 1)
label var bus_group_2 "Household activity: artisan + clothes/shoes + food transformation + petty trade, 12 months"
gen bus_group_3 = (bus1_constr == 1)
label var bus_group_3 "Household activity: construction/carpentry, 12 months"
gen bus_group_4 = (bus1_prof == 1)
label var bus_group_4 "Household activity: liberal profession, 12 months"
gen bus_group_5 = (bus1_extra == 1)
label var bus_group_5 "Household activity: other, 12 months"

/* NOTE: there are 1478 households who do not have a household enterprise --- is this still true? */
** div_n_na_12
egen div_n_na_12 = rowtotal(bus_group_1 bus_group_2 bus_group_3 bus_group_4 bus_group_5)
label var div_n_na_12 "B.3.3 Count of HH business types [0-5] at ${phase} last 12 months"
assert div_n_na_12 >= 0 & div_n_na_12 <= 5

if "$ph" == "fu" {
	// B3.6 FU main activity non-ag
	gen act_main_nonag = . // act_main is the same at FU1 and FU2
	levelsof act_main, local(act_list) // get list of businesses in survey: "$activity??"
	foreach act in `act_list' { // "$activity??" can go up to 20
		// ignore -2 (ag) and -1 (livestock) activities
		if `act' > 0 replace act_main_nonag = 1 if act_main == `act' & act_main_nonag == .
	}
	replace act_main_nonag = 0 if act_main_nonag == . // fill out remaining missings
	label var act_main_nonag "B.3.6 Beneficiary's main activity is Non-agricultural"
	
	// B9   FU healthy business practices (defined similarly at FU1 and FU2)
	assert plan == . if does_not_do_anything == 1
	local healthy_components prac_inp_know prac_best_know prac_goal prac_comp1 prac_cust prac_sup_chang ///
							 prac_sup_neg prac_sup_comp
	
	sum `healthy_components' prac_credit_record prac_freq_pub
	local i = 1
	foreach var in `healthy_components' prac_credit_record prac_freq_pub {
		assert `var' == . if does_not_do_anything == 1
		label var `var' "B.9 Healthy business practices component `i'"
		local i = `i' + 1
		replace `var' = 0 if missing(`var') & does_not_do_anything != 1
	}
	
	gen  prac_credit_record_d = 1 if prac_credit_record > 0 & !missing(prac_credit_record)
	replace prac_credit_record_d = 0 if prac_credit_record == 0
	label var prac_credit_record_d "B.9 Healthy business practices component 9"
	
	gen  prac_freq_pub_d = 1 if prac_freq_pub > 0 & !missing(prac_freq_pub)
	replace prac_freq_pub_d = 0 if prac_freq_pub == 0
	label var prac_freq_pub_d	   "B.9 Healthy business practices component 10"
		
	egen  health_bus = rsum(`healthy_components' prac_credit_record_d prac_freq_pub_d), m
	label var health_bus "B.9 Count of good business practices"
	
	// compute factor z-score for 10 healthy business components
	merge 1:1 hhid using "${constructed_${phase}}/identification", keepusing(pm_treatment)
	zindex `healthy_components' prac_credit_record_d prac_freq_pub_d, gen(health_bus_ind) condition(pm_treatment == 0)
	label variable health_bus_ind "B.9 Index of good business practices"

	local keep_var act_main_nonag  health_bus health_bus_ind `healthy_components' prac_credit_record_d prac_freq_pub_d
	
	preserve
		keep hhid activity*

		foreach var of varlist activity? activity?? {
			tostring `var', replace
			replace `var' = "" if `var' == "."
			replace `var' = subinstr(`var', "à", "a", .)
		}
		label copy activity1_type activity_type
		
		foreach var of varlist activity?_type activity??_type {
			label drop `var'
			tostring `var', replace force
			replace `var' = "" if `var' == "."
			replace `var' = subinstr(`var', "à", "a", .)
		}
		
		// reshape
		rename activity*_type activity_type*
		reshape long activity activity_type, i(hhid) j(bus2_pos)
		destring activity_type, replace
		drop if activity == "" & activity_type == .
		replace activity = trim(itrim(activity))
		sort activity
		assert activity_type != . // type info available for all businesses
		
		sort hhid bus2_pos
		isid hhid bus2_pos
		tempfile bus_types
		save 	`bus_types' // ID = hhid bus2_pos
	restore
}

keep  hhid act_n bus1_food - bus1_extra div_n_na_12 bus_group_* `keep_var'
order hhid act_n bus1_food - bus1_extra div_n_na_12 bus_group_* `keep_var'

// generate dummies for business vars
foreach var of varlist bus1_food - bus1_extra {
	gen 	`var'_d = `var' // copy var
	replace `var'_d = 1 if (`var' >= 1 & !missing(`var')) // make dummy
}

duplicates drop
isid hhid
tempfile bus1_outcomes
save `bus1_outcomes'


********************************************************************************
*** bus2: Revenues and Profits, HH BEN and chef level, 30 days and 12 months
********************************************************************************

	// import business data
	use "${intermediate_${phase}}/business_long.dta", clear
		
	if "$ph" == "bl" rename __key__    bus2_pos
	sort hhid
		
	merge m:1 hhid using "${constructed_${phase}}/demographics.dta", ///
		keepusing(hhid chef_pos benef_pos) gen(_mdemog)
	drop if _mdemog == 2 

	/* 
		ignore businesses with missing (not 0 or 1) here.
		No other info besides bus2_name and ownership	
		drop businesses owned entirely outside the HH
	*/
	if "$ph" == "bl" {
		rename (bus2_own2 bus2_curr) (bus2_own bus2_active) // baseline vars are named differently	
		drop if bus2_active == . | bus2_own == "0"  	
	}
	else if "$ph" == "fu" {
		drop if (bus2_own == "0" & bus2_manage  == "0") | bus2_name == ""
	}

	foreach lvl in chef benef {
		tostring `lvl'_pos, replace
		replace `lvl'_pos = trim(`lvl'_pos)		
	}

	*** divide by number of owners (no managers at BL) 		
	if "$ph" == "bl" local string_vars benef_pos chef_pos bus2_workers bus2_own
	if "$ph" == "fu" local string_vars benef_pos chef_pos bus2_workers bus2_own bus2_manage
	foreach var in `string_vars' {
		replace `var' = " " + `var' + " "
	}
	
	foreach lvl in chef ben {
		local varpos = cond("`lvl'" == "ben", "benef_pos", "chef_pos")
		if "$ph" == "bl" gen my_`lvl'_ownman = strpos(bus2_own, `varpos') > 0
		if "$ph" == "fu" gen my_`lvl'_ownman = strpos(bus2_own, `varpos') > 0 | strpos(bus2_manage, `varpos') > 0 	
		
		// test `lvl'_ownmanager variable with actual `lvl' position
		if "$ph" == "bl" {
			capture confirm var `lvl'_ownmanager	
			if _rc != 0 { // variable DNE at BL	
				rename my_`lvl'_ownman `lvl'_ownmanager  // (BL)	
			}	
			else if _rc == 0 { // variable only exists at FU	
				capture assert `lvl'_ownmanager == my_`lvl'_ownman // `lvl'_ownmanager is good at FU
				if _rc == 0 {	
					drop my_ben_ownman // if ben_ownmanager is correct, drop the new one 
				}	
				else {	
					drop `lvl'_ownmanager	
					rename my_`lvl'_ownman `lvl'_ownmanager  // if not, replace the two and continue
				}	
			}
		}
		else if "$ph" == "fu" {
			capture assert `lvl'_ownmanager == my_`lvl'_ownman // `lvl'_ownmanager is good at FU
			if "`lvl'" == "chef" rename my_`lvl'_ownman `lvl'_ownmanager
		}		
	}	
	
	*** divide by number of owner/managers 
	gen n_ownman = 0 // number of owners and managers excluding non-HH members
	gen n_ownman_original = 0 // // number of owners and managers regardless of HH membership
	
	if "$ph" == "bl" {
		gen bus2_ownmanage = bus2_own	
		gen bus2_people    = bus2_own + bus2_workers
	}
	else if "$ph" == "fu" {
		gen bus2_ownmanage = bus2_own 				 + bus2_manage 
		gen bus2_people    = bus2_own + bus2_workers + bus2_manage 
	}
	gen bus2_people_uniq = "" // List of owners, managers, and workers regardless of HH membership
	
	forval i = 1/`=_N' { 
	
		// count number of owners/managers for each business
		local all
		local all  `"`=bus2_ownmanage[`i']'"'
		local all : list uniq all
		replace n_ownman_original = `: list sizeof all' in `i'
		local zeros "0"
		local all : list all - zeros // remove if position = "0". Person not in HH
		replace n_ownman = `: list sizeof all' in `i'
		
		// fix months (1/2)
		// count number of months at FU
		if "$ph" == "fu" {
			local mos
			local mos  `"`=bus2_mos12[`i']'"'
			replace bus2_months = min(`: list sizeof mos', 12)  in `i' // cap at 12 because questions spanned more months at fu
		}
		
		// find business size using number of owners, managers, and workers
		local ppl
		local ppl `"`=bus2_people[`i']'"'
		local ppl : list uniq ppl
		replace bus2_people_uniq = "`ppl'" in `i'
	}
	
	preserve 
		tempfile secondary
		save 	`secondary'		
	restore
	
	preserve
		keep hhid `alsokeep' bus2_pos bus2_people_uniq
		isid hhid `alsokeep' bus2_pos // confirm unique businesses
		
		keep hhid bus2_people_uniq // keep people list
		gen n = _n
		byso hhid: egen bus2_posnew = rank(n) // count businesses (j in reshape)
		drop n 
		
		reshape wide bus2_people_uniq , i(hhid ) j(bus2_posnew)
		
		foreach var of varlist bus2_people_uniq* { // insert space after
			replace `var' = `var' + " "
		}
		egen hh_ppl = concat(bus2_people_uniq*)
		gen tot_bus2_ppl_uniq = . // uniq people
		forval i = 1/`=_N' {
			// find business size using number of owners, managers, and workers
			local ppl
			local ppl `"`=hh_ppl[`i']'"'
			local ppl : list uniq ppl
			replace tot_bus2_ppl_uniq =`: list sizeof ppl' in `i'
			
		}
		keep hhid tot_bus2_ppl_uniq
		label var tot_bus2_ppl_uniq "No. of unique people working in HH business"
		isid hhid
		tempfile buspeople
		save 	`buspeople'
	restore
	merge m:1 hhid using `buspeople', gen(_mppl)

	
	/* fix months (2/2)
		at baseline, we asked for integer no. of months <=12 (bus2_months)
		at Followup 1, we asked for list of months active in the last 12 and provided 24 options (bus2_mos12)
		at Followup 2, we asked for list of months active in the last 12 and provided 14 options 
	 				   constrained to 12 choices (bus2_mos12)
	*/
	
	// sanity checks
	if "$ph" == "bl" {
		assert bus2_months != . if bus2_active == 1
	}
	else if "$ph" == "fu" {
		replace bus2_active = 1 if bus2_active == . & bus2_mos12 != ""
		assert bus2_mos12 != "" // all business listed mention some months active in last 12 months
		assert inrange(bus2_months, 0, 12) | bus2_months == . // months range between 0 and 12
	}
	
	// merge in activity types (created above)
	merge 1:1 hhid `alsokeep' bus2_pos using `bus_types', gen(_mbus2)
	drop if _mbus2 == 2 // these are for businesses not owned or managed by hh members
	// _mbus2 == 1 will be handled below. These are businesses with revenues but not type info. Mark as "other"
	
	// some businesses have no names... mark them as "other"
	assert bus2_name == "" if activity_type == .
	
	gen misshere = activity_type == .
	byso hhid : egen prob = max(misshere)
	if "$ph" == "bl" replace activity_type = 9 if prob == 1
	
	foreach type in pro rev {
		foreach pp in 95 98 99 {
			
			// scale for currency if currency var exists
			capture confirm var bus2_prorev_curr
			if _rc == 0 { // if currency var exists 
				scale_cur bus2_`type'30 bus2_prorev_curr 
			}

			*winsorize 
			_pctile bus2_`type'30 , p(`pp')
			gen bus_`type'30_win_`pp' = bus2_`type'30 
			replace bus_`type'30_win_`pp' = `r(r1)' if !missing(bus_`type'30_win_`pp') & bus_`type'30_win_`pp' > `r(r1)'
			
			// Household
			gen hh_`type'30_`pp' = bus_`type'30_win_`pp' * n_ownman / n_ownman_original // exclude share of non-hh-member
			gen hh_`type'12_`pp' = hh_`type'30_`pp' * bus2_months // compute yearly ben total
			replace hh_`type'30_`pp' = 0 if bus2_active == 0 // drop business that were not active in last 30 days			
			
			// monthly total 
			byso hhid : egen tot_hh_`type'30_`pp' = total(hh_`type'30_`pp') // sum across HH excluding that non-hh-member
			replace tot_hh_`type'30_`pp' = tot_hh_`type'30_`pp' / 1000 // scale
			label var tot_hh_`type'30_`pp' "B.2.1 (1) HH bus `type' `pp' winsorized, 30 days (1000 FCFA)"
			
			// yearly total
			byso hhid : egen tot_hh_`type'12_`pp' = total(hh_`type'12_`pp') // sum across HH excluding that non-hh-member
			replace tot_hh_`type'12_`pp' = tot_hh_`type'12_`pp' / 1000 // scale
			label var tot_hh_`type'12_`pp' "B.2.1 (1) HH bus `type' `pp' winsorized, 1 year (1000 FCFA)"			
			
			// note that some businesses have revenues despite not operating in last year
			// hence those observations get a yearly value of zero
			// these tot_*rev30 vars are used in employment to get profit margins
			
			foreach lvl in ben chef {
				gen `lvl'_`type'30_`pp' = bus_`type'30_win_`pp' / n_ownman_original if `lvl'_ownmanager == 1 // pp only in `lvl'-owned/managed bus
				gen `lvl'_`type'12_`pp' = `lvl'_`type'30_`pp' * bus2_months // compute yearly `lvl' total
				replace `lvl'_`type'30_`pp' = 0 if bus2_active == 0 // for monthly rev, drop business that were not active in last 30 days	
				
				// monthly total 
				byso hhid: egen tot_`lvl'_`type'30_`pp' = total(`lvl'_`type'30_`pp')
				replace tot_`lvl'_`type'30_`pp' = tot_`lvl'_`type'30_`pp' / 1000 // scale
				label var tot_`lvl'_`type'30_`pp' "B.2.1 (1) `lvl' bus `type' `pp' winsorized , 30 days (1000 FCFA)"				
				// yearly total
				byso hhid: egen tot_`lvl'_`type'12_`pp' = total(`lvl'_`type'12_`pp')
				replace tot_`lvl'_`type'12_`pp' = tot_`lvl'_`type'12_`pp' / 1000 // scale
				label var tot_`lvl'_`type'12_`pp' "B.2.1 (1) `lvl' bus `type' `pp' winsorized, 1 year (1000 FCFA)"				
			}

			// HH and benef level by activity type:
			foreach lev in ben hh {
				capture confirm var activity_type
				if _rc == 0 {
					levelsof activity_type, local(acts)
					foreach act in `acts' {
						if "`lev'" == "ben" local yearlyrevvar ben_`type'12_`pp'
						if "`lev'" == "hh"  local yearlyrevvar hh_`type'12_`pp'
						
						// activity `act' share of yearly pro/rev at business level
						gen `type'_`lev'_`act'_`pp' = `yearlyrevvar' if activity_type == `act' 
						byso hhid : egen bus_`type'12_`lev'_`act'_`pp' = total(`type'_`lev'_`act'_`pp')
					}
					ds bus_`type'12_`lev'_?_`pp' // only 9. can't do double question mark
					local bus`type'_`lev'_by_act `r(varlist)'
				}
			}
	
		}  
	}
			
	// count nonoverlapping months across all of a HH's businesses
	if "$ph" == "bl" {
		byso hhid : egen tot_busmths_uniq = total(bus2_months)	
		assert tot_busmths_uniq != .	
		replace tot_busmths_uniq = min(tot_busmths_uniq, 12)
	}
	else if "$ph" == "fu" {
		gen bus2_months_all = bus2_mos12
		bysort hhid (bus2_pos) : replace bus2_months_all = bus2_months_all[_n-1] + " " + bus2_months_all if _n > 1
		bysort hhid (bus2_pos) : replace bus2_months_all = bus2_months_all[_N]
		gen busmths_uniq = .
		forval i = 1/`=_N' { 
			local mnths
			local mnths `"`=bus2_months_all[`i']'"'
			local mnths : list uniq mnths
			local omit "0"
			local mnths : list mnths - omit
			replace bus2_months_all = "`mnths'" in `i'
			replace busmths_uniq =`: list sizeof mnths' in `i'
		}
		replace busmths_uniq = busmths_uniq + 1 if strpos(bus2_mos12, "2105 2105") > 0		
		gen tot_busmths_uniq = busmths_uniq
		byso hhid (tot_busmths_uniq) : replace tot_busmths_uniq = tot_busmths_uniq[_N]
	}	
	
	// get unique months of beneficiary-run/chef-run business
	foreach lvl in ben chef {
		if "$ph" == "bl" {
			gen bus2_months_`lvl' = bus2_months if `lvl'_ownmanager == 1 // business level	
			byso hhid : egen tot_busmths_uniq_`lvl' = total(bus2_months_`lvl')	
			assert tot_busmths_uniq_`lvl' != .	
			replace tot_busmths_uniq_`lvl' = min(tot_busmths_uniq_`lvl', 12)		
		}	
		else if "$ph" == "fu" {	
			gen busmths_uniq_`lvl' = busmths_uniq if `lvl'_ownmanager == 1 // business level
			gen tot_busmths_uniq_`lvl' = busmths_uniq_`lvl'
			replace tot_busmths_uniq_`lvl' = 0 if tot_busmths_uniq_`lvl' == .
			byso hhid (tot_busmths_uniq_`lvl') : replace tot_busmths_uniq_`lvl' = tot_busmths_uniq_`lvl'[_N]
		}	
	}
	
	// redo business diversification to get beneficiary businesses only
	* grouped enterprise variables (required in survey)
	gen bus_5acts = 1 if inlist(activity_type, 6, 7) // trans serv 
	replace bus_5acts = 2 if inlist(activity_type, 1, 2, 4, 8) // food tailoring commerce and artisanship 
	replace bus_5acts = 3 if inlist(activity_type, 3) // construction
	replace bus_5acts = 4 if inlist(activity_type, 5) // professions
	replace bus_5acts = 5 if inlist(activity_type, 9) // other

	** div_n_na_12_hh
	byso hhid bus_5acts : gen div_n_na_12_hh = _n == 1
	byso hhid : replace div_n_na_12_hh = sum(div_n_na_12_hh)
	byso hhid : replace div_n_na_12_hh = div_n_na_12_hh[_N]
	
	** div_n_na_12_ben & div_n_na_12_chef
	foreach lvl in ben chef {
		gen bus_5acts_`lvl' = bus_5acts if `lvl'_ownmanager == 1
		byso hhid bus_5acts_`lvl' : gen div_n_na_12_`lvl' = _n == 1
		replace div_n_na_12_`lvl' = . if `lvl'_ownmanager != 1
		byso hhid : replace div_n_na_12_`lvl' = sum(div_n_na_12_`lvl')
		byso hhid : replace div_n_na_12_`lvl' = div_n_na_12_`lvl'[_N]
	}

	** business assets
	// fix negative, 888 and 999 responses to continuous, positive variables
	fix_continuous bus2_assval 
	assert bus2_assval >= 0 | missing(bus2_assval)
	if "$ph" == "fu" fix_continuous bus2_assval12 
	if "$ph" == "fu" assert bus2_assval12 >= 0 | missing(bus2_assval12)

	foreach pp in 95 98 99 {
		** all HH businesses
		gen bus2_assval_win`pp' = bus2_assval 
		_pctile bus2_assval, p(`pp') 
		replace bus2_assval_win`pp' = `r(r1)' if bus2_assval >`r(r1)'  & !missing(bus2_assval)
		bysort hhid : egen bus_assval_`pp' = total(bus2_assval_win`pp')
		label var bus_assval_`pp' "B.5.3 Direct business asset value, wins. at `pp'p"
		
		** benef/chef businesses only
		foreach lvl in ben chef {
			gen bus2_assval_win`pp'_`lvl' = bus2_assval_win`pp' if `lvl'_ownmanager == 1
			bysort hhid : egen bus_assval_`pp'_`lvl' = total(bus2_assval_win`pp'_`lvl')
			label var bus_assval_`pp'_`lvl' "B.5.3 Direct business asset value (`lvl'), wins. at `pp'p"
		}
		
		// value 12 months ago
		if "$ph" == "fu" {
			gen bus2_assval12_win`pp' = bus2_assval12 
			_pctile bus2_assval12, p(`pp') 
			replace bus2_assval12_win`pp' = `r(r1)' if bus2_assval12 >`r(r1)' & !missing(bus2_assval12)
			
			bysort hhid : egen bus_assval12_`pp' = total(bus2_assval12_win`pp')
			label var bus_assval12_`pp' "B.5.3 Direct business asset value 12 months ago, wins. at `pp'p"
			
			** benef/chef businesses only
			foreach lvl in ben chef {
				gen bus2_assval12_win`pp'_`lvl' = bus2_assval12_win`pp' if `lvl'_ownmanager == 1
				bysort hhid : egen bus_assval12_`pp'_`lvl' = total(bus2_assval12_win`pp'_`lvl')
				label var bus_assval12_`pp'_`lvl' "B.5.3 Direct business asset value 12 months ago (`lvl'ef), wins. at `pp'p"
			}
		}
		
		// scale up
		foreach var of varlist bus_assval_`pp' bus_assval_`pp'_ben {
			replace `var' = `var' / 1000
			local this_lab : variable label `var'
			label var `var' "(1000 FCFA) `this_lab'"
		}
	}
	
	if "$ph" == "fu" local fu_extra bus_assval12_98_chef bus_assval12_98_chef ///
								    bus_assval12_98_ben bus_assval12_98_ben
									
	local keeporder_hh tot_ben_rev30* tot_ben_pro30* 			///
					   tot_ben_rev12* tot_ben_pro12* 			/// 
					   tot_chef_rev30* tot_chef_pro30* 			///
					   tot_chef_rev12* tot_chef_pro12* 			///
					   tot_hh_rev30*  tot_hh_pro30* 			///
					   tot_hh_rev12*  tot_hh_pro12* 			///
					   tot_busmths_uniq 	 div_n_na_12_hh		///
					   tot_busmths_uniq_ben  div_n_na_12_ben	///
					   tot_busmths_uniq_chef div_n_na_12_chef	///
					   bus_assval_98 	  bus_assval_95 		///
					   bus_assval_98_ben  bus_assval_95_ben 	///
					   bus_assval_98_chef bus_assval_95_chef 	///
					   tot_bus2_ppl_uniq `fu_extra'

	// by default we don't have all hhs at FU because we drop households without businesses
	// replace with zeros later after merging in with all other datasets
preserve
	keep hhid `keeporder_hh'
	duplicates drop 
	isid hhid 

	tempfile bus2_outcomes
	save `bus2_outcomes'
restore


*************************************************************************************
*** Secondary B.8.1 Count of household non-agricultural business in last 12 months 
*************************************************************************************

// bring in: submissiondate list_chef consent
merge m:1 hhid using "${intermediate_${phase}}/chad_main_${phase_yr}.dta", ///
	keepusing (submissiondate list_chef consent) gen(_mdate)
drop if _mdate == 2 // HHs not in non-ag dataset
assert consent == 1
sort hhid bus2_pos 

// this dataset describes HH non-ag activities that were operational over the last 12 months
// bus2_mos12 captures months in which business was active in last 12 months
// count no. of na bus in operation within last 12 months
byso hhid : egen na_bus2_op_wn_12 = count(bus2_pos)
label var na_bus2_op_wn_12 "B.8.1 (1) no. of HH NA bus in operation within last 12 months at ${phase}" 

// count no. of na bus in operation within last 12 months owned/mngd by beneficiary/chef
foreach lvl in ben chef {
	gen bus2_pos_`lvl' = bus2_pos if `lvl'_ownmanager 
	byso hhid : egen na_bus2_op_wn_12_`lvl' = count(bus2_pos_`lvl')
	label var na_bus2_op_wn_12_`lvl' "B.8.2 (1) no. of `lvl' NA bus in operation within last 12 months at ${phase}" 	
}

// count no. of jointly managed bus within last 12 months 
gen bus2_pos_joint = bus2_pos if ben_ownmanager & chef_ownmanager
byso hhid : egen na_bus2_op_wn_12_joint = count(bus2_pos_joint)
label var na_bus2_op_wn_12_joint "B.8.2 (1) no. of chef and ben NA bus in operation within last 12 months at ${phase}" 	

gen na_bus2_op_wn_12_joint_s = na_bus2_op_wn_12_joint / na_bus2_op_wn_12
label var na_bus2_op_wn_12_joint_s "B.8.2 (1) share jointly managed/owned chef and ben NA bus in operation within last 12 months at ${phase}" 	


********************************************************************************
*** Secondary B.8.2 Whether household has any non-agricultural business
********************************************************************************

** 1 year
	// dummy for having any na bus in operation within last 12 months
	assert bus2_active != . & bus2_years != .
	gen bus2_dum = 1 // all HHs in this dataset run a non-ag business of some sort.
					 // FU1: HHs listed in act_n in main.dta miss 5 HHs mentioned here.
	label var bus2_dum "B.8.1 (2) HH has any na bus in operation within last 12 months at ${phase}"

	// dummy for having any na bus in operation within last 12 months
	// only for businesses owned/managed by beneficiary/chef 
	foreach lvl in ben chef {
		byso hhid : egen bus2_`lvl'_dum = max(`lvl'_ownmanager) 
		label var bus2_`lvl'_dum "B.8.2 (2) `lvl'EF has any na bus in operation within last 12 months at ${phase}"
	} 

** 1 month
	gen bus2_dum30_temp = bus2_active == 1 // full dummy w. no missings
	assert bus2_months > 0 | !missing(bus2_months) if bus2_dum30_temp == 1 // bus2_months generated at FU
	byso hhid : egen bus2_dum30 = max(bus2_dum30_temp) 
	label var bus2_dum30 "HH has any na bus in operation within last 1 month at ${phase}"
	drop bus2_dum30_temp
	
	foreach lvl in ben chef {
		gen bus2_30_`lvl' = bus2_dum30 == 1 & `lvl'_ownmanager == 1
		byso hhid : egen bus2_`lvl'_dum30 = max(bus2_30_`lvl') 
		label var bus2_`lvl'_dum30 "`lvl' has any na bus in operation within last 1 month at ${phase}"
		drop bus2_30_`lvl'

		// B.8.2 by activity type (`lvl''s business extensive margins)
		levelsof activity_type, local(types)
		foreach type in `types' {
			gen bus1_`lvl'_`type' = 1 if activity_type == `type' & `lvl'_ownmanager == 1
			replace bus1_`lvl'_`type' = 0 if missing(bus1_`lvl'_`type')
			
			byso hhid : egen bus1_`lvl'_`type'_d = max(bus1_`lvl'_`type')
			label var bus1_`lvl'_`type'_d "B.8.2 (2) `lvl' has type `type' bus in operation within last 12 months"
		}
	}
	
	
********************************************************************************
*** Secondary B.8.3 HH started a business within the last 12 months
********************************************************************************

fix_continuous bus2_years
tab bus2_years, m
// some years assumed sticky fingers (following approach in survey corrections)
if "$ph" == "bl" replace bus2_years = 50 if bus2_years > 50	
if "$ph" == "fu" replace bus2_years = 100 if bus2_years >100

// sanity check on years
assert bus2_years <= 100 | missing(bus2_years) // assume 100-year cutoff for reasonable tenure


********************************************************************************
**** Secondary B.8.4 Abandoned a non-agricultural activity in last 24 months
********************************************************************************

if "$ph" == "fu" {
	order bus2_abandon, after(bus2_years)

	// dummy capturing whether a HH abandoned a na business
	byso hhid : egen bus2_abandon_24_dum = max(bus2_abandon) // generate dummy. ignores missing values
	order bus2_abandon_24_dum, after (bus2_abandon)
	label var bus2_abandon_24_dum "B.8.1 (4) whether HH abandoned NA business in last 24 months at ${phase}"
	
	// sum abandoned businesses only by beneficiary/chef in household
	foreach lvl in ben chef {
		gen bus2_abandon_`lvl' = bus2_abandon
		replace bus2_abandon_`lvl' = 0 if `lvl'_ownmanager == 0
		byso hhid : egen bus2_abandon_24_dum_`lvl' = max(bus2_abandon_`lvl') // generate dummy
		label var bus2_abandon_24_dum_`lvl' "B.8.2 (4) whether `lvl' abandoned NA business in last 24 months at ${phase}"

		order bus2_abandon_`lvl', after(bus2_abandon_24_dum)
		order bus2_abandon_24_dum_`lvl', after (bus2_abandon_`lvl')
	}
}

if "$ph" == "fu" local fu_extra bus2_abandon_24_dum bus2_abandon_24_dum_ben	 ///
													bus2_abandon_24_dum_chef

local keeporder_B81_B84 na_bus2_op_wn_12 bus2_dum bus2_dum30			///
						na_bus2_op_wn_12_ben na_bus2_op_wn_12_chef		///
						bus2_ben_dum bus2_ben_dum30 bus1_ben_*_d 		///
						bus2_chef_dum bus2_chef_dum30 bus1_chef_*_d 	///
						na_bus2_op_wn_12_joint na_bus2_op_wn_12_joint_s `fu_extra'
							
preserve
	keep hhid `keeporder_B81_B84'
	order hhid `keeporder_B81_B84'
	duplicates drop
	isid hhid 

	tempfile bus1_outcomes_B81_B84
	save 	`bus1_outcomes_B81_B84'
restore


********************************************************************************
**** Secondary B.8.5 Total investments in non-agricultural businesses, beneficiary
********************************************************************************

** recode bus2_cap_o
gen bus2_cap_recode = bus2_cap, after(bus2_cap)
label val bus2_cap_recode  bus2_cap

if "$ph" == "bl" {
	replace bus2_cap_recode = 10 if regexm(bus2_cap_o, "parent") & regexm(bus2_cap_o, "heriter")
	
	// list "other" responses
	list bus2_cap_o

	foreach list in `r(resp_list)' {
		local i = subinstr("`list'", "responses_", "", .) // keep list number
		dis "i = `i'"
		foreach item in `r(`list')' {
			replace bus2_cap_recode = `i' if bus2_cap_o == `"`item'"'
		}
	}
	sort bus2_cap bus2_cap_o

	****** Sources 

	tab bus2_cap_recode, gen(source) 

	forvalues i = 1/10 { 
		bysort hhid : egen has_source`i' = max(source`i') 
	} 
	recode has_source* (.=0) 

	rename  has_source1 b_src_sav 
	label var b_src_sav	"Start-up financed through savings"
	rename  has_source2 b_src_gift 
	label var b_src_gift "Start-up financed through  a gift"
	rename  has_source3 b_src_inf
	label var b_src_inf	"Start-up financed through an informal loan"
	rename  has_source4 b_src_ton
	label var b_src_ton	"Start-up financed through a tontine"
	rename  has_source5 b_src_for
	label var b_src_for	"Start-up financed through a formal loan"
	rename  has_source6 b_src_ngo
	label var b_src_ngo	"Start-up financed through an NGO"
	rename  has_source7 b_src_net
	label var b_src_net	"Start-up finaced through safety net"
	rename  has_source8 b_src_inc
	label var b_src_inc	"Start-up self-financed"
	rename  has_source10 b_src_inh
	label var b_src_inh	"Start-up financed through inheritance"
	rename  has_source9 b_src_non
	label var b_src_non	"Start-up did not require financing"

	gen src_o = 0 
	replace src_o = 1 if bus2_cap_recode == -777
	bysort hhid: egen b_src_o = max(src_o)
	label var b_src_o "Start up financed through other means"

	local keeporder_invest b_src_sav b_src_gift b_src_inf b_src_ton b_src_for 	///
						   b_src_ngo b_src_net b_src_inc b_src_inh b_src_non  
}
else if "$ph" == "fu"{
	// winsorize investments
	foreach pp in 95 98 99 {
		foreach var of varlist put_total_12mos { 
			_pctile `var' , p(`pp')
			gen `var'_w_`pp' = `var' 
			replace `var'_w_`pp'  = `r(r1)' if !missing(`var'_w_`pp') & `var'_w_`pp'  > `r(r1)'
			replace `var'_w_`pp' = `var'_w_`pp' / 1000
		}
	
		// hh level investments
		byso hhid : egen bus2_invest_`pp' = total(put_total_12mos_w_`pp')        // sum puts in benef bus only
		label var bus2_invest_`pp' "B.8.1 (5) hh business investments last 12 months `pp' wins. at ${phase} (1000 FCFA)"
	} 
	
	// investment from BT and tontines separately 
	byso hhid: egen bus2_invest_bt = total(put_6)
	byso hhid: egen bus2_invest_tontines = total(put_7)
	local keeporder_invest bus2_invest* bus2_invest_bt bus2_invest_tontines // bus2_invest_ben 	
}
	
preserve
	keep hhid `keeporder_invest'
	duplicates drop 
	isid hhid 

	tempfile bus1_outcomes_invest
	save 	`bus1_outcomes_invest'
restore


********************************************************************************
**** Secondary B.8.6 Estimated business profits, household level 
********************************************************************************

if "$ph" == "fu"{	
	// winsorize
	foreach var of varlist bus_most_xof bus_least_xof { 
		_pctile `var' , p(98)
		gen `var'_w = `var' 
		replace `var'_w  = `r(r1)' if !missing(`var'_w ) & `var'_w  > `r(r1)'
	}

	// calculate average profits (highest + lowest)/2
	egen month_average_xof = rowmean(bus_most_xof_w bus_least_xof_w)

	// Calculate estimated business profits, household level
	gen bus2_pro_active_mnths = bus2_months * month_average_xof
	
	// scale to exclude share for non-HH member
	replace bus2_pro_active_mnths = bus2_pro_active_mnths * n_ownman / n_ownman_original
	
	capture confirm var amt_curr
	if _rc == 0 { // if currency var exists 
		foreach var of varlist bus2_pro_active_mnths bus_most_xof_w bus_least_xof_w {
			scale_cur `var' amt_curr 
		}
	}
	
	// sum monthly low profits at HH level
	byso hhid : egen tot_bus_least = total(bus_least_xof_w)
	replace tot_bus_least = tot_bus_least / 1000
	label var tot_bus_least "estimated HH lowest monthly profits (1000 FCFA)"
	
	byso hhid : egen tot_bus_most = total(bus_most_xof_w)
	replace tot_bus_most = tot_bus_most / 1000
	label var tot_bus_most "estimated HH hightest monthly profits (1000 FCFA)"
	
	// sum estimated profits at HH level
	byso hhid : egen bus2_profits_hh_xof = total(bus2_pro_active_mnths) 
	replace bus2_profits_hh_xof = bus2_profits_hh_xof / 1000
	label var bus2_profits_hh_xof "B.8.1 (8) estimated HH business profits at ${phase} (1000 FCFA)"

	// repeat for beneficiary-owned only
	gen bus2_pro_active_mnths_ben = bus2_pro_active_mnths
	replace bus2_pro_active_mnths_ben = 0 if ben_ownmanager == 0
	
	byso hhid : egen bus2_profits_hh_xof_ben = total(bus2_pro_active_mnths_ben) // sum profits at HH level
	replace bus2_profits_hh_xof_ben = bus2_profits_hh_xof_ben / 1000
	label var bus2_profits_hh_xof_ben "B.8.2 (8) estimated benef business profits at ${phase} (1000 FCFA)"

	local keeporder_estim tot_bus_least tot_bus_most bus2_profits_hh_xof bus2_profits_hh_xof_ben
}

preserve
	keep hhid `keeporder_estim'
	duplicates drop
	isid hhid

	tempfile bus1_outcomes_estim
	save 	`bus1_outcomes_estim'
restore


********************************************************************************
**** New vars in FU -- Business costs 
********************************************************************************
// conditional on active business where benef is owner, manager, or worker.


********************************************************************************
**** New vars in FU -- New vs old business sectors, revenues, and investment 
********************************************************************************
// Hypothesis: In SEN, stark diffs b/n new and old companies
// within_12 this is sufficient b/c the cash grants were just over 12 months prior to survey

if "$ph" == "fu"{	
	// get dummies by activity type (sector)
	tab activity_type, gen(act_) // activity dummies

	// new bus's are esp. likely to enter commerce and food processing 
	// count types of business in per household in old businesses only and compare with old+new

	by hhid activity_type, sort: gen nvals = _n == 1
	byso hhid : egen bus2_divrse = total(nvals)
	byso hhid : egen acts = count(bus2_pos)
	byso hhid activity_type : egen others = count(activity_type) if activity_type == 9
	byso hhid (others) : replace others = others[1]
	replace bus2_divrse = bus2_divrse + others - 1 if others != . // consider others unique
	label var bus2_divrse "Number of different bus types per HH"

	// br hhid activity_type activity nvals bus2_divrse acts others 
	// some HHs list "menage" as in whatever business the nth housewife runs

	preserve
		local abandon bus2_abandon_24_dum
		if "$ph" == "bl" local abandon 
		keep hhid  `abandon' bus2_divrse tot_hh_pro12_98 tot_hh_rev12_98
		duplicates drop
		isid hhid
	restore

	preserve
		keep hhid bus2_divrse
		duplicates drop
		isid hhid
		
		tempfile bus_divrse
		save 	`bus_divrse'
	restore	
}


********************************************************************************
**** Outworkers
********************************************************************************

if "$ph" == "fu" {		
	// gen dummy for employing outworkers
	gen has_bus_empl = bus2_outworkers > 0 & !missing(bus2_outworkers)
	label variable has_bus_empl "Has employees in non-farm activity"
	byso hhid : egen hh_has_bus_empl = max(has_bus_empl)

	preserve
		keep hhid hh_has_bus_empl
		duplicates drop
		isid hhid
		// empty file
		
		tempfile bus2_workers
		save 	`bus2_workers'
	restore	
}


********************************************************************************
**** Secondary 
********************************************************************************

/* 
	- Business competition
	- Business closure
	- Main Source of Funds
	- Business Future Outlook
	- Input Source
	- Place where Business Output is Sold
*/
if "$ph" == "fu" {
	use `secondary', clear 
	 
	preserve 
		keep if ben_ownmanager == 1
		tempfile secondary_ben
		save 	`secondary_ben'
	restore 
	 
	preserve 
		keep if chef_ownmanager == 1
		tempfile secondary_chef
		save 	`secondary_chef'
	restore 
	
	foreach lev in hh chef ben {
		if "`lev'" == "hh" 	    local level hh
		if "`lev'" == "ben" 	local level benef 
		if "`lev'" == "chef" 	local level chef 
		
		if "`lev'" != "hh" use `secondary_`lev'', clear 
		
	* ------------------------ Business Competition  ------------------------- *	
		
		winsor2 bus_competition_n, replace cuts(0 98)
		replace bus2_outworkers = 30 if bus2_outworkers >30
		
		** business closure 
		gen business_closure = bus2_abandon

		** reason for business closure: 1 = non-rentable 
		gen closure_non_rentable = . 
		replace closure_non_rentable = 0 if business_closure == 1
		replace closure_non_rentable = 1 if bus2_abandon_why == 1 
		
		** reason for business closure: 2 = shock  
		gen closure_shock = . 
		replace closure_shock = 0 if business_closure == 1
		replace closure_shock = 1 if bus2_abandon_why == 2 

		** reason for business closure: 3 = lack of financing 
		gen closure_nofinance = . 
		replace closure_nofinance = 0 if business_closure == 1
		replace closure_nofinance = 1 if bus2_abandon_why == 3

		** reason for business closure: 4 = lack of clients
		gen closure_noclients = . 
		replace closure_noclients = 0 if business_closure == 1
		replace closure_noclients = 1 if bus2_abandon_why == 4 

		** reason for business closure: 5 = difficulties finding inputs 
		gen closure_noinputs = . 
		replace closure_noinputs = 0 if business_closure == 1
		replace closure_noinputs = 1 if bus2_abandon_why == 5 

		** reason for business closure: 8 = no time
		gen closure_notime = . 
		replace closure_notime = 0 if business_closure == 1
		replace closure_notime = 1 if bus2_abandon_why == 8 

		** reason for business closure: 11 = social pressure
		gen closure_pressure = . 
		replace closure_pressure = 0 if business_closure == 1
		replace closure_pressure = 1 if bus2_abandon_why == 11 

	* ----------------------------- Main Source of Funds --------------------- *	

		 ** create finance_resp variable 
		 gen finance_resp = 0
		 replace finance_resp = 1 if bus2_cap != . 
		 
		 ** savings 
		 gen finance_savings = . 
		 replace finance_savings = 0 if finance_resp == 1
		 replace finance_savings = 1 if bus2_cap == 1
		  
		  ** gift from parent
		 gen finance_gift = . 
		 replace finance_gift = 0 if finance_resp == 1
		 replace finance_gift = 1 if bus2_cap == 2
		 
		  ** loan
		 gen finance_loan = . 
		 replace finance_loan = 0 if finance_resp == 1
		 replace finance_loan = 1 if bus2_cap == 3
		 
		 ** cash transfers
		 gen finance_transfers = . 
		 replace finance_transfers = 0 if finance_resp == 1
		 replace finance_transfers = 1 if bus2_cap == 7

		** revenues from agr and livestock
		 gen finance_revenues = . 
		 replace finance_revenues = 0 if finance_resp == 1
		 replace finance_revenues = 1 if bus2_cap == 8
		 
		 ** loan from other household 
		 gen finance_other_hh = . 
		 replace finance_other_hh = 0 if finance_resp == 1
		 replace finance_other_hh = 1 if bus2_cap == 3
		 
		 ** tontine (caisse de femme)
		 gen finance_tontine = . 
		 replace finance_tontine = 0 if finance_resp == 1
		 replace finance_tontine = 1 if bus2_cap == 4
		 
	* ---------------------- Business Future Outlook ------------------------- *	
		
		** create future_resp variable 
		gen future_resp = 0
		replace future_resp = 1 if bus_future != . 
		 
		** future: invest and develop business 
		gen future_invest = . 
		replace future_invest = 0 if future_resp == 1
		replace future_invest = 1 if bus_future == 2 

		** future: not invest but continue business 
		gen future_continue = . 
		replace future_continue = 0 if future_resp == 1
		replace future_continue = 1 if bus_future == 1 

		** future: stop activity 
		gen future_stop = . 
		replace future_stop = 0 if future_resp == 1
		replace future_stop = 1 if bus_future == 0 

	* -------------------------------- Input Source -------------------------- *	
		 
		** create input_resp variable 
		gen input_resp = 0
		replace input_resp = 1 if bus_input_source != .
		 
		** village market 
		gen input_village_market = . 
		replace input_village_market = 0 if input_resp == 1
		replace input_village_market = 1 if bus_input_source == 5
		
		** regional market 
		gen input_regional_market = . 
		replace input_regional_market = 0 if input_resp == 1
		replace input_regional_market = 1 if bus_input_source == 6 

		** supplier inside village
		gen input_supplier_inside = . 
		replace input_supplier_inside = 0 if input_resp == 1
		replace input_supplier_inside = 1 if bus_input_source == 2 | bus_input_source == 7 
		
		** supplier outside village
		gen input_supplier_outside = . 
		replace input_supplier_outside = 0 if input_resp == 1
		replace input_supplier_outside = 1 if bus_input_source == 3 | bus_input_source == 4
		   
	* ------------------ Place where Business Output is Sold ----------------- *	
		 
		gen output_resp = 0
		replace output_resp = 1 if place_sell != . 

		** village market  
		gen output_village_market = . 
		replace output_village_market = 0 if output_resp == 1
		replace output_village_market = 1 if place_sell == 3 
		 
		** regional market   
		gen output_regional_market = . 
		replace output_regional_market = 0 if output_resp == 1
		replace output_regional_market = 1 if place_sell == 4 
		 
		** merchant inside village 
		gen output_merchant_inside = . 
		replace output_merchant_inside = 0 if output_resp == 1
		replace output_merchant_inside = 1 if place_sell == 1 | place_sell == 5 
		 
		** merchant outside village  
		gen output_merchant_outside = . 
		replace output_merchant_outside = 0 if output_resp == 1
		replace output_merchant_outside = 1 if place_sell == 2 | place_sell == 6 
			
		*--------------------- TOTALS AND FINAL DATASET -----------------------*		

		local `level'_business_vars bus2_outworkers business_closure closure_* /// 
			   bus_competition_n finance_* future_* input_* output_*
			   
		keep hhid bus2_pos ``level'_business_vars'
		drop input_source_could
		 
		foreach v in 	bus2_outworkers bus_competition_n business_closure closure_non_rentable		///
						closure_shock closure_nofinance closure_noclients closure_noinputs			///
						closure_notime closure_pressure finance_resp finance_savings 				///
						finance_gift finance_loan finance_transfers finance_revenues 				///
						finance_tontine finance_other_hh future_resp future_invest 					///
						future_continue future_stop input_resp input_village_market 				///
						input_regional_market input_supplier_outside input_supplier_inside 			///
						output_resp output_village_market output_regional_market  					///
						output_merchant_inside output_merchant_outside {
			rename `v' `v'_t
			byso hhid : egen `v' = total(`v'_t)
			drop `v'_t	
		}
		
		foreach v in 	business_closure closure_non_rentable closure_shock closure_nofinance 		///
						closure_noclients closure_noinputs closure_notime closure_pressure 			///
						finance_resp finance_savings finance_gift finance_loan finance_transfers 	///
						finance_revenues finance_tontine finance_other_hh future_resp future_invest ///
						future_continue future_stop input_resp input_village_market 				///
						input_regional_market input_supplier_outside input_supplier_inside 			///
						output_resp output_village_market output_regional_market  					///
						output_merchant_inside output_merchant_outside {
			replace `v' = 1 if `v' >= 1
		}
		duplicates drop hhid, force
		
		** insert true zeros
		foreach v in closure_non_rentable closure_shock closure_nofinance closure_noclients 		///
					 closure_noinputs closure_notime closure_pressure finance_savings 				///
					 finance_gift finance_loan finance_transfers finance_revenues 					///
					 finance_tontine finance_other_hh {
			replace  `v' = 0 if business_closure == 0
		}

		* adding ben/chef suffix to each variable to differentiate: 
		foreach v in 	bus2_outworkers bus_competition_n business_closure closure_non_rentable 	///
						closure_shock closure_nofinance closure_noclients closure_noinputs 			///
						closure_notime closure_pressure finance_resp finance_savings finance_gift 	///
						finance_loan finance_transfers finance_revenues finance_tontine 			///
						finance_other_hh future_resp future_invest future_continue future_stop 		///
						input_resp input_village_market input_regional_market 						///
						input_supplier_outside input_supplier_inside output_resp 					///
						output_village_market output_regional_market output_merchant_inside 		///
						output_merchant_outside {
			rename `v' `v'_`lev'
		}
		
	drop bus2_pos
	tempfile bus1_outcomes_secondary_`lev'
	save	`bus1_outcomes_secondary_`lev''
	}
}


********************************************************************************
*** Bring it all together
********************************************************************************

use 				 `bus1_outcomes', clear // extensive margins (full sample)
merge 1:1 hhid using `bus2_outcomes', gen(_mBus2) // intensive margins (pro, rev: only households w/ businesses)
merge 1:1 hhid using `bus1_outcomes_B81_B84', gen(_mBus_B81_84)
merge 1:1 hhid using `bus1_outcomes_invest', gen(_mBus_invest)
merge 1:1 hhid using `bus1_outcomes_estim', gen(_mBus_estim)
if "$ph" == "fu" merge 1:1 hhid using `bus_divrse', gen(_mBus_divrse)
if "$ph" == "fu" cap merge 1:1 hhid using `bus2_workers', gen(_mBus_workers)

if "$ph" == "fu" { // Secondary
	merge 1:1 hhid using `bus1_outcomes_secondary_hh', gen(_mHh)
	merge 1:1 hhid using `bus1_outcomes_secondary_chef', gen(_mChef)
	merge 1:1 hhid using `bus1_outcomes_secondary_ben', gen(_mBen)	
	
	assert _mHh   != 2
	assert _mChef != 2 
	assert _mBen  != 2 
	
	// replace missing true missing values with 0s 
	foreach var_data of varlist _mHh _mChef _mBen {
		if "`var_data'" == "_mHh" 		local lev "hh"
		if "`var_data'" == "_mChef" 	local lev "chef"
		if "`var_data'" == "_mBen" 		local lev "ben"
		
		foreach var of varlist  bus2_outworkers_`lev' - output_merchant_outside_`lev' { 
			replace `var' = 0 if `var' == . & `var_data' == 1 
		} 		
	}
	drop _mHh _mChef _mBen	
}


********************************************************************************
*** a few extras
********************************************************************************

	// b2 extra: HH profits per adult equivalent
	merge 1:1 hhid using "${constructed_${phase}}/demographics.dta", keepusing(equiv_n) gen(_madult)
	
	foreach pp in 95 98 99 {
		gen tot_hh_pro30_actual_`pp' = tot_hh_pro30_`pp' * 1000 // monthly profit in FCFA
		gen tot_hh_pro_day_eq_`pp' = tot_hh_pro30_actual_`pp' / 30 / equiv_n // daily profit per adult equivalent
		replace tot_hh_pro_day_eq_`pp' = 0 if tot_hh_pro_day_eq_`pp' == .
		label var tot_hh_pro_day_eq_`pp' "B.2.1 (1) HH bus pro `pp' winsorized, (daily FCFA/adult eq.)"

		foreach term in 12 30 {
			if `term' == 30 local unit day 	 // 30 day
			if `term' == 12 local unit month // 12 month
		
			foreach type in pro rev {
				gen tot_hhlb_`type'`term'_`pp' = tot_hh_`type'`term'_`pp' - tot_ben_`type'`term'_`pp' // hh less ben
				label var tot_hhlb_`type'`term'_`pp' "Business `type' `pp' winsorized, household less benef, `term'-`unit' term (1000 FCFA)"

				gen tot_bohh_`type'`term'_`pp' = tot_ben_`type'`term'_`pp' / tot_hh_`type'`term'_`pp' // ben over hh
				label var tot_bohh_`type'`term'_`pp' "Business `type' winsorized, `term'-`unit' term, fraction: benef/household"
			}
		}
	}
	
	
	
********************************************************************************
*** insert true zeros
********************************************************************************

if "$ph" == "bl" {
	local bus_vars 	na_bus2_op_wn_12 	  bus2_dum 		bus2_dum30  	   		///
					na_bus2_op_wn_12_ben  bus2_ben_dum 	bus2_ben_dum30     		///	
					na_bus2_op_wn_12_chef bus2_chef_dum bus2_chef_dum30     	///	
					tot_busmths_uniq tot_bus2_ppl_uniq 							///	
					tot_busmths_uniq_ben tot_busmths_uniq_chef					///	
					div_n_na_12_hh bus_assval_98 bus_assval_95 					///	
					bus_assval_98_ben bus_assval_95_ben div_n_na_12_ben			///
					bus_assval_98_chef bus_assval_95_chef div_n_na_12_chef		///
					na_bus2_op_wn_12_joint na_bus2_op_wn_12_joint_s
}
else if "$ph" == "fu" {
	local bus_vars 	na_bus2_op_wn_12 	  bus2_dum 		bus2_dum30  	   		///
					na_bus2_op_wn_12_ben  bus2_ben_dum 	bus2_ben_dum30     		///	
					na_bus2_op_wn_12_chef bus2_chef_dum bus2_chef_dum30     	///	
					tot_busmths_uniq tot_bus2_ppl_uniq 							///	
					tot_busmths_uniq_ben tot_busmths_uniq_chef					///	
					div_n_na_12_hh bus_assval_98 bus_assval_95 					///	
					bus_assval_98_ben bus_assval_95_ben div_n_na_12_ben			///
					bus_assval_98_chef bus_assval_95_chef div_n_na_12_chef		///
					bus2_abandon_24_dum bus2_invest_bt bus2_invest_tontines		///
					bus2_profits_hh_xof bus2_profits_hh_xof_ben					///
					bus2_abandon_24_dum_ben bus2_abandon_24_dum_chef			///
					bus2_invest_bt bus2_invest_tontines tot_bus_least 			///
					tot_bus_most bus2_divrse hh_has_bus_empl 					///
					na_bus2_op_wn_12_joint na_bus2_op_wn_12_joint_s
}			   

ds bus1_ben_*_d
local benef_dum_bytype `r(varlist)' // benef ext mgns			   

* winsorized vars
if "$ph" == "fu" local fu_wins "bus2_invest*"
	ds 	tot_hhlb_rev12* tot_hhlb_rev30* ///
		tot_hhlb_pro12* tot_hhlb_pro30* /// 
		tot_ben_pro30*  tot_ben_rev30* 	///
		tot_chef_pro30* tot_chef_rev30* ///
		tot_hh_pro30*   tot_hh_rev30*	/// 
		tot_ben_rev12*  tot_ben_pro12* 	/// 
		tot_chef_rev12* tot_chef_pro12* /// 
		tot_hh_rev12*   tot_hh_pro12* `fu_wins'	
local wins_vars `r(varlist)'

// insert true zeros
foreach var in `bus_vars' `wins_vars' `benef_dum_bytype'  {
		replace `var' = 0 if `var' == .
	
}


********************************************************************************
*** Create dummies for business activity types
********************************************************************************

if "$ph" == "fu" {
	preserve 
		use "${intermediate_${phase}}/chad_main_2021.dta", clear
		keep hhid bus1_food bus1_tail bus1_constr bus1_comm bus1_prof bus1_serv bus1_trans bus1_art bus1_extra
		
		egen activities_n = rowtotal(bus1_food bus1_tail bus1_constr bus1_comm bus1_prof bus1_serv bus1_trans bus1_art)

		foreach v in bus1_food bus1_tail bus1_constr bus1_comm bus1_prof bus1_serv bus1_trans bus1_art {
			replace `v' = 1 if `v' >= 1
		}

		egen activity_types_n = rowtotal(bus1_food bus1_tail bus1_constr bus1_comm bus1_prof bus1_serv bus1_trans bus1_art)
		
		tempfile business_activity_types
		save    `business_activity_types'
	restore 
	
	merge 1:1 hhid using  `business_activity_types', gen(_mActivity)
	assert _mActivity != 2 
	drop _mActivity
}

	isid hhid
	tempfile business 
	save 	`business'

	
********************************************************************************
*** ZINDEX - Beneficiaries
********************************************************************************

	merge 1:1 hhid using "${constructed_${phase}}/identification.dta", gen(mtreat)
	keep if mtreat == 3
	drop mtreat
	
   if "$ph" == "fu" local fu_extra bus2_invest_95
   foreach v in tot_ben_rev12_98 tot_ben_pro12_98 bus_assval_98_ben na_bus2_op_wn_12_ben `fu_extra' { 
		replace `v' = 0 if `v' == .
   }
   
	* standardizing each component of the index: 
	zindex na_bus2_op_wn_12_ben, gen(na_bus2_op_wn_12_ben_z) condition(pm_treatment == 0)
	zindex tot_ben_pro12_98, gen(tot_ben_pro12_98_z) condition(pm_treatment == 0)
   	zindex tot_ben_rev12_98, gen(tot_ben_rev12_98_z) condition(pm_treatment == 0)
	zindex bus_assval_98_ben, gen(bus_assval_98_ben_z) condition(pm_treatment == 0)
   	zindex tot_busmths_uniq_ben, gen(tot_busmths_uniq_ben_z) condition(pm_treatment == 0)
	if "$ph" == "fu" {
		zindex bus2_invest_95, gen(bus2_invest_95_z) condition(pm_treatment == 0)
		local keep_extra1 bus2_invest_95_z
	}
	
	** Creating indices with all or select variables: 
	
	* all variables
	local zindex_vars na_bus2_op_wn_12_ben tot_ben_pro12_98  tot_ben_rev12_98 bus_assval_98_ben tot_busmths_uniq_ben `fu_extra'
	zindex `zindex_vars', gen(business_index_ben) condition(pm_treatment == 0)
	
	* without assets & investments
	local zindex_vars na_bus2_op_wn_12_ben tot_ben_pro12_98  tot_ben_rev12_98  tot_busmths_uniq_ben
	zindex `zindex_vars', gen(business_index_ben4) condition(pm_treatment == 0)
	
	if "$ph" == "fu" {
	   * without investment 
		local zindex_vars na_bus2_op_wn_12_ben tot_ben_pro12_98  tot_ben_rev12_98 bus_assval_98_ben tot_busmths_uniq_ben
		zindex `zindex_vars', gen(business_index_ben3) condition(pm_treatment == 0)
		* without assets
		local zindex_vars na_bus2_op_wn_12_ben tot_ben_pro12_98  tot_ben_rev12_98 tot_busmths_uniq_ben `fu_extra'
		zindex `zindex_vars', gen(business_index_ben2) condition(pm_treatment == 0)
	
		local keep_extra2 business_index_ben2 business_index_ben3
	}
	
	preserve
		keep hhid na_bus2_op_wn_12_ben_z tot_ben_pro12_98_z tot_ben_rev12_98_z 	/// 
				  bus_assval_98_ben_z tot_busmths_uniq_ben_z 	`keep_extra1'  	///
				  business_index_ben business_index_ben4 		`keep_extra2'	
		tempfile business_zindex_ben
		save    `business_zindex_ben'
	restore

	
********************************************************************************
*** ZINDEX - Household
********************************************************************************

	if "$ph" == "fu" local fu_extra bus2_invest_98   
	foreach v in tot_hh_rev12_98 tot_hh_pro12_98 bus_assval_98 act_n tot_busmths_uniq `fu_extra' { 
		replace `v' = 0 if `v' == .
	}
   
	* standardizing each component of the index: 
   	zindex act_n, gen(na_bus2_op_wn_12_z) condition(pm_treatment == 0)
	zindex tot_ben_pro12_98, gen(tot_hh_pro12_98_z) condition(pm_treatment == 0)
   	zindex tot_ben_rev12_98, gen(tot_hh_rev12_98_z) condition(pm_treatment == 0)
	zindex bus_assval_98, gen(bus_assval_98_z) condition(pm_treatment == 0)
   	zindex tot_busmths_uniq_ben, gen(tot_busmths_uniq_z) condition(pm_treatment == 0)
	
	if "$ph" == "fu" {
		zindex bus2_invest_98, gen(bus2_invest_98_z) condition(pm_treatment == 0)
		local keep_extra1 bus2_invest_98_z
	}
	
	** Creating indices with all or select variables:
	
	* all variables  	
	local zindex_vars act_n tot_hh_pro12_98  tot_hh_rev12_98 bus_assval_98 tot_busmths_uniq `fu_extra'
	zindex `zindex_vars', gen(bus_activity_index) condition(pm_treatment == 0)
		
	* without asset 		
	local zindex_vars act_n tot_hh_pro12_98  tot_hh_rev12_98 tot_busmths_uniq `fu_extra'
	zindex `zindex_vars', gen(bus_activity_index2) condition(pm_treatment == 0)		

	if "$ph" == "fu" {
		* without investment 	
		local zindex_vars act_n tot_hh_pro12_98  tot_hh_rev12_98 bus_assval_98  tot_busmths_uniq
		zindex `zindex_vars', gen(bus_activity_index3) condition(pm_treatment == 0)
	   * without asset & investment
		local zindex_vars act_n tot_hh_pro12_98  tot_hh_rev12_98  tot_busmths_uniq
		zindex `zindex_vars', gen(bus_activity_index4) condition(pm_treatment == 0)
		
		local keep_extra2 bus_activity_index3 bus_activity_index4
	}
	
	preserve
	   keep hhid na_bus2_op_wn_12_z tot_hh_pro12_98_z tot_hh_rev12_98_z ///
			bus_assval_98_z tot_busmths_uniq_z     `keep_extra1' 		///
			bus_activity_index bus_activity_index2 `keep_extra2'
			tempfile business_zindex_hh
			save    `business_zindex_hh'
	restore 
	
	
********************************************************************************
*** ZINDEX - Household Head
********************************************************************************
	
	* standardizing each component of the index: 
   	zindex na_bus2_op_wn_12_chef, gen(na_bus2_op_wn_12_chef_z) condition(pm_treatment == 0)
	zindex tot_chef_pro12_98, gen(tot_chef_pro12_98_z) condition(pm_treatment == 0)
   	zindex tot_chef_rev12_98, gen(tot_chef_rev12_98_z) condition(pm_treatment == 0)
	zindex bus_assval_98_chef, gen(bus_assval_98_chef_z) condition(pm_treatment == 0)
   	zindex tot_busmths_uniq_chef, gen(tot_busmths_uniq_chef_z) condition(pm_treatment == 0)

	* Index without investment 	
	local zindex_vars na_bus2_op_wn_12_chef tot_chef_pro12_98  tot_chef_rev12_98 bus_assval_98_chef  tot_busmths_uniq_chef
	zindex `zindex_vars', gen(business_index_chef3) condition(pm_treatment == 0)

	* Index without asset & investment 	
	local zindex_vars na_bus2_op_wn_12_chef tot_chef_pro12_98  tot_chef_rev12_98  tot_busmths_uniq_chef
	zindex `zindex_vars', gen(business_index_chef4) condition(pm_treatment == 0)
	
	keep hhid 	na_bus2_op_wn_12_chef_z tot_chef_pro12_98_z tot_chef_rev12_98_z ///
				bus_assval_98_chef_z tot_busmths_uniq_chef_z  					///
				business_index_chef3 business_index_chef4
	tempfile business_zindex_chef
	save    `business_zindex_chef'
	
	use `business_zindex_hh', clear
	merge 1:1 hhid using `business_zindex_ben' , gen(_mBen) 
	merge 1:1 hhid using `business_zindex_chef', gen(_mChef) 
	assert _mBen  != 2
	assert _mChef != 2 
	drop _mBen _mChef
	
	isid hhid 
	tempfile business_zindex
	save 	`business_zindex'
	
	
********************************************************************************
*** Export 
********************************************************************************

use `business', clear 
merge 1:1 hhid using `business_zindex', gen(_mZindex)
assert _mZindex != 2 
drop _mZindex

isid hhid
compress 
save "${constructed_${phase}}/business", replace
