	***************************************************************************
	*																		  *
	*		    		CONSUMPTION CLEANING CHAD ASP IE 			 		  *
	*																		  *
	***************************************************************************
	
    /*
	** PURPOSE: 	Cleaning consumption
	
	** OUTLINE: 	1. Food consumption scores
					2. Nonfood consumption
					3. Education consumption
					4. Health consumption
					5. celebration consumption
					5. repair consumption
					5. eating out consumption
					5. Merge
					6. Save Dataset
    */
	 
	***************************************************************************

	****************************************************************************
	*------------------------ I. FOOD CONSUMPTION  ----------------------------*
	****************************************************************************

	/* Outline for food consumption
	0. Rename and label variables
	1. Define problem food types
	2. Recode missing values
	3. Standardize "specify other"
	4. Identify "problem" entries based on consumed but not purchased
	5. Identify "problem" entries based on IQR
	6. Identify "problem" entries based on Decomposition
	7. Create median unit prices
	8. Replace median unit prices to correct consumed unit
	9. Create food consumption importance dataset
	10. Compute food consumption quantities 
	*/
	
	local locations p_village p_canton p_sousprefecture p_region country
	use 		"${intermediate_${phase}}/foodconsumption_long", clear
	merge m:1 	 hhid using "${constructed_${phase}}/identification", keepus(consent `locations') gen(_mID)
	merge m:1 	hhid using "${constructed_${phase}}/demographics.dta", keepusing(mem_n equiv_n) 

	drop if consent != 1 & _merge == 2
	drop 		_merge consent
	order hhid `locations', first 
	
	* ------------------------------------------------------------------------ *
	* ------------------- 0. Rename and label variables ---------------------- *
	* ------------------------------------------------------------------------ *

	capture confirm var gp_consum_bot
	if _rc == 0 {
		rename gp_consum_bot consum_bot	// mistake in SurveyCTO variable name 
	}
	
	foreach var in consum_bot consum_prod consum_gift {
		capture confirm var `var'
		if _rc == 0 {
			rename `var' `var'_qty
		}
	}

	rename consum_u_bot_name consum_bot_u_name
	label values consum_bot_u consum_u
	order consum_bot_u_o consum_bot_u_name, after(consum_bot_u)

	* ------------------------------------------------------------------------ *
	* ------------------- 1. Define problem food types  ---------------------- *
	* ------------------------------------------------------------------------ *
	
	#delimit ;
	label 		define prob_food
	1 "undefined consumed quantity - don't know, refused" 
	2 "very unlikely/impossible consumed qty" 
	4 "undefined consumed unit"
	5 "unconvertible consumed unit";
	#delimit cr
	
	gen prob_food:prob_food  = 0
	
	* ------------------------------------------------------------------------ *
	* ------------------- 2. Recode missing values      ---------------------- *
	* ------------------------------------------------------------------------ *
	
	recode consum_qty consum_prod_qty consum_gift_qty consum_bot_qty consum_bot_val consum_in_bot ///
	(-777 = .o) (888 = .d) (999 = .r) (555 = .r) (1234 = .d) (9999 = .r)

	// remove 99999 and 88888 etc
	fix_continuous consum_qty consum_prod_qty consum_gift_qty consum_bot_qty consum_bot_val consum_in_bot

	* consum_in_bot cannot be 0 and consum_bot_qty should be missing if 0
	replace consum_bot_freq = .m if consum_bot_qty == 0
	replace consum_bot_u = .m if consum_bot_qty == 0
	
	* ------------------------------------------------------------------------ *
	* ------------ 3. Standardize "specify other" consumption units ---------- *
	* ------------ (consum_u, consum_bot_u), adjust consum_in_bot	---------- *
	* ------------------------------------------------------------------------ *
	
	/* We manually standardized the "specify other" units
	Original
	1 KG
	2 Litre
	3 Article/Unité
	4 Coro
	5 Sachet/sac
	6 Boite/paquet
	7 Dozoum
	8 Alvéole / plateau
	9 Louche
	10 Tas
	11 Verres
	*/
		
	*** Consumption units
	gen consum_u_recode:consum_u_extend = consum_u, after(consum_u)
	replace consum_u_o = trim(itrim(lower(consum_u_o))) // tolower() and trailing spaces removed

	*** Purchase units (bot)
	gen consum_bot_u_recode:consum_u_extend = consum_bot_u, after(consum_bot_u)
	replace consum_bot_u_o = trim(itrim(lower(consum_bot_u_o)))
		
	foreach unit_var in consum consum_bot consum_prod consum_gift {
		if "`unit_var'" != "consum_bot" local ope "*"
		else							local ope "/"
		
		if "`unit_var'" != "consum_bot" local u_var "consum_u_o"
		else							local u_var "consum_bot_u_o"
		
		// let's assume roubou = 0.5 coro
		replace `unit_var'_qty 	= `unit_var'_qty * 0.5 		if inlist(`u_var', "roubou", "robou", "demicoro", "demilitre")
		replace `unit_var'_qty 	= `unit_var'_qty * 1.5 		if inlist(`u_var', "unlitreetdemi")		
		replace `unit_var'_qty 	= `unit_var'_qty * 0.25 	if inlist(`u_var', "quardecorro", "quart")
		replace `unit_var'_qty 	= `unit_var'_qty * 2    	if inlist(`u_var', "deuxboitesdetarzanourobe")
		
		replace consum_in_bot 	= consum_in_bot `ope' 0.5 	if inlist(`u_var', "roubou", "robou", "demicoro", "demilitre")
		replace consum_in_bot 	= consum_in_bot `ope' 1.5 	if inlist(`u_var', "unlitreetdemi")		
		replace consum_in_bot 	= consum_in_bot `ope' 0.25 	if inlist(`u_var', "quardecorro", "quart")
		replace consum_in_bot 	= consum_in_bot `ope' 2    	if inlist(`u_var', "deuxboitesdetarzanourobe")		
	}
	
	foreach unit_var in consum_u consum_bot_u {				
		replace `unit_var'_recode = 11 if inlist(`unit_var'_o, "verre", "verres", "verron", "tasse")	
		replace `unit_var'_recode = 4  if inlist(`unit_var'_o, "roubou", "robou", "demicoro", "quardecorro", "quart")
		replace `unit_var'_recode = 2  if inlist(`unit_var'_o, "demilitre", "unlitreetdemi", "bouteilletarzan")
		replace `unit_var'_recode = 3  if inlist(`unit_var'_o, "mouton", "poulet", "tete", "gigot", "coq", "langua", "detail", "deuxboitesdetarzanourobe") | /// 
										  inlist(`unit_var'_o, "koundale", "koundiale", "tchimbele", "boule", "boules", "boullette" )
	}		
		
	* Fix consum_in_bot if other was chosen
	replace consum_in_bot = 1 if consum_u_recode == consum_bot_u_recode & consum_ate == 1

	* ------------------------------------------------------------------------ *
	* -----------  4. Identify "problem" entries based on consumed ----------- *
	* -----------  but not purchased units in data set - no value  ----------- *
	* ------------------------------------------------------------------------ *
	
	replace prob_food = 1 if consum_qty == .o | consum_qty == .r | consum_qty == .d   
	replace prob_food = 4 if consum_u_recode == .o | consum_u_recode == .r | consum_u_recode == .d
	replace consum_ate = 0 if missing(consum_ate) & missing(consum_u_recode)

	* ------------------------------------------------------------------------ *
	* -------------  5. Identify "problem" entries based on IQR  ------------- *
	* ------------------------------------------------------------------------ *
	
	*** Identify outliers as observations outside 10 IQR of p75 and p25 for unit of per capita consumption
	gen consum_qty_pc = consum_qty / mem_n
	byso consum_pos consum_u_recode : egen p75_qty_pc = pctile(consum_qty_pc) if !missing(consum_qty_pc) , p(75)
	byso consum_pos consum_u_recode : egen p25_qty_pc = pctile(consum_qty_pc) if !missing(consum_qty_pc), p(25)
	byso consum_pos consum_u_recode : egen iqr_qty_pc = iqr(consum_qty_pc) if !missing(consum_qty_pc) 
	
	*** set as prob_food = 2 if weird consumed quantity here
	replace prob_food = 2 if (consum_qty_pc > (p75_qty_pc + (10*iqr_qty_pc)) | ///
							  consum_qty_pc < (p25_qty_pc - (10*iqr_qty_pc))) & ///
							  !missing(consum_qty_pc)
						  
	// people report to eat and buy in different units but report same quantity 
	tab consum_bot_u_recode prob_food
	tab consum_u_recode prob_food 

	// see where most quantity outliers exist
	egen unitmismatch = group(consum_u_recode consum_bot_u_recode) if consum_u_recode != consum_bot_u_recode
	tab unitmismatch prob_food
	egen unitmatch = group(consum_u_recode consum_bot_u_recode) if consum_u_recode == consum_bot_u_recode
	tab unitmatch prob_food

	* ------------------------------------------------------------------------ *
	* --------  6. Identify "problem" entries based on Decomposition  -------- *
	* ------------------------------------------------------------------------ *
	
	/*
		Survey question is "among the quantity consumed, how much com from own production/gift"
		consumption = purchased + own production + gifted  
		(but we do not have purchased in last 7 days)	
	*/
	
	*** clean own-production quantity and gifted quantity 
	assert missing(consum_gift_qty) if missing(consum_qty)
	assert missing(consum_prod_qty) if missing(consum_qty)
	replace consum_gift_qty = 0 if consum_gift_qty == . & consum_qty != .
	replace consum_prod_qty = 0 if consum_prod_qty == . & consum_qty != .
	gen consum_prod_gift_tot = consum_prod_qty + consum_gift_qty
	
	*** set as prob_food = 3 if gifted + own production > consumption
	replace prob_food = 3 if (consum_qty < consum_prod_gift_tot) & !missing(consum_qty)
	assert prob_food != 3

	* share of gifted and ownprod and purchased quantity 
	foreach shr in prod gift {
		gen qty_`shr'_share = consum_`shr'_qty / consum_qty
	}
	gen qty_buy_share = 1 - (qty_prod_share + qty_gift_share)
	
	* ------------------------------------------------------------------------ *
	* --------------------  7. Create median unit prices  -------------------- *
	* ------------------------------------------------------------------------ *
	
	gen bot_unit_price = consum_bot_val / consum_bot_qty
	label variable bot_unit_price "purchased unit price"

	// Same unit consumed and bought and non missing units
	replace consum_in_bot = 1 if consum_u_recode == consum_bot_u_recode & !missing(consum_bot_u_recode)

	* Create median price units for each location
	foreach loc in `locations' {
		display "`loc'"
		byso `loc' consum_pos consum_bot_u_recode: egen bot_mp_`loc' = median(bot_unit_price)
		label var bot_mp_`loc' "median price of this purchased food/unit at `loc' level" 
	}

	* ------------------------------------------------------------------------ *
	* ---- 8. Replace median unit prices to correct consumed unit   ---------- *
	* ------------------------------------------------------------------------ *
	
	** where bot and consumed units are the same, assign bought median prices to ate prices
	foreach loc in `locations' {
		gen ate_mp_`loc' =  bot_mp_`loc' if consum_u_recode == consum_bot_u_recode 	
		label var ate_mp_`loc' "median price of this consum food/unit at `loc' level" 
	}

	** where bot & consumed units are different: consum_in_bot != 1 & where consum_in_bot == . (not purchased)
	foreach loc in `locations' {
		bysort `loc' consum_pos consum_u_recode  (ate_mp_`loc') : replace ate_mp_`loc' = ate_mp_`loc'[_n-1] if missing(ate_mp_`loc') 
	}

	* observations that are still missing the unit price
	gen missing_unit_price = missing(ate_mp_country) & consum_ate == 1
	tab consum_name missing_unit_price // if missing_unit_price 	
	
	*** Method 
	/***
		only use median prices when have to - try to get as much information from the survey as possible 
		If we have the purchase price of a food product, and consumption units are the 
		same as purchase units, then we use the purchase price to compute the consumption 
		value for each food product. If these units are different, we first rescale 
		purchased quantities using a reported conversion factor. Finally, if a product 
		was consumed but not purchased (i.e. we do not have its price), we use median 
		purchase prices. We then sum over products within the household.		
	***/ 

	sort hhid consum_pos
	gen eat_value = .
	
	* use each item's price (val/qty) -> first, if bot and conusme units are the same
	replace eat_value = consum_qty*consum_bot_val/consum_bot_qty if consum_u_recode == consum_bot_u_recode // same units 

	* if eat_value missing, but have a survey conversion (ie, not unit price in data set but have a conversion in survey for this unit
	replace eat_value = (consum_qty/consum_in_bot)*(consum_bot_val/consum_bot_qty) if eat_value == . & !missing(consum_in_bot) 

	* replace by median in progressively larger locality 
	foreach loc in `locations'  {
		qui gen savedvar = eat_value
		qui replace eat_value = consum_qty * ate_mp_`loc' if missing(eat_value)
		qui count if eat_value != savedvar 
		dis "`r(N)' values changed at `loc'."
		qui drop savedvar
	}	
	
	* ------------------------------------------------------------------------ *
	* -----------   9. Create food consumption importance dataset  ----------- *
	* ------------------------------------------------------------------------ *
	
	/*  establish "food importance" of each food type and use to address problem foods
	*	generate a temp value for weekly food consumption 
	*	get total value for household
	*	excluding households that have problem food, non-important foods are foods
	*	that are less than 10% of food consumption for 90% of households 
	*	if important & problem -> set to missing and total food consumption will also be missing 
	*	if unimportant & problem -> set to 0 
	*/
	
	replace prob_food = 5 if eat_value == . & consum_ate == 1
	tab prob_food // 21

	** set problem foods to missing for now, will decide whether 0 or missing based on next step
	sort hhid consum_pos
	replace eat_value = .p if prob_food != 0
	
	// generate hh-dummy for problem foods -> don't include households with prob_foods in calculations
	byso hhid : egen has_prob = total(prob_food)
	replace has_prob = 1 if has_prob >= 1 & !missing(has_prob)

	// previous command is: recode eat_value (. = 0) but this leaves eat_value = .p if minor problem food
	recode eat_value (. = 0)

	byso hhid : egen total_value = total(eat_value)
	gen share = eat_value / total_value

	// minor food for household
	gen minor_hh = (share < 0.1)

	// don't include households with problematic foods in the calculation
	replace minor_hh = . if has_prob == 1

	byso consum_pos : egen mean_minor = mean(minor_hh)
	gen is_minor = (mean_minor >= 0.9)

	drop total_value 

	*** tag if a major food/minor food is also a problem food
	gen major_prob = (prob_food != 0 & is_minor == 0)
	bysort hhid: egen has_major_prob = total(major_prob)
	replace has_major_prob = 1 if (has_major_prob >= 1 ) 

	gen minor_prob =  ( prob_food != 0 & is_minor == 1 ) 
	bysort hhid: egen has_minor_prob = total(minor_prob)
	replace has_minor_prob = 1 if has_minor_prob >= 1 	
	
	/*  households problems 
	preserve
	collapse (sum) has_major_prob, by (hhid)
	tab has_major_prob
	restore

	preserve
	collapse (sum) has_minor_prob, by (hhid)
	tab has_minor_prob
	restore

	preserve
	collapse (sum) is_minor, by (consum_pos)
	tab is_minor
	restore

	BL: 24 major 51 minor 11/24 are major
	FU: 55 major 52 minor 10/25 are major
	*/ 
	
	* ------------------------------------------------------------------------ *
	* ------------------- 10. Compute Quantity Consumed  --------------------- *
	* ------------------------------------------------------------------------ *
	
	*** set to 0s if minor food and problem (same as has_minor_prob == 1)
	replace eat_value = 0 if prob_food !=0 & is_minor ==1 

	*** winsorize within each food item (smallest component type possible)
	levelsof consum_pos, local(consum_pos) 
	foreach pos in `consum_pos' {
		_pctile eat_value if consum_pos == `pos' & !missing(eat_value) , p(98)
		replace eat_value = `r(r1)' if consum_pos == `pos' & eat_value > `r(r1)' & !missing(eat_value) 
	}
	
	bysort hhid: egen food_week_xof = total(eat_value) 
		
	*** set to missing if major problem or no reported consumption
	replace food_week_xof = .m if has_major_prob == 1 | food_week_xof == 0 // if report no consumption, set to .m 
	label var food_week_xof "Total food consumption (week)"	
	
	*** Compute daily, monthly, and yearly total food consumption
	foreach period in day week month year {
		if 		"`period'" == "day"	 	local multi = 1/7
		else if "`period'" == "month" 	local multi = 52/12
		else if "`period'" == "year"	local multi = 52
		
		if "`period'" != "week" {
			gen food_`period'_xof = food_week_xof * `multi'
			label var food_`period'_xof "Total food consumption (`period')"	
		}
		
		*** per capita and adult equivalent values
		foreach type in pc eq {
			local std = cond("`type'" == "pc", "mem_n", "equiv_n")
			gen food_`period'_`type'_xof = food_`period'_xof / `std'
			label var food_`period'_`type'_xof "Total value: Food consumption (`period') (`type')"
		}
	}
	
	*** Purchased, Gifted, and Own_production food consumption 
	foreach shr in buy prod gift {
		* Multiply eat_value by share of the gifted quantity
		gen eat_value_`shr' = eat_value * qty_`shr'_share
		bysort hhid: egen food_week_`shr'_xof = total(eat_value_`shr')

		* Set to missing if major problem or no reported consumption
		replace food_week_`shr'_xof = .m if has_major_prob == 1 | food_week_xof == 0

		*** Compute daily, monthly, and yearly total food consumption
		foreach period in day week month year {
			if 		"`period'" == "day"	 	local multi = 1/7
			else if "`period'" == "month" 	local multi = 52/12
			else if "`period'" == "year"	local multi = 52
			
			if "`period'" != "week" {
				gen food_`period'_`shr'_xof = food_week_`shr'_xof * `multi'
				label var food_`period'_`shr'_xof "Total `shr' food consumption (`period')"	
			}
			
			*** per capita and adult equivalent values
			foreach type in pc eq {
				local std = cond("`type'" == "pc", "mem_n", "equiv_n")
				gen food_`period'_`shr'_`type'_xof = food_`period'_`shr'_xof / `std'
				label var food_`period'_`shr'_`type'_xof "Total value: `shr' Food consumption (`period') (`type')"
			}
		}
	}
	
	// Save
	keep 		hhid food_*_xof
	drop 		food_week_xof
	duplicates  drop hhid, force
	gen 		__FOOD__ = "FOOD CONSUMPTION"
	order		__FOOD__, after(hhid)
	tempfile 	food_consumption
	save 		`food_consumption'
	
	
	****************************************************************************
	*---------------------- II. NON-FOOD CONSUMPTION  -------------------------*
	****************************************************************************

	use 		"${intermediate_${phase}}/nonfood_consumption_wide", clear
	merge 1:1 	hhid using "${intermediate_${phase}}/chad_main_${phase_yr}", keepus(consent) nogen
	merge m:1 	hhid using "${constructed_${phase}}/demographics", keepusing(equiv_n mem_n) 
	drop if 	consent != 1 
	drop 		_merge

	// set consumption value to "0" if item not consumed 
	qui ds consum_nf_val*
	forvalues i = 1 / `:word count `r(varlist)'' {
		replace consum_nf_val_`i' = 0 if consum_nf_`i' == 0
	}
	
	// if a component is missing, this effectively sets to 0 
	egen missing = anycount(consum_nf_val*), v(888 999)
	fix_continuous consum_nf_val* 
	order consum_nf_val_*, after(hhid)

	* winsorize within component, at hh level (per capita, then scale back up) 
	qui ds consum_nf_val*
	forvalues i = 1 / `:word count `r(varlist)'' {
		replace consum_nf_val_`i' = consum_nf_val_`i' / equiv_n
		qui count if consum_nf_val_`i' > 0 & !missing(consum_nf_val_`i')
		if `r(N)' > 0 {
			_pctile consum_nf_val_`i' if consum_nf_val_`i' > 0, p(98)
			replace consum_nf_val_`i' = `r(r1)' if consum_nf_val_`i' > `r(r1)' & !missing(consum_nf_val_`i')  
			drop if consum_nf_val_`i' < 0 
		}
		replace consum_nf_val_`i' = consum_nf_val_`i' * equiv_n
	}
	
	local vars_7days    consum_nf_val_1 -  consum_nf_val_8  // 7 days
	local vars_30days   consum_nf_val_9 -  consum_nf_val_24 // 30 days
	local vars_6months  consum_nf_val_25 - consum_nf_val_45 // 6 months
	// we had 46-49 (6 months) and 50-69 (12 months) extra and overlapping with other responses
	
	local periods 7days 30days 6months 
	
	// scale to days
	foreach period in `periods' {
		
		if "`period'" == "7days"    local scale = 7
		if "`period'" == "30days"   local scale = 30
		if "`period'" == "6months"  local scale = 365/2 // 182.5 days
		if "`period'" == "12months" local scale = 365
		
		foreach var of varlist `vars_`period'' {
			gen `var'_day = `var' / `scale'
		}
	}

	** per day
	egen 	  nonfood_day_xof = rowtotal(*_day), m
	label var nonfood_day_xof "Total value: Nonfood consumption (day)"

	** per month
	gen 	  nonfood_month_xof = nonfood_day_xof * 365 / 12
	label var nonfood_month_xof "Total value: Nonfood consumption (month)"
	
	** per year
	gen 	  nonfood_year_xof = nonfood_day_xof * 365
	label var nonfood_year_xof "Total value: Nonfood consumption (year)"

	** per day per capita
	gen 	  nonfood_day_pc_xof = nonfood_day_xof / mem_n
	label var nonfood_day_pc_xof "Total value: Nonfood consumption (day) (per capita)"

	** per month per capita
	gen 	  nonfood_month_pc_xof = nonfood_month_xof / mem_n
	label var nonfood_month_pc_xof "Total value: Nonfood consumption (month) (per capita)"
	
	** per year per capita
	gen 	  nonfood_year_pc_xof = nonfood_year_xof / mem_n
	label var nonfood_year_pc_xof "Total value: Nonfood consumption (year) (per capita)"	
	
	** per day per adult equiv
	gen 	  nonfood_day_eq_xof = nonfood_day_xof / equiv_n
	label var nonfood_day_eq_xof "Total value: Nonfood consumption (day) (per adult equiv)"

	** per month per adult equiv
	gen 	  nonfood_month_eq_xof = nonfood_month_xof / equiv_n
	label var nonfood_month_eq_xof "Total value: Nonfood consumption (month) (per adult equiv)"
	
	** per year per adult equiv
	gen 	  nonfood_year_eq_xof = nonfood_year_xof / equiv_n
	label var nonfood_year_eq_xof "Total value: Nonfood consumption (year) (per adult equiv)"		
	
	// save
	keep 		hhid nonfood_*_xof mem_n equiv_n
	gen 		__NONFOOD__ = "NONFOOD CONSUMPTION"
	order 		__NONFOOD__, after(hhid)
	tempfile 	nonfood_consumption
	save 		`nonfood_consumption'

	
	****************************************************************************
	*--------------------- III. EDUCATION CONSUMPTION  ------------------------*
	****************************************************************************

	use 		"${intermediate_${phase}}/chad_main_${phase_yr}", clear
	keep 		hhid consent edu_fee*
	drop if 	consent != 1
	merge m:1 	hhid using "${constructed_${phase}}/demographics.dta", keepusing(equiv_n mem_n) nogen

	recode edu_fee* (999 = .o) (888 = .o) (555 = .o)
	
	// tag missing
	egen missing = rowmiss(edu_fee*)

	// winsorize 
	foreach var of varlist edu_fee? {
		qui count if `var' > 0 & !missing(`var')
		if `r(N)' > 0 {
			_pctile `var' if `var' > 0, p(98)
			replace `var'  = `r(r1)' if !missing(`var' )  & `var' >`r(r1)'
		}
	} 
		
	drop missing
	
	local educ_exp edu_fee1 edu_fee2 edu_fee3 edu_fee4 edu_fee5 edu_fee6 edu_fee7 edu_fee8 edu_fee9

	*** edu_year_xof
	egen 	  edu_year_xof = rowtotal(`educ_exp') 
	label var edu_year_xof "Total value: Education consumption (year)"

	*** edu_month_xof
	gen 		edu_month_xof = edu_year_xof / 12 
	label var 	edu_month_xof "Total value: Education consumption (month)"
	
	*** edu_day_xof
	gen 	  edu_day_xof = edu_year_xof / 365
	label var edu_day_xof "Total value: Education consumption (day)"

	*** edu_year_pc_xof
	gen 	  edu_year_pc_xof = edu_year_xof / mem_n
	label var edu_year_pc_xof "Total value: Education consumption (year) (per capita)"

	*** edu_month_pc_xof
	gen 		edu_month_pc_xof = edu_month_xof / mem_n 
	label var 	edu_month_pc_xof "Total value: Education consumption (month) (per capita)"
	
	*** edu_day_pc_xof
	gen 	  edu_day_pc_xof = edu_day_xof / mem_n
	label var edu_day_pc_xof "Total value: Education consumption (day) (per capita)"

	*** edu_year_eq_xof
	gen 	  edu_year_eq_xof = edu_year_xof / equiv_n
	label var edu_year_eq_xof "Total value: Education consumption (year) (per adult equiv)"

	*** edu_month_eq_xof
	gen 		edu_month_eq_xof = edu_month_xof / equiv_n 
	label var 	edu_month_eq_xof "Total value: Education consumption (month) (per adult equiv)"
	
	*** edu_day_eq_xof
	gen 	  edu_day_eq_xof = edu_day_xof / equiv_n
	label var edu_day_eq_xof "Total value: Education consumption (day) (per adult equiv)"

	// save 
	keep 		hhid edu_*_xof
	gen 		__EDUCATION__ = "EDUCATION"
	order 		__EDUCATION__, after(hhid)
	tempfile 	education_consumption
	save 		`education_consumption'


	****************************************************************************
	*---------------------- IV. HEALTH CONSUMPTION  -------------------------*
	****************************************************************************

	use 		"${intermediate_${phase}}/chad_main_${phase_yr}", clear
	keep 		hhid consent health*
	drop if 	consent != 1
	merge m:1 	hhid using "${constructed_${phase}}/demographics.dta", keepusing(equiv_n mem_n) nogen

	// set consumption value to zero if the item is not consumed
	recode health_*_amt (999 = .m) (888 = .d)
		
	// tag missing
	egen missing = rowmiss(health_*_amt) // effectively treats as 0 

	// winsorize 
	foreach var of varlist health_*_amt {
		qui count if `var' > 0 & !missing(`var')
		if `r(N)' > 0 {
			_pctile `var' if `var' > 0, p(98)
			replace `var'  = `r(r1)' if `var' > `r(r1)' & !missing(`var') 
		}
	} 

	if "$phase" == "Baseline" {
		*** health_30day_xof // all 30 days 
		egen health_30day_day_xof = rowtotal(health_1_amt health_2_amt health_3_amt health_4_amt health_5_amt health_6_amt health_7_amt health_8_amt) 
		replace health_30day_day_xof = health_30day_day_xof / 30 
	}
	else {
		*** health_30day_xof // all 30 days 
		egen health_30day_day_xof = rowtotal(health_a_amt health_b_amt health_c_amt health_d_amt health_e_amt health_f_amt health_g_amt) 
		replace health_30day_day_xof = health_30day_day_xof / 30 		
	}

	** Per day
	egen  	  health_day_xof = rowtotal(health_*_day_xof) 
	label var health_day_xof "Total value: Health consumption (day)"

	** per month 
	gen  	  health_month_xof = health_day_xof * 365 / 12 
	label var health_month_xof "Total value: Health consumption (month)"
	
	** per year
	gen 	  health_year_xof = health_day_xof * 365
	label var health_year_xof "Total value: Health consumption (year)"

	** Per day per capita
	gen  	  health_day_pc_xof = health_day_xof / mem_n
	label var health_day_pc_xof "Total value: Health consumption (day) (per capita)"

	** per month per capita
	gen  	  health_month_pc_xof = health_month_xof / mem_n
	label var health_month_pc_xof "Total value: Health consumption (month) (per capita)"
	
	** per year per capita
	gen 	  health_year_pc_xof = health_year_xof / mem_n
	label var health_year_pc_xof "Total value: Health consumption (year) (per capita)"	
	
	** Per day per equiv
	gen  	  health_day_eq_xof = health_day_xof / equiv_n
	label var health_day_eq_xof "Total value: Health consumption (day) (per equiv)"

	** per month per equiv
	gen  	  health_month_eq_xof = health_month_xof / equiv_n
	label var health_month_eq_xof "Total value: Health consumption (month) (per equiv)"
	
	** per year per equiv
	gen 	  health_year_eq_xof = health_year_xof / equiv_n
	label var health_year_eq_xof "Total value: Health consumption (year) (per equiv)"	
	
	// save
	keep 		hhid health_*_xof
	drop 		health_30day_day_xof 
	gen 		__HEALTH__ = "HEALTH"
	order 		__HEALTH__, after(hhid)
	tempfile 	health_consumption
	save `health_consumption'

	
	****************************************************************************
	*--------------------------- V. CELEBRATIONS ------------------------------*
	****************************************************************************	
	
	use "${intermediate_${phase}}/nf_celebrations_long.dta", clear
	merge m:1 hhid using "${constructed_${phase}}/demographics", keepus(mem_n equiv_n) nogen
	assert cel_food == . if cel == 0 // check no spending if no celebration

	* flag missing values
	egen missing = anycount(cel_food cel_drink cel_cloth cel_nonfood), values(888 999)
	tab missing // no celeb values == 888 or 999
	fix_continuous cel_food cel_drink cel_cloth cel_nonfood

	order cel_food cel_drink cel_cloth cel_nonfood, after (cel)

	* winsorize
	foreach item in food drink cloth nonfood {

		// winsorize at smallest component (spending types)
		qui count if cel_`item' > 0 & !missing(cel_`item')
		if `r(N)' > 0 {
			_pctile cel_`item' if cel_`item' > 0  , p(98)
			replace cel_`item' = `r(r1)' if cel_`item' > `r(r1)' & !missing(cel_`item') 
		} 
	}

	* total spending on each celebration
	egen cel_items_year  = rowtotal(cel_food - cel_nonfood), m 
	
	** per year
	bysort hhid: egen cel_year_xof = total(cel_items_year)
	label var cel_year_xof "Total value: Celebration consumption (year)"	
	
	*** per day
	gen 	  cel_day_xof = cel_year_xof / 365
	label var cel_day_xof "Total value: Celebration consumption (day)"

	** per month 
	gen  	  cel_month_xof = cel_year_xof / 12 
	label var cel_month_xof "Total value: Celebration consumption (month)"
	
	** per year per capita
	gen cel_year_pc_xof = cel_year_xof / mem_n
	label var cel_year_pc_xof "Total value: Celebration consumption (year) (per capita)"	
	
	*** per day per capita
	gen 	  cel_day_pc_xof = cel_day_xof / mem_n
	label var cel_day_pc_xof "Total value: Celebration consumption (day) (per capita)"

	** per month per capita
	gen  	  cel_month_pc_xof = cel_month_xof / mem_n
	label var cel_month_pc_xof "Total value: Celebration consumption (month) (per capita)"
	
	** per year per equiv
	gen cel_year_eq_xof = cel_year_xof / equiv_n
	label var cel_year_eq_xof "Total value: Celebration consumption (year) (per equiv)"	
	
	*** per day per equiv
	gen 	  cel_day_eq_xof = cel_day_xof / equiv_n
	label var cel_day_eq_xof "Total value: Celebration consumption (day) (per equiv)"

	** per month per equiv
	gen  	  cel_month_eq_xof = cel_month_xof / equiv_n
	label var cel_month_eq_xof "Total value: Celebration consumption (month) (per equiv)"
	
	// save
	keep hhid cel_*_xof 
	duplicates drop
	gen __CELEBRATION__ = "CELEBRATIONS", after(hhid)
	tempfile celeb_consumption
	save 	`celeb_consumption'


	****************************************************************************
	*------------------------- VI. Household repairs --------------------------*
	****************************************************************************
	
	if "$phase" == "Followup" {
		use "${intermediate_${phase}}/repair_consumption_long.dta", clear
		merge m:1 hhid using "${constructed_${phase}}/demographics", keepus(mem_n equiv_n) nogen	
		
		// set consumption value to zero if the item is not consumed
		recode improve_xof (999 = .m) (888 = .d)	
		fix_continuous improve_xof
		
		// wins
		_pctile improve_xof if !missing(improve_xof) , p(98)
		replace improve_xof = `r(r1)' if improve_xof > `r(r1)' & !missing(improve_xof) 
		replace improve_xof = 0 if improve_xof == .
		
		byso hhid : egen repairs_2yrs_xof = total(improve_xof) // raw variable asked about last 2 years
		label variable repairs_2yrs_xof "Total value: household repairs (last 2 years)"
		
		* year
		gen repairs_year_xof = repairs_2yrs_xof/2/8, after (repairs_2yrs_xof) // for 8-yr expected lifetime of repairs
		label variable repairs_year_xof "Total value: household repairs (year)"
		
		* month 
		gen 	  repairs_month_xof = repairs_year_xof/12
		label var repairs_month_xof "Total value: household repairs (month)"
		
		* day 
		gen 	  repairs_day_xof = repairs_year_xof/365
		label var repairs_day_xof "Total value: household repairs (day)"
		
		* year per capita
		gen repairs_year_pc_xof = repairs_year_xof / mem_n
		label variable repairs_year_pc_xof "Total value: household repairs (year) (per capita)"
		
		* month per capita
		gen 	  repairs_month_pc_xof = repairs_month_xof / mem_n 
		label var repairs_month_pc_xof "Total value: household repairs (month) (per capita)"
		
		* day per capita
		gen 	  repairs_day_pc_xof = repairs_day_xof / mem_n 
		label var repairs_day_pc_xof "Total value: household repairs (day) (per capita)"

		* year per adult equiv
		gen repairs_year_eq_xof = repairs_year_xof / equiv_n
		label variable repairs_year_eq_xof "Total value: household repairs (year) (adult equivalent)"
		
		* month per adult equiv
		gen 	  repairs_month_eq_xof = repairs_month_xof / equiv_n
		label var repairs_month_eq_xof "Total value: household repairs (month) (adult equivalent)"
		
		* day per adult equiv
		gen 	  repairs_day_eq_xof = repairs_day_xof / equiv_n 
		label var repairs_day_eq_xof "Total value: household repairs (day) (adult equivalent)"
		
		// save
		keep hhid repairs_*_xof 
		duplicates drop
		isid hhid
		gen __REPAIRS__ = "REPAIRS", after(hhid)
		tempfile repairs_consumption
		save 	`repairs_consumption'		
	}
	
	****************************************************************************
	*---------------------------- VII. Eating Out -----------------------------*
	****************************************************************************

	if "$phase" == "Followup" {
		use 		"${intermediate_${phase}}/chad_main_${phase_yr}", clear
		keep 		hhid consent eat_*
		drop if 	consent != 1
		merge m:1 	hhid using "${constructed_${phase}}/demographics.dta", keepusing(equiv_n mem_n) nogen

		// set consumption value to zero if the item is not consumed
		recode eat_out_xof (999 = .m) (888 = .d)	
		fix_continuous eat_out_xof
		
		// wins
		_pctile eat_out_xof if eat_out_xof > 0, p(98)
		replace eat_out_xof = `r(r1)' if eat_out_xof > `r(r1)' & !missing(eat_out_xof)  
		replace eat_out_xof = 0 if eat_out_xof == .
		
		** per day
		gen 	  eatout_day_xof = eat_out_xof / 7
		label var eatout_day_xof "Total value: eating out (day)"

		** per month
		gen 	  eatout_month_xof = eatout_day_xof * 365 / 12
		label var eatout_month_xof "Total value: eating out (month)"	
		
		** per year
		gen 	  eatout_year_xof = eatout_day_xof * 365
		label var eatout_year_xof "Total value: eating out (year)"

		** per day per capita
		gen 	  eatout_day_pc_xof = eatout_day_xof / mem_n
		label var eatout_day_pc_xof "Total value: eating out (day) (per capita)"

		** per month per capita
		gen 	  eatout_month_pc_xof = eatout_month_xof / mem_n
		label var eatout_month_pc_xof "Total value: eating out (month) (per capita)"	
		
		** per year per capita
		gen 	  eatout_year_pc_xof = eatout_year_xof / mem_n
		label var eatout_year_pc_xof "Total value: eating out (year) (per capita)"	
		
		** per day adult equiv
		gen 	  eatout_day_eq_xof = eatout_day_xof / equiv_n
		label var eatout_day_eq_xof "Total value: eating out (day) (adult equiv)"

		** per month adult equiv
		gen 	  eatout_month_eq_xof = eatout_month_xof / equiv_n
		label var eatout_month_eq_xof "Total value: eating out (month) (adult equiv)"	
		
		** per year adult equiv
		gen 	  eatout_year_eq_xof = eatout_year_xof / equiv_n
		label var eatout_year_eq_xof "Total value: eating out (year) (adult equiv)"		
		
		// save
		keep hhid eatout_*_xof 
		duplicates drop
		gen __EATOUT__ = "EAT OUT", after(hhid)
		tempfile eatout_consumption
		save 	`eatout_consumption'
	}
	
	****************************************************************************
	*-------------------------------- VIII. MERGE -----------------------------*
	****************************************************************************

	use 		`food_consumption', clear
	merge 1:1 	hhid using `nonfood_consumption', keep(match) nogen
	merge 1:1 	hhid using `education_consumption', keep(match) nogen
	merge 1:1 	hhid using `health_consumption', keep(match) nogen
	merge 1:1   hhid using `celeb_consumption', keep(match) nogen
	if "$phase" == "Followup" {
		merge 1:1   hhid using `repairs_consumption', keep(match) nogen
		merge 1:1   hhid using `eatout_consumption', keep(match) nogen
	}

	***  Total consumption
	gen 		__TOTAL_CONSUMPTION__ = "TOTAL CONSUMPTION"
	foreach type in year_xof month_xof day_xof year_pc_xof month_pc_xof day_pc_xof year_eq_xof month_eq_xof day_eq_xof {

		// add datasets where present
		if "$phase" == "Followup" {
			local fu_extra1 repairs_`type'
			local fu_extra2 eatout_`type'
		}
		egen consum_`type' = rowtotal(food_`type' nonfood_`type') // edu_`type' health_`type' cel_`type' `fu_extra1' `fu_extra2'
	
		*** set total consumpion to missing if a component is missing 
		foreach var of varlist food_`type' nonfood_`type' { // edu_`type' health_`type' cel_`type' `fu_extra1' `fu_extra2'
			replace consum_`type' = . if missing(`var') 
		}
	}

	label var 	consum_day_xof "Total consumption (food+nonfood) (day)"
	label var 	consum_month_xof "Total consumption (food+nonfood) (month)"
	label var 	consum_year_xof "Total consumption (food+nonfood) (year)"
	label var 	consum_day_pc_xof "Total consumption (food+nonfood) (day) (per capita)"	
	label var 	consum_month_pc_xof "Total consumption (food+nonfood) (month) (per capita)"	
	label var 	consum_year_pc_xof "Total consumption (food+nonfood) (year) (per capita)"
	label var 	consum_day_eq_xof "Total consumption (food+nonfood) (day) (per adult equiv)"	
	label var 	consum_month_eq_xof "Total consumption (food+nonfood) (month) (per adult equiv)"	
	label var 	consum_year_eq_xof "Total consumption (food+nonfood) (year) (per adult equiv)"

	
	****************************************************************************
	*-------------------------- VI. SAVE DATASET ------------------------------*
	****************************************************************************

	order 		hhid equiv_n mem_n, first
	isid hhid 
	compress
	save 		"${constructed_${phase}}/consumption.dta", replace
	