	***************************************************************************
	*																		  *
	*		   SOCIAL WELL-BEING AND OTHER DOWNSTREAM OUTCOMES			 	  *
	*																		  *
	***************************************************************************
	
    /*	
	** OUTLINE: 	
	
				**** Downstream C.1.1 Gender attitudes index
					 RELATION vars: dom_burn dom_kids ten_violen ten_men ten_boys
					 
				**** Downstream C.1.2 perceptions of domestic violence 
					 RELATION vars: ten_tension vill_burn vill_kids

					 
				-------------------------------------------
				**** Downstream C.2.1 social support index 
					 MENTAL vars: role soc_tips soc_tips_in soc_confl soc_confl_in other_market
					 
				**** Downstream C.2.2 financial support index 
					 MENTAL vars: ce3_new 
					 FINANCE vars: ask_siblings ask_otherfam ask_friends ask_otherknown accesstofunds_rvrs

				**** Downstream C.2.3 (NEW-A) 	q (Woman's Perspective) 
					 RELATION vars: free_move rel_disagree rel_interest 
					 MENTAL vars: los1 los3 tens_house
					 
				**** Downstream C.2.3 (NEW-B) Social cohesion and closeness to community 
					 MENTAL vars: aff_ieff  enemy los2 tens_comm 
					 
				**** Downstream C.2.4 groups and collective action 
					 MENTAL vars: aut_fond_ppp_w aut_volu partic soc_post worktogether_new
					 
    */
  
	// Import main dataset where all MENTAL and RELATIONS variables exist

	use "${intermediate_${phase}}/chad_main_2021.dta", clear
	drop if consent == 0
	drop consent

	merge 1:1 hhid using "${constructed_${phase}}/identification.dta", ///
		gen(_mtreat) keepusing(pm_treatment)
		
	// keep downstream vars by section
	local c21_vars  role soc_tips soc_tips_in soc_confl soc_confl_in other_market
	local c22_vars  ce3_new accesstofunds ask_siblings ask_otherfam ask_friends ask_otherknown
	local c23a_vars free_move rel_disagree rel_interest los1 los3 tens_house
	local c23b_vars aff_ieff enemy for_trust1 tens_comm los2 
	local c24_vars  partic soc_post aut_fond aut_volu worktogether_new

	local downstream_sections  `c21_vars' `c22_vars' `c23a_vars' `c23b_vars' `c24_vars'

	foreach var in `downstream_sections' {
		capture confirm var `var'
		if _rc != 0 { // if var DNE, remove it from list to keep
			local omit `var'
			local downstream_sections : list downstream_sections - omit
		}
	}						  
							  
	order hhid pm_treatment `downstream_sections' 
	keep  hhid pm_treatment `downstream_sections'

	// temporary measure (drop HHs with no benef)
	merge 1:1 hhid using "${constructed_${phase}}/demographics.dta", ///
			gen(_mdem) keepusing(benef_pos)
	drop if benef_pos == . // removing absent beneficiaries for now although responses exist for someone else in the HH
	qui count if benef_pos != .
	assert `r(N)' == _N // assert all HHs have benefs	
	
	
	********************************************************************************
	*******************   Downstream C.2. Social well-being   **********************

	********************************************************************************
	**** Downstream C.2.1 social support index 

	/*
	** Count of people know that have succeeded in life (has aspirational role models)
	** Count of people could ask for activity advice
	** Count of people who have asked beneficiary for activity advice in last 6 months
	** Count of people could ask for conflict advice
	** Count of people who have asked beneficiary for conflict advice in last 6 months
	** Count of people could ask to sell products for you in a market            */

	local social_support_vars role soc_tips soc_tips_in soc_confl soc_confl_in other_market
	// note: some HHs register hundreds of people

	label var role 			"How many people do you know who have personally succeeded in life?"
	label var soc_tips 		"How many people can you go to for advice on income-generating activity?"
	label var soc_tips_in 	"How many people come to you for advice on income-generating activity?"
	label var soc_confl 	"How many people can you go to for advice on arguments/disputes?"
	label var soc_confl_in 	"How many people come to you for advice on arguments/disputes?"
	label var other_market	"How many people can you trust to sell your products in other markets?"
	// all positive variables. No crazy values

	zindex `social_support_vars', gen (social_support_index) condition(pm_treatment == 0) 
	label var social_support_index "C.2.1 social support index (Z-score)"

	order hhid social_support_index `social_support_vars', last

	
	********************************************************************************
	**** Downstream C.2.2 financial support index 

	/*
	Can count on village community to help you financially [1-4]
	Count of people could ask for money
	Probability of putting together a small sum of money (0-4)  */

	// ce3
	recode ce3_new (5=1)(6=2)(7=3)(8=4)

	// reverse access to funds since it's apparently decreasing
	gen accesstofunds_rvrs = accesstofunds // as accesstofunds is negatively increasing
	revrs accesstofunds_rvrs, replace

	local ask_comp ask_siblings ask_otherfam ask_friends ask_otherknown
	label var ask_siblings 		"No. of siblings that you can ask for money"
	label var ask_otherfam 		"No. of family members that you can ask for money"
	label var ask_friends 		"No. of friends that you can ask for money"
	label var ask_otherknown	"No. of other people that you can ask for money"

	// two winsorization approaches: 
	// 1. winsorize number of siblings, sum it all up, and winsorize the total number
	// 2. sum every thing up and then winsorize the result

	// approach 1
	gen ask_siblings_w = ask_siblings 
	_pctile ask_siblings, p(98)
	replace ask_siblings_w  = `r(r1)' if !missing(ask_siblings) & ask_siblings > `r(r1)'
	egen ask_sum1 = rowtotal(ask_siblings_w ask_otherfam ask_friends ask_otherknown), m // treats missing as zero unless all missing

	gen ask_sum1_w = ask_sum1
	_pctile ask_sum1, p(98)
	replace ask_sum1_w  = `r(r1)' if !missing(ask_sum1) & ask_sum1 > `r(r1)'
	label var ask_sum1_w ""

	// approach 2
	egen ask_sum2 = rowtotal(ask_siblings ask_otherfam ask_friends ask_otherknown), m // treats missing as zero unless all missing
	gen ask_sum2_w = ask_sum2
	_pctile ask_sum2, p(98)
	replace ask_sum2_w  = `r(r1)' if !missing(ask_sum2) & ask_sum2 > `r(r1)'
	label var ask_sum2_w "winsorized row sum"

	label var ask_sum2_w "Count you could ask for money (winsorized row sum after winsorizing siblings variable)"
	label var ask_sum1_w "Count you could ask for money (winsorized row sum)"
	label var ce3_new 			 "Can count on village people to help financially if you face difficulties"
	label var accesstofunds_rvrs "Probability of raising funds"

	// approach 1
	local financial_support_vars ce3_new ask_sum1_w accesstofunds_rvrs
	if "$ph" == "bl" local omit ask_sum1_w
	local financial_support_vars : list financial_support_vars - omit 
		
	zindex `financial_support_vars', gen(fin_supp_index_1) condition(pm_treatment == 0) 
	label var fin_supp_index_1 "C.2.2 Financial support index (Z-score), wins. siblings then sum"

	// approach 2
	local financial_support_vars_keep ce3_new `ask_comp' ask_sum2_w accesstofunds_rvrs 
	local financial_support_vars 	  ce3_new 			 ask_sum2_w accesstofunds_rvrs
	local omit `ask_comp' ask_sum2_w
	local financial_support_vars_keep : list financial_support_vars_keep - omit
	local financial_support_vars : 		list financial_support_vars 	 - omit
		
	zindex `financial_support_vars', gen(fin_supp_index_2) condition(pm_treatment == 0) 
	label var fin_supp_index_2 "C.2.2 Financial support index (Z-score), wins. sum"

	local keep_2_2_extra ask_sum1_w 
	order fin_supp_index_2 fin_supp_index_1 `keep_2_2_extra' `financial_support_vars_keep', last

	
	********************************************************************************
	**** Downstream C.2.3 (NEW-A) Intra-household Dynamics (Woman's Perspective) 
	/*	- Able to tell partner disagree (4-1) -> (1-4)				(from old B.10.4)rel_disagree
		- Partner acts in my interest (4-1) -> (1-4)				(from old B.10.4)rel_interest
		- inclusion of self in (closeness to) partner [1-4]			(from old C.2.3) los3
		
		- Household tensions in last 6 months [0-3]					(from old C.2.3) tens_house
		- inclusion of self in (closeness to) household [1-4]		(from old C.2.3) los1        */


	********************************************************************************
	**** Downstream C.2.3 (NEW-B) Social cohesion and closeness to community 

	/*  - Can count on other women in village [1-4]					(from old C.2.3) aff_ieff
		- Number of personal enemies [0-3]							(from old C.2.3) enemy
		- Community tensions in last 6 months [0-3]					(from old C.2.3) tens_comm
		- inclusion of self in (closeness to) community [1-4]		(from old C.2.3) los2 		
		*/ 

	**** ----------------| Downstream C.2.3 (NEW-A) Intra-household Dynamics (Woman's Perspective) 

	// reverse these two variables
	foreach var of varlist rel_disagree rel_interest {
		recode `var' (1=4)(2=3)(3=2)(4=1)
	}

	label variable rel_interest "8.01 Do you think your spouse will always do the things that are best for you?"
	label variable rel_disagree "8.02 When you disagree with your spouse, you feel comfortable telling him so"
	label define likert 1 		"Most of the time" 2 "Sometimes" 3 "Rarely" 4 "Never"
	label values rel_disagree likert 
	label values rel_interest likert 

	**	emp_move
	gen 	emp_move = (free_move - 1)
	replace emp_move = abs(emp_move)
	label var emp_move "Household has not prevented you from visiting friends or family"
	drop free_move
	
	
	// reverse tension measure to capture lower tension with increasing nos. (DNE at BL)
	ds tens_house 
	foreach var in `r(varlist)' {
		gen `var'_rvrs = `var'
		revrs `var'_rvrs, replace // these become {1-4}
	}
	label var tens_house_rvrs "In the last 6 months, have you had tensions with other members of your household?"

	// partner dynamics sub-index
	local partner_vars rel_disagree rel_interest los3
	zindex `partner_vars', gen (partner_vars_index) condition(pm_treatment == 0)
	label var partner_vars_index "C.2.3.A Partner Dynamics Z-index"

	// HH dynamics sub-index components
	// omitting vars not in that survey to be excluded from zindex command

	local hh_vars  tens_house_rvrs los1 emp_move

	local hh_vars : list hh_vars - omit

	zindex `hh_vars', gen (hh_vars_index) condition(pm_treatment == 0)
	label var hh_vars_index "C.2.3.A Partner Dynamics Z-index at ${phase}"

	// standard z index
	local intrahh_vars partner_vars_index hh_vars_index
	zindex `intrahh_vars', gen (intrahh_vars_index) condition(pm_treatment == 0)
	label var intrahh_vars_index "C.2.3.A Intra-HH Dynamics Z-index at ${phase}"

	order hhid `partner_vars' partner_vars_index `hh_vars' hh_vars_index* 		///
				intrahh_vars_index* 											// * for trim (BL) version


	**** ----------------| Downstream C.2.3 (NEW-B) Social cohesion and closeness to community 

	// a few vars only exist at 
	label var aff_ieff 		"You can count on the help of the women of your village when you have difficulties" // increasing. keep
	recode aff_ieff (5=1)(6=2)(7=3)(8=4)

	// reverse tension measure to capture lower tension with increasing nos.
	ds enemy tens_comm
	foreach var in `r(varlist)'{
		gen `var'_rvrs = `var'
		revrs `var'_rvrs, replace // these become {1-4}
	}

	label var enemy_rvrs 	  "Are there ppl who hate you and wish you failed or to sabotage your success?"
	label var tens_comm_rvrs  "In the last 6 months, has there been tension between members of your community?"

	local community_vars aff_ieff enemy_rvrs for_trust1 tens_comm_rvrs los2
	local community_vars : list community_vars - omit // harmless if omit isn't defined

	zindex `community_vars', gen (soc_cohsn_index) condition(pm_treatment == 0) 
	label var soc_cohsn_index "C.2.3.B Social cohesion and closeness to community Z-index"

	order hhid `community_vars' soc_cohsn_index*, last /// * for trim (BL) version
			   

	********************************************************************************
	**** Downstream C.2.4 groups and collective action 

	// Count of groups or associations that member, last 2 months
	// Count of positions of responsibility in any group, last 12 months
	// Amount given for community projects, last 2 months
	// Days volunteered for community activities, last 2 months
	// Works with community to achieve common goals [1-4]

	label var partic 			"Count of groups or associations that member, last 2 months"
	label var soc_post 			"Count of positions of responsibility in any group, last 12 months"
	label var aut_fond 			"(FCFA) How much money have you given to a fund for community projects in the past two months?"
	label var aut_volu 			"How many days have you spent in community activities in the last two months?"
	label var worktogether_new	"Works with community to achieve common goals [1-4]"
	recode worktogether_new (5=1)(6=2)(7=3)(8=4)

	/*
	** conversion to purchasing power parity
	rename aut_fond aut_fond_xof // run through all variables with FCFA units
	currency_work aut_fond_xof, task("convert_ppp_2016") // generates *_ppp
	currency_work aut_fond_xof, task("deflate_2016")     // deflates original
	rename *_xof_ppp *_ppp // retain ppp suffix only
	*/ 

	rename aut_fond aut_fond_xof // run through all variables with FCFA units
	gen aut_fond_ppp = aut_fond_xof

	foreach var of varlist aut_fond_ppp aut_fond_xof { 
		_pctile `var' , p(98)

		gen `var'_w = `var' 
		replace `var'_w  = `r(r1)' if !missing(`var'_w ) & `var'_w  > `r(r1)'
	}
	label var aut_fond_xof_w "Community project donations past 2 months (FCFA, Wins. 98p)"
	label var aut_fond_ppp_w "Community project donations past 2 months (2016 USD, Wins. 98p)"

	local collective_action_vars partic soc_post aut_fond_ppp_w aut_volu worktogether_new
	
	zindex `collective_action_vars', gen(collective_action_index) condition(pm_treatment == 0) 
	label var collective_action_index "C.2.4 Groups and collective action index (Z-score)"

	order collective_action_index `collective_action_vars' aut_fond_xof_w, last

	********************************************************************************
	**** Export 

	// BL 			c_2_2 and c_2_3
	// FU c_2_1 and c_2_2 and c_2_3 and c_2_4 and c_2_5

	compress 
	save "${constructed_${phase}}/social_wellbeing", replace



