/*******************************************************************************
Title: 05_regs.do
This do-file is the regression do-file for the project.
*******************************************************************************/

pause on 
matrix drop _all
nois dis "Running do-file: 06b_regs_chad.do"

********************************************************************************
****  1. Import data

use "${data_dir}/allrounds_CHAD_hh.dta", clear
local id hh // used to label some result files

********************************************************************************
****  2. Collect variables in section-s

regs_vars // return list: r(all_sections), r(section)

// extract locals from r(.)
local chad_tables `r(all_sections)'
foreach section in `chad_tables' {
	local `section' `r(`section')'	// copy old components
}

********************************************************************************
****  2.1 collect all locals from above in different sections. Each of these produces a table

local lists `r(all_sections)'

********************************************************************************
****  3 Label Baseline Outcomes	
	
* label BL outcomes 
local blvars "*_bl"
qui ds `blvars'
foreach var in `r(varlist)' {
	capture confirm variable `var'
	if (_rc == 0) label variable `var' "variable @ Baseline"
}

********************************************************************************
****  4. Run Regressions and generate output 

	eststo clear 		 	// for estout 
	local row_n_long = 0 	
	local section_n = 1 // for est_collect_long
	local fam = 1 			// for p_collect_long
	local sanity_check_counter 1
		
	* loop on each variable within each section, saving a table for each section
	foreach section in `lists' {

		eststo clear 				  // for estout
		local blvar_count = 0		  // count bl vars per section
		local var_count = 1 		  // for suest estadd command
		local var_count_tot : word count ``section''
		local no_of_sections : word count `lists' // for est_collect_long
		local mylabels 				// empty
		
		// sanity check
		if "``section''" == "" {
			nois dis as error "Table `section' is not defined in regs_vars"
			stop 
		}
		
		************************************************************************
		****  4.1 Define table specific var labels, titles, and footnotes

		//---------------------------------
		// label variables conditional on section
		qui regs_labels, section("`section'") stack_opt(vertical)
		
		//---------------------------------
		// Label tables based on subset and PAP section. Used in title() in esttab below

		// add permutation test to main tables
		if inlist("`section'", "prim1_hh_t1", "prim1_hh_t2", "prim2_beno_t1", "prim2_beno_t2") 											| ///
		   inlist("`section'", "prim3_ben_t1",  "prim3_ben_t2",  "prim4_ben_t1",  "prim4_ben_t2",  "prim6_ben_t1",  "prim6_ben_t2") 	| ///
		   inlist("`section'", "prim3_chef_t1", "prim3_chef_t2", "prim4_chef_t1", "prim4_chef_t2", "prim6_chef_t1", "prim6_chef_t2") {
				local perm "yes"
		   }
		else {
				local perm
		}
		
		// Primary outcomes
		forvalues i = 1/4 {

			if ("`section'" == "prim1_hh_t`i'") {
				if `i' == 1	local table_title "Table 2: Direct impacts on household welfare"
				if `i' == 2 local table_title "Table 7: Spillovers on household welfare"
				if `i' == 3	local table_title "Table A8: Decomposition of spillovers on household welfare"
			}
			else if ("`section'" == "prim1_hh1_t`i'") {
				if `i' == 1	local table_title "Table S3: Direct impacts on household welfare, per capita cons."
				if `i' == 2 local table_title "Table S9: Spillovers on household welfare, per capita cons."
				if `i' == 3	local table_title "Table S17: Decomposition of spillovers on standardized welfare indices, per capita cons."
			}	
			else if ("`section'" == "prim1_hh2_t`i'") {
				if `i' == 1	local table_title "Table S4: Direct impacts on household welfare, gross cons."
				if `i' == 2 local table_title "Table S10: Spillovers on household welfare, gross cons."
				if `i' == 3	local table_title "Table S18: Decomposition of spillovers on standardized welfare indices, gross cons."
			}	
			else if ("`section'" == "prim2_beno_t`i'") {
				if `i' == 1 local table_title "Table 6: Direct impacts of women's empowerment and psychosocial well-being"
				if `i' == 2 local table_title "Table 11: Spillovers on women's empowerment and psychosocial well-being"
				if `i' == 3 local table_title "Table S23: Decomposition of spillovers on women's empowerment and psychosocial well-being"
			}			
			
			foreach lev in ben chef {
				else if ("`section'" == "prim3_`lev'_t`i'")	{
					if `i' == 1 local table_title "Table 3: Direct impacts on agriculture"
					if `i' == 2 local table_title "Table 8: Spillovers impacts on agriculture"
					if `i' == 3 local table_title "Table A11: Decomposition of spillovers impacts on agriculture"
				}		
				else if ("`section'" == "prim4_`lev'_t`i'") {
					if `i' == 1 local table_title "Table 4: Direct impacts on off-farm businesses"
					if `i' == 2 local table_title "Table 9: Spillovers impacts on off-farm businesses"
					if `i' == 3 local table_title "Table A12: Decomposition of spillovers impacts on off-farm businesses"
				}			
				else if ("`section'" == "prim5_`lev'_t`i'")	{
					if `i' == 1 local table_title "Table A4: Direct impacts on salaried employment"
					if `i' == 2 local table_title "Table A7: Spillovers impacts on salaried employment"
					if `i' == 3 local table_title "Table S25: Decomposition of spillovers on salaried employment"					
				}		
				else if ("`section'" == "prim5b_`lev'_t`i'")	{
					if `i' == 1 local table_title "Table S8: Direct impacts on non-agricultural employment"
					if `i' == 2 local table_title "Table S14: Spillovers impacts on non-agricultural employment"
					if `i' == 3 local table_title "Table S22: Decomposition of spillovers on non-agricultural employment"					
				}	
				else if ("`section'" == "prim6_`lev'_t`i'") {
					if `i' == 1 local table_title "Table 5: Direct impacts on livestock and savings"
					if `i' == 2 local table_title "Table 10: Spillovers impacts on livestock and savings"
					if `i' == 3 local table_title "Table A13: Decomposition of spillovers on livestock and savings"				
				}				
			}
			
			if ("`section'" == "scnd7_t`i'") {
				if `i' == 1 					local table_title "Table S5: Direct impacts on agriculture at household level"
				if `i' == 2 					local table_title "Table S11: Spillovers on agriculture at household level"
				if `i' == 3						local table_title "Table S19: Decomposition of spillovers on agriculture at household level"
			}			
			else if ("`section'" == "scnd8_t`i'") {
				if `i' == 1						local table_title "Table S6: Direct impacts on off-farm businesses at household level"
				if `i' == 2						local table_title "Table S12: Spillovers impacts on off-farm businesses at household level"
				if `i' == 3						local table_title "Table S20: Decomposition of spillovers impacts on off-farm businesses at household level"
			}			
			else if ("`section'" == "scnd9_t`i'") {
				if `i' == 1						local table_title "Table S7: Direct impacts on livestock and savings at household level"
				if `i' == 2						local table_title "Table S13: Spillovers impacts on livestock and savings at household level"
				if `i' == 3						local table_title "Table S21: Decomposition of spillovers on livestock and savings at household level"
			}	
			else if ("`section'" == "scnd5_t`i'") {
				if `i' == 1						local table_title "Table A2: Direct impacts on standardized welfare indices"
				if `i' == 2						local table_title "Table A5: Spillovers impacts on standardized welfare indices"
				if `i' == 3						local table_title "Table A9: Decomposition of spillovers on standardized welfare indices"
			}	
			else if ("`section'" == "scnd6_t`i'") {
				if `i' == 1						local table_title "Table A3: Direct impacts on agricultural inputs"
				if `i' == 2						local table_title "Table A6: Spillovers impacts on agricultural inputs"
				if `i' == 3						local table_title "Table S24: Decomposition of spillovers on agricultural inputs"
			}	
				

			if ("`section'" == "supp_9_t`i'")   local table_title "Table S35: Impacts and spillovers on assets and financial behavior"
			if ("`section'" == "supp_10_t`i'")  local table_title "Table A10: Food Consumption Components"
			if ("`section'" == "supp_25_t`i'")	local table_title "Table S26: Productive measures (PM) compliance" 
			if ("`section'" == "supp_26_t`i'")	local table_title "Table S27: Agriculture outcomes by main crops"
			
			if ("`section'" == "supp_37_t`i'")	local table_title "Table A14: Control over household resources index components"
			if ("`section'" == "supp_35_t`i'")	local table_title "Table A15: Intra-household dynamics index components"
			if ("`section'" == "supp_31_t`i'")	local table_title "Table A16: Financial support index components"
			if ("`section'" == "supp_30_t`i'")	local table_title "Table A17: Social support index components"
			if ("`section'" == "supp_32_t`i'")	local table_title "Table A18: Social standing index components"
			if ("`section'" == "supp_34_t`i'")	local table_title "Table A19: Collective action index components"			
			if ("`section'" == "supp_33_t`i'")	local table_title "Table A20: Social cohesion and community closeness index components"
			if ("`section'" == "supp_27_t`i'")	local table_title "Table A21: Mental health index components"
			if ("`section'" == "supp_28_t`i'")	local table_title "Table A22: Self-efficacy index components"
			if ("`section'" == "supp_29_t`i'")	local table_title "Table A23: Future expectations index components"
			
			if ("`section'" == "supp_38_t`i'")	local table_title "Table S28: Perceptions of productive measures"
			if ("`section'" == "supp_39_t`i'")	local table_title "Table S29: Perceptions of productive measures 2 (continued)"
			if ("`section'" == "supp_40_t`i'")	local table_title "Table S30: Perceptions of cash tranfers program"
			if ("`section'" == "supp_41_t`i'")	local table_title "Table S31: Perceptions of cash tranfers program 2 (continued)"
			if ("`section'" == "supp_42_t`i'")	local table_title "Table S32: Perceptions of cash tranfers program 3 (continued)"
			if ("`section'" == "supp_43_t`i'")	local table_title "Table S33: Household transfers received"
			if ("`section'" == "supp_44_t`i'")	local table_title "Table S34: Household transfers sent out"				
		}			
			
		** 4.1.0 General FOOTNOTES: abbreviated for long deck
		local controls_note "Results presented are OLS estimates that include controls for region fixed effects and, where possible, baseline outcomes." 
		local se_note "Robust standard errors are shown in parentheses, clustered at the village level."
		//---------------------------------
		** 4.1.1 FOOTNOTES: section- or table-specific footnotes 
		if strpos("`section'", "scnd5_t") > 0 		| ///
		   strpos("`section'", "prim1_hh_t") > 0	| ///
		   strpos("`section'", "prim1_hh1_t") > 0	| ///
		   strpos("`section'", "prim1_hh2_t") > 0	{
			local section_footnote "Components in columns (2) to (6) are used to construct the Composite Z-Score Index (7)."
		}
		else if strpos("`section'", "scnd9_t") > 0 		| ///
				strpos("`section'", "prim6_ben_t") > 0 	| /// 
				strpos("`section'", "prim6_chef_t") > 0 {
			local section_footnote "TLU represents Tropical Livestock Units."		
		}
		else if strpos("`section'", "beno_t") > 0 {
			#delimit ;
			local section_footnote 
				`"Results from components of each index are provided in 
				Table A14 (control over household resources index components),
				Table A15 (intra-household dynamics index components),
				Table A16 (financial support index components),
				Table A17 (social support index components),
				Table A18 (social standing index components),
				Table A19 (collective action index components),	
				Table A20 (social cohesion and community closeness index components),
				Table A21 (mental health index components),
				Table A22 (self-efficacy index components), and
				Table A23 (future expectations index components)."' ;
			#delimit cr
		}
		else {
			local section_footnote  //
		}
		
		if strpos("`section'", "scnd5_t") > 0 		| ///
		   strpos("`section'", "prim1_hh_t") > 0	| ///
		   strpos("`section'", "prim1_hh1_t") > 0	| ///
		   strpos("`section'", "prim1_hh2_t") > 0	| ///
		   strpos("`section'", "beno_t") > 0	{
			#delimit ;
			local index_footnote 
				`"All indices are standardized with respect to the 
					control group in that survey round."'; 
			#delimit cr
		}
		else {
			local index_footnote ""
		} 
		
		if "`perm'" != "" {
			#delimit ;
			local permutation_footnote "The randomization inference tests are 
						performed with `=string(${n_reps}, "%9.0fc")'
						permutations, preserving both the randomization strata 
						and the cluster structure." ;	
			#delimit cr
		}
		else {
			local permutation_footnote
		}
	
						
		#delimit ;
		local allnotes 
			`"`controls_note' `se_note' `permutation_footnote'
			*** p $<$ 0.01, ** p $<$ 0.05, * p $<$ 0.1.
			`index_footnote' `section_footnote' "' ;
		#delimit cr

		// trim multiline footnotes
		foreach notehere in controls_note se_note index_footnote section_footnote allnotes {				
			local `notehere' = trim(itrim("``notehere''"))
		}
		
		************************************************************************
		****  4.2 Extract variable labels, run regressions, and store statistics
		dis "Chad tables, step 4: Running regs for `section' table in main spec"

		if strpos("`section'" , "_chef_t1") > 0 | ///
		   strpos("`section'" , "_chef_t2") > 0 | /// 
		   strpos("`section'" , "_chef_t4") > 0 | ///
		   strpos("`section'" , "_hh_t4")   > 0 | ///
		   strpos("`section'" , "_hh1_t4")   > 0 | ///
		   strpos("`section'" , "_hh2_t4")   > 0 | ///
		   strpos("`section'" , "_beno_t4") > 0 | /// 
		   strpos("`section'" , "5_t4") 	> 0 | ///
		   strpos("`section'" , "6_t4") 	> 0 | ///
		   strpos("`section'" , "7_t4") 	> 0 | ///
		   strpos("`section'" , "8_t4") 	> 0 | ///
		   strpos("`section'" , "9_t4") 	> 0 | ///
		   strpos("`section'" , "10_t4") 	> 0 | ///
		  (strpos("`section'" , "_t4") > 0 & strpos("`section'" , "supp_") > 0) {
			local first_panel "no"
			local scond_panel "no"
			local third_panel "no"
			local final_panel "yes"
		}
		else if strpos("`section'" , "_chef_t3") > 0 | ///
		(strpos("`section'" , "_t3") > 0 & strpos("`section'" , "supp_") > 0) {
			local first_panel "no"
			local scond_panel "no"
			local third_panel "yes"
			local final_panel "no"			
		}
		else if strpos("`section'" , "_ben_t4") > 0 | ///
		(strpos("`section'" , "_t2") > 0 & strpos("`section'" , "supp_") > 0) {
			local first_panel "no"
			local scond_panel "yes"
			local third_panel "no"
			local final_panel "no"			
		}
		else {
			local first_panel "yes"
			local scond_panel "no"
			local third_panel "no"
			local final_panel "no"
		}
		
		nois dis as error "1st: `first_panel' - 2nd: `scond_panel' - 3rd: `third_panel' - 4th: `final_panel'"
		
		if "`first_panel'" == "yes" {

			foreach var in ``section'' { 			
				
				dis "Variable: `var'"

				****----------------------------------------------------------------
				****  4.2.1 Extract variable labels
				
				// collect variable labels in Tex friendly format
				// this program returns r(mylabels) and r(returnlocal)
				stack_concat_varlabs, lab("`: var label `var''") ///
									  section("`section'") ///
									  var_count(`var_count') ///
									  var_count_tot(`var_count_tot') ///
									  returnlocal("titles_`section'") ///
									  recurstitles("`titles_`section''") 

				local titles_`section' = "`r(titles_`section')'"
				local templab = subinstr("`r(mylabels)'", "&", "", .)
				
				// concatenate varlabels
				if strlen(`"`mylabels'"') == 0 local mylabels `" "`templab'" "'
				else 				   		   local mylabels `" `mylabels' "`templab'" "'
				
				****----------------------------------------------------------------
				****  4.2.2 run regressions
							
				** Regression treatment, cluster, and strata
					
				if strpos("`section'", "_t1") > 0 {
					local treatvar 	pm_treatment
				}
				else if strpos("`section'", "_t2") > 0 {
					local treatvar	both_spillover_dummy
				}
				else if strpos("`section'", "_t3") > 0 {
					local treatvar	ct_spillover_dummy
				}				
				else if strpos("`section'", "_t4") > 0 {
					local treatvar	non_ct_spillover_dummy
				}	
					
				local cluster_var 	p_village
				local strata_var 	strata

				if "${w_lvl}" == "village" 	local weight_var weight_vil 
				if "${w_lvl}" == "overall" 	local weight_var weight_ovrl
				if "${w_lvl}" == "prop_g2" 	local weight_var weight_g2
			
				** Regression extras: bl_ctrl_var bl_ctrl_dum 
				// check if bl version exists
				// if the exact same bl outcome exists, use that instead.
				// else if no bl outcome exists, empty local - can't control for bl (no ancova)
				capture confirm variable `var'_bl
				if _rc == 0 {
					local bl_ctrl_var `var'_bl    
				}
				else if _rc != 0 {
					local bl_ctrl_var     
				}
				
				** condition 
				if strpos("`section'", "_chef_") > 0 {
					local condition "if same_cb != 1"
				}
				else {
					local condition ""
				}
					
				** Run Regression
				qui	eststo :  reg `var' i.`treatvar' 	 		   	/// treatment 
										`bl_ctrl_var'    		    /// bl controls (wherever available)
										i.`strata_var'				///
										[pw = `weight_var']			///
										`condition', 		   		///
										cluster(`cluster_var') 	    //
				
				** Collect main items from return list for later use 
				qui gen reg_obs = e(sample) // used within each var loop and dropped at the end of the loop
				matrix my_reg = r(table) // collect results

				
				****----------------------------------------------------------------
				****  4.2.3 store group averages and error bars (for ppt) main spec only
					
				//---------------------------------
				// Sample size
				local n_reg = `e(N)'
				local df    = `e(df_r)' // number of clusters - 1 
									 // t-test DoF for clustered s.e.

				//---------------------------------
				// control mean and SD (BL optional) & share of zeros
				reg_stats `var' `treatvar' reg_obs, var_count(`var_count')			///
													bl_ctrl_var(`bl_ctrl_var') 		///
													cluster_var(`cluster_var') 		///
													strata_var(`strata_var') 		///
													weight_var(`weight_var') 		///
													perm(`perm') qui	
				matrix fu_mat = r(fu_mat)
				//  mean of `var' for control treatment
				local esttab_stats  control_mean 
				local esttab_labs `""Control mean""' 
				if "`perm'" != "" {
					local perm_stats `r(mgnpt)'
					local perm_labs `""Permutation T-test""'
				}
				else {
					local perm_stats 
					local perm_labs  ""								
				}
				
				drop reg_obs  // drop e(sample) var generated for each var in step 4.1.2
				local var_count = `var_count' + 1
				if "`bl_ctrl_var'" != "" local blvar_count = `blvar_count' + 1
				
			} // close var loop

			****----------------------------------------------------------------
			****  4.4 Tex output
			
			// add resizebox before and after. 
			local --var_count // overcounts by 1
			if      `var_count' == 3 local tab_resize "0.65\textwidth" // Portray mode    might not be the ideal cutoff everytime
			else if `var_count' == 4 local tab_resize "0.72\textwidth" // Portray mode    might not be the ideal cutoff everytime
			else if `var_count' == 5 local tab_resize "0.80\textwidth" // Portray mode    might not be the ideal cutoff everytime
			else if `var_count' == 6 local tab_resize "1.05\textwidth" // Landscape mode  might not be the ideal cutoff everytime
			else if `var_count' == 7 local tab_resize "1.10\textwidth" // Landscape mode  might not be the ideal cutoff everytime
			else if `var_count' == 8 local tab_resize "1.15\textwidth" // Landscape mode  might not be the ideal cutoff everytime
			else if `var_count' >= 9 local tab_resize "1.20\textwidth" // Landscape mode  might not be the ideal cutoff everytime
			
			if 	strpos("`section'", "supp_26") > 0 | ///
				strpos("`section'", "supp_30") > 0 | strpos("`section'", "supp_38") > 0 {
				local tab_resize "1.00\textwidth" // usually landscape but not portray 
			}
			else if strpos("`section'", "supp_32_") > 0 {
				local tab_resize "0.72\textwidth" // usually landscape but not portray 				
			}
			else if strpos("`section'", "supp_29_") > 0 {
				local tab_resize "0.63\textwidth" // usually landscape but not portray 				
			}		
			else if strpos("`section'", "prim5b_") > 0 {
				local tab_resize "0.62\textwidth" // usually landscape but not portray 				
			}				
			else if strpos("`section'", "supp_10_") > 0 {
				local tab_resize "0.68\textwidth" // usually landscape but not portray 				
			}			
			else if strpos("`section'", "supp_27_") > 0 {
				local tab_resize "0.85\textwidth" // usually landscape but not portray 				
			}
			else if strpos("`section'", "prim3_") > 0 {
				local tab_resize "0.98\textwidth" // usually landscape but not portray 				
			}
			else if strpos("`section'", "prim6_") > 0 {
				local tab_resize "0.90\textwidth" // usually landscape but not portray 				
			}

			// any BL estimates to be dropped from the table drop if they exist in section
			if `blvar_count' != 0 local dropbl `blvars' 
			else 			  local dropbl 
			
			// if output folder DNE, print error message
			local outputfolder "${output}/tables/Followup"
			capture confirmdir "`outputfolder'"
		
			// Labels groups of models at the top of the table heading for specific tables.
			#delimit ;
			
			if strpos("`section'", "prim1_hh_t") > 0 | strpos("`section'", "prim1_hh1_t") > 0 | strpos("`section'", "prim1_hh2_t") > 0 local text_n_pattern 
				`"
					"Consumption"
					"Food Security"
					"",
					pattern(1 0 0 1 0 0 1)
				"';
			else if strpos("`section'", "prim2_ben_t") > 0 local text_n_pattern 
				`"
					"Social Well-Being"
					"Psychological Well-Being"
					"Women Empowerment",
					pattern(1 0 0 0 0 1 0 0 1 0 0 0)
				"';	
			else if strpos("`section'", "prim5_ben_t") > 0 | strpos("`section'", "prim5_chef_t") > 0 local text_n_pattern 
				`"
					"All Salaried Employment"
					"Agricultural Employment",
					pattern(1 0 0 1 0 0)
				"';
			else if strpos("`section'", "prim6_ben_t") > 0 local text_n_pattern 
				`"
					"Livestock"
					"Savings",
					pattern(1 0 0 0 1 0)
				"';	
			else if strpos("`section'", "supp_9_t") > 0 local text_n_pattern 
				`"
					"Assets"
					"Debt"
					"Lend"
					"Transfer",
					pattern(1 0 1 0 1 0 1 0 0 0)
				"';
			else if strpos("`section'", "scnd5_t") > 0 local text_n_pattern 
				`"
					"Consumption"
					"Food Security Indicators"
					"",
					pattern(1 0 1 0 0 1)
				"';
			else if strpos("`section'", "supp_26_t") > 0 local text_n_pattern 
				`"
					"Cultivated Crops"
					"Sold Crops",
					pattern(1 0 0 0 1 0 0 0)
				"';
			else if strpos("`section'", "supp_38_t") > 0 local text_n_pattern 
				`"
					"Perceptions of How Benef. Were Selected"
					"",
					pattern(1 0 0 0 0 0 1)
				"';
			else if strpos("`section'", "supp_39_t") > 0 local text_n_pattern 
				`"
					"Situation After PM is:"
					""
					"Patner/HH Members Were:"
					"",
					pattern(1 0 0 0 0 1 1 0 0 1)
				"';
			else if strpos("`section'", "supp_40_t") > 0 local text_n_pattern 
				`"
					"Perceptions of How CT Benef. Were Selected"
					"Before CT Program Began, Benef. HH Were"
					"",
					pattern(1 0 0 0 0 0 1 0 0 1)
				"';
			else if strpos("`section'", "supp_41_t") > 0 local text_n_pattern 
				`"
					"CT Program Selection Steps"
					"Intra-HH Tensions due to CT Program"
					"CT Program Affected Community Relations"
					"",
					pattern(1 0 0 1 0 0 0 1 0 0 1)
				"';
			else if strpos("`section'", "supp_42_t") > 0 local text_n_pattern 
				`"
					"Village Trust Affected by CT:"
					"Community Support Affected by CT:"
					"Community Involvment Affected by CT:"
					"Community Proximity Affected by CT:",
					pattern(1 0 0 1 0 0 1 0 0 1 0 0)
				"';			
			else 
			
			local text_n_pattern ; // empty
			
			if !missing(`"`text_n_pattern'"') 
				local mgrouplocal 
				`"
					mgroups(
					`text_n_pattern'					
					prefix(\multicolumn{@span}{c}{)			
					suffix(})							
					span 						  		
					erepeat(\cmidrule(lr){@span}) 		
					)
				"';
			/* 
			define how the models are grouped, prefix added to the label, suffix added to the label,
			causes labels to span columns, \cmidrule(lr) repeated for each group of spanned columns
			*/
			else local mgrouplocal ; // empty
			
			#delimit cr
			
			
			**** define panel 
			
			if strpos("`section'", "_ben_t1") > 0 | ///
			   strpos("`section'", "_ben_t2") > 0 | ///
			   strpos("`section'", "_ben_t3") > 0 {
				local option_note     "nonotes"
				local option_posthead `"posthead("\hline \\ \multicolumn{@span}{l}{\textbf{Panel A: Eligible Individual (woman)}} \\\\[-1ex]")"'
				local option_line     "nolines"
				local option_resize   "yes"		
			}		
			else if strpos("`section'", "scnd7_t3") > 0  | ///
					strpos("`section'", "scnd8_t3") > 0  | ///
					strpos("`section'", "scnd9_t3") > 0  | ///	
					strpos("`section'", "scnd5_t3") > 0 | ///
					strpos("`section'", "scnd6_t3") > 0  | ///
					strpos("`section'", "_hh_t3")   > 0  | ///
					strpos("`section'", "_hh1_t3")   > 0  | ///
					strpos("`section'", "_hh2_t3")   > 0  | ///
					strpos("`section'", "_beno_t3") > 0  | ///
					strpos("`section'" , "supp_")   > 0 {
				local option_note     "nonotes"
				local option_posthead `"posthead("\hline \\")"'
				local option_line     "nolines"
				local option_resize   "yes"					
			}
			else {
				#delimit ;
				local option_note     			
				`" 
						 postfoot("\hline\hline" 		
						 "\end{tabular} %firsttabular " 
						 " " 							
						 "\vspace{3pt}" 				
						 " " 							
						 "\begin{tabular}{p{`tab_resize'}} %secondtabular" 
						 "\footnotesize \textit{Notes:} " 
						 "`allnotes'" 					
						 "\end{tabular}" 				
						 "\end{table}" ) 
				"' ; 			
				#delimit cr
				local option_posthead ""
				local option_line     ""
				local option_resize   ""	
			}	
			
			// output
			qui esttab using "`outputfolder'/outcome_table_`section'.tex", ///
				`option_posthead'                       ///
				style(tex)								/// tex style for the output table
				title("`table_title'") 	 				/// Title. If table is small, "-" separates
				mlabels(`mylabels')						/// label the models with label of dependent variable
				nomtitles 								/// suppresses printing of model titles Old: mtitles(`"`titles'"')
				`mgrouplocal'         			        /// labels groups of models for specific tables.
				b(%9.3fc)                               /// coefficient, format specificed 
				se(%9.3fc)                              /// standard error coefficient, format specificed
				star(* 0.10 ** 0.05 *** 0.01)           /// report significance stars
				stats(N 								/// Observations 
					  `esttab_stats'					/// scalar statistics displayed at the bottom of the table 
					  `perm_stats', 					/// permutation t-test	
					  fmt(%9.0f)						/// Formatting for first stat
					  labels("Observations"				/// Observations 
							`esttab_labs'				/// Statistics labels	
							`perm_labs'))				/// Statistics labels	 
				label									/// use variable labels
				varwidth(10)							/// set width of the table's left stub, didn't test if these are useful
				modelwidth(10)							/// set width of the results columns, didn't test if these are useful
				drop(_cons `dropbl' *.strata) 			/// coefficients dropped from the table
				numbers 								/// number models in parentheses
				nogaps									/// remove empty rows, suppress the extra spacing between coefficients to increase readability
				`option_line'							///
				nobaselevels 							/// drops base levels of factor variables
				noconstant								/// remove constant since control mean listed in stats
				`option_note'							///
				replace									 //  Append or replace?
			
			// latex manual edits (overwrites esttab output) 
			tex_resize, 		quietly file("`outputfolder'/outcome_table_`section'.tex") /// add a latex hyperlink in label after the caption line
								tab_resize(`tab_resize') first("`option_resize'")
		} 		
		else {
			eststo clear 				  // for estout
			local blvar_count = 0		  // count bl vars per section
			local var_count = 1 		  // for suest estadd command
			local var_count_tot : word count ``section''
			local no_of_sections : word count `lists' // for est_collect_long
			local mylabels 				// empty			
			
			foreach var in ``section'' { 
				
				dis "Variable: `var'"

				qui regs_labels, section("`section'") stack_opt(vertical)
						
				****----------------------------------------------------------------
				****  4.2.1 Extract variable labels
				
				// collect variable labels in Tex friendly format
				// this program returns r(mylabels) and r(returnlocal)
				stack_concat_varlabs, lab("`: var label `var''") ///
									  section("`section'") ///
									  var_count(`var_count') ///
									  var_count_tot(`var_count_tot') ///
									  returnlocal("titles_`section'") ///
									  recurstitles("`titles_`section''") 

				local titles_`section' = "`r(titles_`section')'"
				local templab = subinstr("`r(mylabels)'", "&", "", .)
				
				// concatenate varlabels
				if strlen(`"`mylabels'"') == 0 local mylabels `" "`templab'" "'
				else 				   		   local mylabels `" `mylabels' "`templab'" "'
												
				****----------------------------------------------------------------
				****  4.2.2 run regressions
								
				** Regression treatment, cluster, and strata
					
				if strpos("`section'", "_t1") > 0 {
					local treatvar 	pm_treatment
				}
				else if strpos("`section'", "_t2") > 0 {
					local treatvar	both_spillover_dummy
				}
				else if strpos("`section'", "_t3") > 0 {
					local treatvar	ct_spillover_dummy
				}				
				else if strpos("`section'", "_t4") > 0 {
					local treatvar	non_ct_spillover_dummy
				}	
					
				local cluster_var 	p_village
				local strata_var 	strata
				if "${w_lvl}" == "village" 	local weight_var weight_vil 
				if "${w_lvl}" == "overall" 	local weight_var weight_ovrl
				if "${w_lvl}" == "prop_g2" 	local weight_var weight_g2
					
				** Regression extras: bl_ctrl_var bl_ctrl_dum 
				// check if bl version exists
				//  if the exact same bl outcome exists, use that instead.
				// else if no bl outcome exists, empty local - can't control for bl (no ancova)
				capture confirm variable `var'_bl
				if _rc == 0 {
					local bl_ctrl_var `var'_bl    
				}
				else if _rc != 0 {
					local bl_ctrl_var     
				}
				
				** condition 
				if strpos("`section'", "_chef_") > 0 {
					local condition "if same_cb != 1"
				}
				else {
					local condition ""
				}
					
				** Run Regression
				qui	eststo :  reg `var' i.`treatvar' 	 		   	/// treatment 
										`bl_ctrl_var'    		    /// bl controls (wherever available)
										i.`strata_var'				///
										[pw = `weight_var']			///
										`condition', 		   		///
										cluster(`cluster_var') 	    //

				** Collect main items from return list for later use 
				qui gen reg_obs = e(sample) // used within each var loop and dropped at the end of the loop
				matrix my_reg = r(table) // collect results
	
				****----------------------------------------------------------------
				****  4.2.3 store group averages and error bars (for ppt) main spec only
					
				//---------------------------------
				// Sample size
					local n_reg = `e(N)'
					local df 	= `e(df_r)' // number of clusters - 1 
											// t-test DoF for clustered s.e.

				//---------------------------------
				// control mean and SD (BL optional) & share of zeros
				// control mean and SD (BL optional) & share of zeros
				reg_stats `var' `treatvar' reg_obs, var_count(`var_count')			///
													bl_ctrl_var(`bl_ctrl_var') 		///
													cluster_var(`cluster_var') 		///
													strata_var(`strata_var') 		///
													weight_var(`weight_var') 		///
													perm(`perm') qui	
				matrix fu_mat =  r(fu_mat)

				local esttab_stats  control_mean 	  //  mean of `var' for control treatment if no het var 
				local esttab_labs `""Control mean""'
				if "`perm'" != "" {
					local perm_stats `r(mgnpt)'
					local perm_labs  `""Permutation T-test""'				
				}
				else {
					local perm_stats 
					local perm_labs  ""								
				}
					
				drop reg_obs  // drop e(sample) var generated for each var in step 4.1.2
				local var_count = `var_count' + 1
				if "`bl_ctrl_var'" != "" local blvar_count = `blvar_count' + 1
				
			} // close var loop
			
			****----------------------------------------------------------------
			****  4.4 Tex output
			
			// add resizebox before and after. 
			local --var_count // overcounts by 1
			if      `var_count' == 3 local tab_resize "0.65\textwidth" // Portray mode    might not be the ideal cutoff everytime
			else if `var_count' == 4 local tab_resize "0.72\textwidth" // Portray mode    might not be the ideal cutoff everytime
			else if `var_count' == 5 local tab_resize "0.80\textwidth" // Portray mode    might not be the ideal cutoff everytime
			else if `var_count' == 6 local tab_resize "1.05\textwidth" // Landscape mode  might not be the ideal cutoff everytime
			else if `var_count' == 7 local tab_resize "1.10\textwidth" // Landscape mode  might not be the ideal cutoff everytime
			else if `var_count' == 8 local tab_resize "1.15\textwidth" // Landscape mode  might not be the ideal cutoff everytime
			else if `var_count' >= 9 local tab_resize "1.20\textwidth" // Landscape mode  might not be the ideal cutoff everytime
			
			if 	strpos("`section'", "supp_26") > 0 | ///
				strpos("`section'", "supp_30") > 0 | strpos("`section'", "supp_38") > 0 {
				local tab_resize "1.00\textwidth" // usually landscape but not portray 
			}
			else if strpos("`section'", "supp_32_") > 0 {
				local tab_resize "0.72\textwidth" // usually landscape but not portray 				
			}
			else if strpos("`section'", "supp_29_") > 0 {
				local tab_resize "0.63\textwidth" // usually landscape but not portray 				
			}		
			else if strpos("`section'", "prim5b_") > 0 {
				local tab_resize "0.62\textwidth" // usually landscape but not portray 				
			}				
			else if strpos("`section'", "supp_10_") > 0 {
				local tab_resize "0.68\textwidth" // usually landscape but not portray 				
			}			
			else if strpos("`section'", "supp_27_") > 0 {
				local tab_resize "0.85\textwidth" // usually landscape but not portray 				
			}
			else if strpos("`section'", "prim3_") > 0 {
				local tab_resize "0.98\textwidth" // usually landscape but not portray 				
			}
			else if strpos("`section'", "prim6_") > 0 {
				local tab_resize "0.90\textwidth" // usually landscape but not portray 				
			}
						
			// any BL estimates to be dropped from the table drop if they exist in section
			if `blvar_count' != 0 local dropbl `blvars' 
			else 			  local dropbl 
			
			// if output folder DNE, print error message
			local outputfolder "${output}/tables/Followup"
			capture confirmdir "`outputfolder'"

			**** define panel
			if "`final_panel'" == "yes" {
				if strpos("`section'", "_chef_t1") > 0 | ///
				   strpos("`section'", "_chef_t2") > 0 {
					local option_posthead `"posthead("\hline \\ \multicolumn{@span}{l}{\textbf{Panel B: Household Head (man)}} \\\\[-1ex]")"'
					local option_resize   ""	
					local old_section   = subinstr("`section'","_chef_t", "_ben_t", .)
				}
				else if strpos("`section'", "_chef_t4") > 0 {
					local option_posthead `"posthead("\hline \\")"'
					local option_resize   ""	
					local old_section   = subinstr("`section'","_chef_t4", "_ben_t3", .)					
				}
				else if strpos("`section'" , "supp_") > 0 {
					local option_posthead `"posthead("\hline \\")"'
					local option_resize   ""	
					local old_section   = subinstr("`section'","_t4", "_t1", .)					
				}				
				else if strpos("`section'", "_hh_t4")   > 0 | ///
						strpos("`section'", "_hh1_t4")  > 0 | ///
						strpos("`section'", "_hh2_t4")  > 0 | ///
						strpos("`section'", "_beno_t4") > 0 | ///
						strpos("`section'", "5_t4") 	> 0 | ///
						strpos("`section'", "6_t4") 	> 0 | ///
						strpos("`section'", "7_t4") 	> 0 | ///
						strpos("`section'", "8_t4") 	> 0 | ///
						strpos("`section'", "9_t4") 	> 0 {
					local option_posthead `"posthead("\hline \\")"'
					local option_resize   ""	
					local old_section   = subinstr("`section'","_t4", "_t3", .)				
				}
				else {
					local old_section     ""
					local option_posthead ""
					local option_resize   ""
				}
				#delimit ;
				local option_note     			
				`" 
						 postfoot("\hline\hline" 		
						 "\end{tabular} %firsttabular " 
						 " " 							
						 "\vspace{3pt}" 				
						 " " 							
						 "\begin{tabular}{p{`tab_resize'}} %secondtabular" 
						 "\footnotesize \textit{Notes:} " 
						 "`allnotes'" 					
						 "\end{tabular}" 				
						 "\end{table}" ) 
				"' ; 			
				#delimit cr
			}
			else if "`scond_panel'" == "yes" {
				if strpos("`section'", "_ben_t4") > 0 {
					local option_posthead `"posthead("\hline \\")"'
					local option_resize   ""	
					local old_section   = subinstr("`section'","_ben_t4", "_ben_t3", .)						
				}
				else if strpos("`section'" , "supp_") > 0 {
					local option_posthead `"posthead("\hline \\")"'
					local option_resize   ""	
					local old_section   = subinstr("`section'","_t2", "_t1", .)							
				}
				local option_note "nonotes"
			}
			else if "`third_panel'" == "yes" {
				if strpos("`section'", "_chef_t3") > 0 {
					local option_posthead `"posthead("\hline \\ \multicolumn{@span}{l}{\textbf{Panel B: Household Head}} \\\\[-1ex]")"'
					local option_resize   ""	
					local old_section   = subinstr("`section'","_chef_t", "_ben_t", .)					
				}
				else if strpos("`section'" , "supp_") > 0 {
					local option_posthead `"posthead("\hline \\")"'
					local option_resize   ""	
					local old_section   = subinstr("`section'","_t3", "_t1", .)						
				}
				local option_note "nonotes"
			}			

			local section `old_section'
			
			// output
			qui esttab using "`outputfolder'/outcome_table_`section'.tex", ///
				`option_posthead'                       ///
				fragment								///
				style(tex)								/// tex style for the output table
				b(%9.3fc)                               /// coefficient, format specificed 
				se(%9.3fc)                              /// standard error coefficient, format specificed
				star(* 0.10 ** 0.05 *** 0.01)           /// report significance stars
				stats(N 								/// Observations 
					  `esttab_stats' 					/// scalar statistics displayed at the bottom of the table 	
					  `perm_stats',						/// permutation t-test			
					  fmt(%9.0f)						/// Formatting for first three stats
					  labels("Observations"				/// Observations 
							 `esttab_labs'				/// Statistics labels	
							 `perm_labs'))				/// Statistics labels	 
				label									/// use variable labels
				varwidth(10)							/// set width of the table's left stub, didn't test if these are useful
				modelwidth(10)							/// set width of the results columns, didn't test if these are useful
				drop(_cons `dropbl' *.strata) 			/// coefficients dropped from the table
				nomtitles nonumbers nolines		 		/// for bottom panel only
				nogaps									/// remove empty rows, suppress the extra spacing between coefficients to increase readability
				nobaselevels 							/// drops base levels of factor variables
				noconstant								/// remove constant since control mean listed in stats
				`option_note'							///
				append 
			
			// latex manual edits (overwrites esttab output)
			if "`final_panel'" == "yes" {
				tex_resize, 		quietly file("`outputfolder'/outcome_table_`section'.tex") /// add a latex hyperlink in label after the caption line
									tab_resize(`tab_resize') first("`option_resize'") section("`section'")					
			}								
		}
					
		tex_add_hyperlink,  quietly file("`outputfolder'/outcome_table_`section'.tex") /// add latex resizebox
										section("`section'")
		local section_n = `section_n' + 1 // needed for 4.1.5 to work
	} // close foreach `section' loop
