/*******************************************************************************
Title: 06_balance_and_attrition.do
This script prepares the baseline balance table.

  Outline:
	** -----| 1) import baseline balance variables
	** -----| 2) set table list
	** -----| 3.a) set table name
	** -----| 3.b) set table segment name
	** -----| 3.c) set treatment variable
	** -----| 3.d) set condition	
	** -----| 3.e) set observation line 
	** -----| 4.a) collect variables
	** -----| 4.b) label variables 	
	** -----| 4.c) footnotes	
	** -----| 4.d) run balance code	
	** -----| 5.a) merge horizontally
	** -----| 5.b) remove temporary files
	** -----| 5.c) adjust column numbers 
*******************************************************************************/
  
set seed ${n_seed}
  
** -----| 1) import baseline balance variables
use "${data_dir}/baseline_CHAD_hh.dta", clear

** -----| 2) set table list

local balance_table_list balance_t1 balance_t2 balance_t3 balance_t4 			// balance_pc_t1 balance_pc_t2 balance_pc_t3 balance_pc_t4
																				// balance_gr_t1 balance_gr_t2 balance_gr_t3 balance_gr_t4						 
local bal_ct = 0

foreach section of local balance_table_list {
	local bal_ct = `bal_ct' + 2
	
	preserve 	 
	 
	if (strpos("`section'", "_t1") > 0)  local treatment_type "PM Treatment" 
	if (strpos("`section'", "_t2") > 0)  local treatment_type "Pooled Spillover"
	if (strpos("`section'", "_t3") > 0)  local treatment_type "CT Spillover" 
	if (strpos("`section'", "_t4") > 0)  local treatment_type "Non-CT Spillover"
	 
	** -----| 3.a) set table name 
	if (strpos("`section'", "_t1") > 0)    local title "Table A`bal_ct': Balance Table - `treatment_type' Specification"
	if (strpos("`section'", "_t2") > 0)    local title "Table A`bal_ct': Balance Table - `treatment_type' Specification"
	if (strpos("`section'", "_t3") > 0)    local title "Table A`bal_ct': Balance Table - `treatment_type' Specification"	
	if (strpos("`section'", "_t4") > 0)    local title "Table A`bal_ct': Balance Table - `treatment_type' Specification"
	
	** -----| 3.b) set table segment name
	local header_1 "Panel A: Household"
	local header_2 "Panel B: Eligible Individual (woman)"
	local header_3 "Panel C: Household Head (man) - Eligible Individual Excluded"
	local header_4 "Panel D: Response Rate"

	** -----| 3.c) set treatment variable
	if (strpos("`section'", "_t1") > 0)  local treatvar pm_treatment 
	if (strpos("`section'", "_t2") > 0)  local treatvar both_spillover_dummy
	if (strpos("`section'", "_t3") > 0)  local treatvar ct_spillover_dummy 
	if (strpos("`section'", "_t4") > 0)  local treatvar non_ct_spillover_dummy
	
	** -----| 3.d) set condition 
	local condition1 "if survey_bl == 1 & `treatvar' != ."
	local condition2 "if survey_bl == 1 & `treatvar' != ."
	local condition3 "if survey_bl == 1 & `treatvar' != . & same_cb == 0" 
	local condition4 "if 				  `treatvar' != ."
	
	** -----| 3.e) set observation line 
	forvalues s = 1/4 {
		qui count `condition`s'' & `treatvar' == 0
		local ctrl `r(N)'
		qui count `condition`s'' & `treatvar' == 1
		local trt  `r(N)'
		local nobs`s' "N & `ctrl' & `trt' & \\"	
		nois dis "`nobs`s''"
	}

	** -----| 4.a) collect variables 
	
	if (strpos("`section'", "_pc_") > 0) {
		local seg1	mem_n equiv_n poly same_cb										///
					food_index4 FIES_rvrs_raw FCS_W diversity_score 				///
					food_day_pc_xof nonfood_day_pc_xof consum_day_pc_xof		
	}
	else if (strpos("`section'", "_gr_") > 0) {
		local seg1	mem_n equiv_n poly same_cb										///
					food_index4 FIES_rvrs_raw FCS_W diversity_score 				///
					food_day_xof nonfood_day_xof consum_day_xof		
	}	
	else {
		local seg1	mem_n equiv_n poly same_cb										///
					food_index4 FIES_rvrs_raw FCS_W diversity_score 				///
					food_day_eq_xof nonfood_day_eq_xof consum_day_eq_xof
					
		local seg2	ctben_fem ctben_age ctben_edu									///
					ment_hlth_index gse_index soc_stand_index						///
					ctben_ag_12 tot_ben_ag_days ag_r_hrv_ben_xof_98 				///
					ag_plot_n_benef ag_plot_ha_benef ctben_na_12 tot_ben_bus_days 	///
					tot_ben_pro12_98 na_bus2_op_wn_12_ben bus_assval_98_ben
									
		local seg3 	hhh_fem hhh_age hhh_edu 										///
					hhh_ag_12 ag_r_hrv_chef_xof_98 ag_plot_n_chef					/// 
					ag_plot_ha_chef hhh_na_12 tot_chef_bus_days 					///
					tot_chef_pro12_98 na_bus2_op_wn_12_chef bus_assval_98_chef 
			
		local seg4  attrition_fu attrition_blfu	 				
	}	

	** -----| 4.b) label variables 
	
	label var mem_n						"No. of Household Members"
	label var equiv_n 					"No. of Adult Equivalent"
	label var poly 						"Polygamous Household"
	label var same_cb					"HH head is also Eligible Individual"
	label var food_index4 				"Welfare and Food security Z-score"
	label var FIES_rvrs_raw 			"Food Security"
	label var FCS_W 					"Food Consumption Score"
	label var diversity_score 			"Dietary Diversity Score"
	label var food_day_xof 				"Daily Food Consumption (FCFA)"
	label var nonfood_day_xof 			"Daily Non-Food Consumption (FCFA)"
	label var consum_day_xof 			"Total Daily Consumption (FCFA)"
	label var food_day_pc_xof 			"Daily Food Consumption (FCFA, per capita)"
	label var nonfood_day_pc_xof 		"Daily Non-Food Consumption (FCFA, per capita)"
	label var consum_day_pc_xof 		"Total Daily Consumption (FCFA, per capita)"
	label var food_day_eq_xof 			"Daily Food Consumption (FCFA, ad. equiv.)"
	label var nonfood_day_eq_xof 		"Daily Non-Food Consumption (FCFA, ad. equiv.)"
	label var consum_day_eq_xof 		"Total Daily Consumption (FCFA, ad. equiv.)"
	
	label var ctben_fem 				"Female"
	label var ctben_age 				"Age"
	label var ctben_edu 				"Years of Education"	
	label var ment_hlth_index			"Mental Health Z-Index"
	label var gse_index					"Self Efficacy Z-Index"
	label var soc_stand_index			"Social Standing Z-Index"
	label var ctben_ag_12  				"Head Works in Agriculture" 
	label var tot_ben_ag_days			"No. of Days Worked in Agriculture (per rainy season)"
	label var ag_r_hrv_ben_xof_98 		"Harvest Value (1000 FCFA)"
	label var ag_plot_n_benef 			"No. of Plots Owned/Managed"
	label var ag_plot_ha_benef 			"Area of Plots Owned/Cultivated (ha)"	 
	label var ctben_na_12  				"Works in Non-Ag Business" 
	label var tot_ben_bus_days 			"No. of Days Worked in Non-Ag Business (per month)"	 
	label var tot_ben_pro12_98 			"Profits (yearly, 1000 FCFA)"
	label var na_bus2_op_wn_12_ben 		"No. of Businesses Owned/Managed."
	label var bus_assval_98_ben 		"Business Assets (1000 FCFA)"
	 
	label var hhh_fem 					"Female"
	label var hhh_age 					"Age"
	label var hhh_edu 					"Years of Education"
	label var hhh_ag_12 				"Works in Agriculture"
	label var ag_r_hrv_chef_xof_98 		"Harvest Value (1000 FCFA)"
	label var ag_plot_n_chef    		"No. of Plots Owned/Managed"
	label var ag_plot_ha_chef  			"Area of Plots Owned/Cultivated(ha)"
	label var hhh_na_12  				"Works in Non-Ag Business" 
	label var tot_chef_bus_days 		"No. of Days Worked in Non-Ag Business (per month)"
	label var tot_chef_pro12_98 		"Business Profits (yearly, 1000 FCFA)" 
	label var na_bus2_op_wn_12_chef 	"No. of Businesses Owned/Managed"
	label var bus_assval_98_chef 		"Business Assets (1000 FCFA)"	 
	
	label var attrition_fu				"Response Rate at Follow-Up"
	label var attrition_blfu			"Response Rate Baseline to Follow-Up"
	 
** -----| 4.c) footnotes
	#delimit ;
	local table_note1 "Standard errors for all tests are clustered at 
						the village level." ;
	local table_note2 "Fixed effects using randomization strata are 
						included in all estimation regressions." ;
	local table_note3 "Both asymptotic and permutation p-values are computed for the 
						pairwise tests. The randomization inference tests are performed 
						with `=string(${n_reps}, "%9.0fc")' permutations, preserving 
						both the randomization strata and the cluster structure." ;						
	local table_note4 "*** p $<$ 0.01, ** p $<$ 0.05, * p $<$ 0.1." ;
	#delimit cr
	
	foreach note in table_note1 table_note2 table_note3 table_note4 {
		local `note' = trim("``note''")
	}

	** -----| 4.d) run balance code
	
	if (strpos("`section'", "_pc_") > 0) | (strpos("`section'", "_gr_") > 0)  {
	tex_stack_iebaltab, ///
	    table_name(`section') table_title(`title') 								///	
		treat_var(`treatvar') cluster_var(p_village)							///
		seg1(`seg1') seg1_header(`header_1') seg1_condi(`condition1') 			///
		nobs_row1(`nobs1') 														///
		seg1_wei("yes") 														///
		table_note1(`table_note1') 												/// 
		table_note2(`table_note2') 												/// 
		table_note3(`table_note3') 												/// 
		table_note4(`table_note4') 												/// 
		indentthese(`""Follow-up 1""') 											///
		no_strata(`no_strata')        	 										///
		no_onerow("yes")        	 											///
		permute_pvalue("yes")													///
		qui 	
	}	
	else {
	tex_stack_iebaltab, ///
	    table_name(`section') table_title(`title') 								///	
		treat_var(`treatvar') cluster_var(p_village)							///
		seg1(`seg1') seg1_header(`header_1') seg1_condi(`condition1') 			///
		seg2(`seg2') seg2_header(`header_2') seg2_condi(`condition2') 			///
		seg3(`seg3') seg3_header(`header_3') seg3_condi(`condition3') 			///
		seg4(`seg4') seg4_header(`header_4') seg4_condi(`condition4') 			///
		nobs_row1(`nobs1') nobs_row2(`nobs2') nobs_row3(`nobs3')				///
		seg1_wei("yes") seg2_wei("yes") seg3_wei("yes")							///
		table_note1(`table_note1') 												/// 
		table_note2(`table_note2') 												/// 
		table_note3(`table_note3') 												/// 
		table_note4(`table_note4') 												/// 
		indentthese(`""Follow-up 1""') 											///
		no_strata(`no_strata')        	 										///
		no_onerow("yes")        	 											///
		permute_pvalue("yes")													///
		qui 				
	}

	restore 
}

** -----| 5.a) merge horizontally

local balance_table_list balance 												// balance_pc balance_gr
foreach section of local balance_table_list {						 
	foreach i in 1 3 {
		local j = `i' + 1

		import delimited "${output_balance}/`section'_t`i'_si1.tex", delim(",") charset(utf8) clear
		fix_import	
		gen id = _n 
		replace text = ustrtrim(text)
		tempfile balance_t`i'_si1	
		save	`balance_t`i'_si1'	
			
		import delimited "${output_balance}/`section'_t`j'_si1.tex", delim(",") charset(utf8) clear
		fix_import	
		gen id = _n
		replace text = ustrtrim(text)
		tempfile balance_t`j'_si1	
		save	`balance_t`j'_si1'
				
		use `balance_t`i'_si1', clear 
		rename text text0
		merge 1:1 id using `balance_t`j'_si1', nogen

		// adjustments
		replace text0 = "" if inrange(id, 12, 20) | inrange(id, 1, 3) | inlist(id, 7)
		replace text0 = "" if strpos(text0, "\multicolumn{4") > 0 | strpos(text0, "\end{longtable}") > 0		
		replace text0 = subinstr(text0, "\\ \hline \\[-1.8ex]", "", .)	
		replace text0 = subinstr(text0, "\hline \hline \\[-1.8ex]", "", .)
		replace text0 = subinstr(text0, "& \\ [1ex]", "&", .)
		replace text0 = subinstr(text0, "] \\ [1ex]", "] ", .)
		replace text0 = subinstr(text0, "%\\", "", .)
		replace text0 = subinstr(text0, "\\", "", .)	
		replace text = "\begin{longtable}{lcccccc}" if id == 1
		replace text = subinstr(text, "\multicolumn{4}", "\multicolumn{7}", .)	
		replace text = subinstr(text, "\multicolumn{1}{c}{(1)}", "\multicolumn{1}{c}{(5)}", .)
		replace text = subinstr(text, "\multicolumn{1}{c}{(2)}", "\multicolumn{1}{c}{(6)}", .)
		replace text = subinstr(text, "\multicolumn{1}{c}{(1)-(2)}", "\multicolumn{1}{c}{(5)-(6)}", .)

		// merge 
		gen pos_delete = strpos(text, "&") 
		replace text = substr(text, pos_delete, .) if pos_delete > 1
		replace text0 = text0 + " " + text
		keep text0 
		
		// fix title 
		if (strpos("`section'", "_pc") > 0) {
			if (`i' == 1) local treatment_type "direct impacts and spillovers, per capita cons." 
			if (`i' == 3) local treatment_type "decomposition of spillovers, per capita cons." 		
		}
		else if (strpos("`section'", "_gr") > 0) {
			if (`i' == 1) local treatment_type "direct impacts and spillovers, gross cons." 
			if (`i' == 3) local treatment_type "decomposition of spillovers, gross cons." 		
		}
		else {
			if (`i' == 1) local treatment_type "direct impacts and spillovers" 
			if (`i' == 3) local treatment_type "decomposition of spillovers" 		
		}

		replace text0 = subinstr(text0, "Balance Table", "Balance table", .) if strpos(text0, "\caption{") | strpos(text0, "{c}{{\bfseries")
		replace text0 = subinstr(text0, "Pooled Spillover Specification", "`treatment_type'", .) if strpos(text0, "\caption{") | strpos(text0, "{c}{{\bfseries")
		replace text0 = subinstr(text0, "Non-CT Spillover Specification", "`treatment_type'", .) if strpos(text0, "\caption{") | strpos(text0, "{c}{{\bfseries")
		
		if (strpos("`section'", "_pc") > 0) {
			replace text0 = subinstr(text0, "Table A12", "Table S1", .)
			replace text0 = subinstr(text0, "Table A16", "Table S15", .)			
		}
		else if (strpos("`section'", "_gr") > 0) {
			replace text0 = subinstr(text0, "Table A20", "Table S2", .)
			replace text0 = subinstr(text0, "Table A24", "Table S16", .)			
		}
		else {
			replace text0 = subinstr(text0, "Table A4", "Table 1", .)
			replace text0 = subinstr(text0, "Table A8", "Table A1", .)			
		}
		replace text0 = subinstr(text0, "\textit{Notes},", "\textit{Notes}:", .)	
		
		rename text0 text 
		outfile using "${output_balance}/`section'_`i'.tex", noquote wide replace
	}
}

** -----| 5.b) remove temporary files
				
	// list all .tex files in directory 
	local list_files: dir "${output_balance}" files "*tex"
	foreach file of local list_files {
		if (strpos("`file'", "_seg") > 0) | (strpos("`file'", "_si1") > 0) | (strpos("`file'", "_allsegments_final") > 0) {
			erase "${output_balance}/`file'"
		}
	}
	
** -----| 5.c) adjust column numbers 

foreach i in 1 3 {
	import delimited "${output_balance}/balance_`i'.tex", delim(",") charset(utf8) clear
	fix_import	
	replace text = subinstr(text, "(5)", "(3)", .)
	replace text = subinstr(text, "(6)", "(4)", .)
	outfile using "${output_balance}/balance_`i'.tex", noquote wide replace
}
