/*******************************************************************************
Title: 07_cba.do
This do-file prepares Cost - Benefit analysis data
Generates table cba.
									
	Outline:
	** -----| 1) Import data
	** -----| 2) Retrieve Costs Data from Administrative Data
	** -----| 3) CBA Table: Daily Food Consumption per adult equiv 
	** -----| 4) NPV & IRR 
	** -----| 5) Prepare latex file
	** -----| 6) Prepare latex file	
*******************************************************************************/

** -----| 1) Import data

use "${data_dir}/allrounds_CHAD_hh.dta", clear
local rate 0.05 	// annual social discount rate
local perpetuity 60 // perpetuity years

** -----| 2) Retrieve Costs Data from Administrative Data

/*
Initial set up 
2 NGO: 				LOG 		BEG			
Beneficiaries		1,600		400			
Oper. Terrain (OP)	8	4		12
OP salary/month		400,000	  	400,000	
months				3			3
transfer_fee		0.069		0.069	
split CT and PM		0.5		  	0.5	
Cash grant			45,000.00 	45,000.00		
*/

** Assumptions 

local LOG_n_beneficiary 		= 1600
local LOG_n_employee_terrain 	= 8
local BEG_n_beneficiary 		= 400
local BEG_n_employee_terrain 	= 4

local n_operation_month			= 3 
local transfer_fee				= 0.069
local split_PM_CT				= 0.5
local wage_monthly 				= 400000
local cash_grant				= 45000

** Computations 

* NGO: LOG
local LOG_ngo_service	= 9908940 + 1783609
local LOG_operation		= `LOG_n_employee_terrain' * `wage_monthly' * `n_operation_month' * `split_PM_CT'
local LOG_payment_fees  = `cash_grant' * `LOG_n_beneficiary' * `transfer_fee'
local LOG_payment		= `cash_grant' * `LOG_n_beneficiary'

* NGO: BEG	
local BEG_ngo_service	= 6457450 + 1162341
local BEG_operation		= `BEG_n_employee_terrain' * `wage_monthly' * `n_operation_month' * `split_PM_CT'
local BEG_payment_fees  = `cash_grant' * `BEG_n_beneficiary' * `transfer_fee'
local BEG_payment		= `cash_grant' * `BEG_n_beneficiary'

* Total Cost per Beneficiary (in 1000 FCFA) 
local ngo_service	= ((`LOG_ngo_service' 	+ `BEG_ngo_service')  	/ (`LOG_n_beneficiary' + `BEG_n_beneficiary')) / 1000
local operation		= ((`LOG_operation' 	+ `BEG_operation')  	/ (`LOG_n_beneficiary' + `BEG_n_beneficiary')) / 1000
local payment_fees  = ((`LOG_payment_fees' 	+ `BEG_payment_fees')  	/ (`LOG_n_beneficiary' + `BEG_n_beneficiary')) / 1000
local payment		= ((`LOG_payment' 		+ `BEG_payment')  		/ (`LOG_n_beneficiary' + `BEG_n_beneficiary')) / 1000
local total_costs_0 = `ngo_service' + `operation' + `payment_fees' + `payment'
local total_costs_1 = `total_costs_0' * (1 + `rate')^1

local total_costs_07 = `total_costs_0' * (1 + 0.07)^1
local total_costs_10 = `total_costs_0' * (1 + 0.10)^1


** -----| 3) CBA Table: Daily Food Consumption per adult equiv  

** Compute Benefits per Household
local cba_var food_day_eq_xof
if "${w_lvl}" == "village" 	local weight_var weight_vil 
if "${w_lvl}" == "overall" 	local weight_var weight_ovrl
if "${w_lvl}" == "prop_g2" 	local weight_var weight_g2
		
foreach trt in PMT CTS {
	if "`trt'" == "PMT" {
		local treat_var pm_treatment
		local spillover_multiplier = 1 
	}
	if "`trt'" == "CTS" {
		local treat_var ct_spillover_dummy
		local spillover_multiplier = 2207/1798 // 2207 non ct for 1798 direct beneficiaries in population 
	}
	
	qui reg `cba_var' `treat_var' `cba_var'_bl i.strata [pw = `weight_var'], cluster(p_village)
	local b_`trt' = _b[`treat_var']	
	
	// adult equiv 
	qui sum equiv_n if `treat_var' != .
	local adulteq_`trt' `r(mean)'
	
	// global effect: b * adult_equiv * 365.25
	local effect_`trt' = `b_`trt'' * `adulteq_`trt'' * 365.25 * `spillover_multiplier' / 1000
	
	nois dis "`adulteq_`trt'' and `b_`trt'' and `effect_`trt''"
}
local effect_PMT_CTS = `effect_PMT' + `effect_CTS'


** Basic CBA 
foreach trt in PMT PMT_CTS {
	foreach sfx in 1 07 10 {
		local base_cba_`trt'_`sfx' = (`effect_`trt'' / `total_costs_`sfx'') * 100
	}
}


** -----| 4) NPV & IRR 

foreach trt in PMT PMT_CTS {
	foreach dr in 100 75 50 25 0 {
		
		local npv_`trt'_`dr' = 0 
		
		tempname cashflow_hold	
		tempfile cashflow_irr	
		postfile `cashflow_hold' year cashflow using `cashflow_irr'		
		
		forvalues t = 0/`= `perpetuity' + 1' {
			if 		`t' == 0 	local cash_flow_0 = - `total_costs_0' // investment 
			else if `t' == 1	local cash_flow_1 = `effect_`trt''
			else {
				local cash_flow_`t' = `cash_flow_`= `t' - 1'' * (1 - (`dr'/100))
				local npv_`trt'_`dr'_`t' = `cash_flow_`t'' / ((1 + `rate')^`= `t' - 1')
				local npv_`trt'_`dr' = (`npv_`trt'_`dr'' + `npv_`trt'_`dr'_`t'')				
			}
		
			post `cashflow_hold' (`t') (`cash_flow_`t'')
		}
		
		// adjust Year2 to Year1
		local npv_`trt'_`dr' = `npv_`trt'_`dr'' / (1 + `rate')  

 		// IRR
		postclose `cashflow_hold'
		use `cashflow_irr', clear

		// Export cashflow as .xlsx
		export excel "${output_balance}/cashflow_irr.xlsx", replace
		
		shell "${output_balance}/compute_irr.vbs" // vbs script computing IRR
		
		sleep 2000
		
		// Extract IRR
		import excel using "${output_balance}/cashflow_irr.xlsx", clear	
		local irr_`trt'_`dr' = C[1] * 100 
	}
}

** remove transitory file
erase "${output_balance}/cashflow_irr.xlsx"

foreach trt in PMT PMT_CTS { 
	foreach dr in 100 75 50 25 0 { 
		// Total benefits, with dissipation
		local totben_`trt'_`dr' = `npv_`trt'_`dr'' + `effect_`trt''		
		
		// CBA 
		local cba_`trt'_`dr' = (`totben_`trt'_`dr'' / `total_costs_1') * 100	
	}
	
	// Exact formula for 0 gains
	local npv_`trt'_0 = `effect_`trt'' * ((1 - (1 + `rate')^(-`perpetuity')) / `rate') / (1 + `rate')
	local totben_`trt'_0 = `npv_`trt'_0' + `effect_`trt''
		
	// CBA 
	local cba_`trt'_0 = (`totben_`trt'_0' / `total_costs_1') * 100
}


** -----| 5) Prepare latex file

** Labels

local hphantom    = "\hphantom{(99)}"
local table_name  = "cba"
local table_title = "Table 12: Cost-Benefit Analysis"

local latex_head_9	"\multicolumn{3}{l}{\textbf{Panel 1: Program costs per beneficiary, 1000 FCFA}} \\"
local latex_line_10 "\hphantom{(99) T} Coordination"
local latex_line_11 "\hphantom{(99) T} Field Operations"
local latex_line_12 "\hphantom{(99) T} Cash Grant Transfer fees"
local latex_line_13 "\hphantom{(99) T} Cash Grant"
local latex_line_14 "`hphantom' Total costs, calculated as if all incurred immediately at beginning of year 0"
local latex_line_15 "\hphantom{0}(1) Total costs, inflated to year 1 at 5\% annual discount rate"

local latex_head_16 "\hline \\ [-1.8ex] \multicolumn{3}{l}{\textbf{Panel 2: Benefits per household, 1000 FCFA, all values inflated to year 1 at 5\% annual social discount rate}} \\"
local latex_line_17 "\hphantom{0}(2) Year 1 food consumption treatment effect"
local latex_line_18 "\hphantom{0}(3) B1: Year 2 onward food consumption treatment effect, assuming dissipation of 75\%"
local latex_line_19 "`hphantom' B2: Year 2 onward food consumption treatment effect, assuming dissipation of 50\%"
local latex_line_20 "`hphantom' B3: Year 2 onward food consumption treatment effect, assuming dissipation of 25\%"
local latex_line_21 "\hphantom{0}(4) C: Year 2 onward food consumption treatment effect, assuming year 1 gains persist in perpetuity"

local latex_line_22 "\hphantom{0}(5) A: Total benefits: (2) = (5), 5\% discount rate, no impact after year 1"
local latex_line_23 "\hphantom{0}(6) B1: Total benefits: (2) + (3) = (6), 5\% discount rate, 75\% annual dissipation"
local latex_line_24 "`hphantom' B2: Total benefits, 5\% discount rate, 50\% annual dissipation"
local latex_line_25 "`hphantom' B3: Total benefits, 5\% discount rate, 25\% annual dissipation"
local latex_line_26 "\hphantom{0}(7) C: Total benefits: (2) + (4) = (7), 5\% discount rate, assuming year 1 gains persist in perpetuity"

local latex_head_27 "\hline \\ [-1.8ex] \multicolumn{3}{l}{\textbf{Panel 3: Benefit/cost ratios}} \\"
local latex_line_28 "\hphantom{0}(8) A: Benefit/cost ratio: (5) / (1) = (8), 5\% discount rate"
local latex_line_29 "`hphantom' A: Benefit/cost ratio, 7\% discount rate"
local latex_line_30 "`hphantom' A: Benefit/cost ratio, 10\% discount rate"
local latex_line_31 "\hphantom{0}(9) B1: Benefit/cost ratio: (6) / (1) = (9), 5\% discount rate, 75\% annual dissipation"
local latex_line_32 "`hphantom' B2: Benefit/cost ratio, 5\% discount rate, 50\% annual dissipation"
local latex_line_33 "`hphantom' B3: Benefit/cost ratio, 5\% discount rate, 25\% annual dissipation"
local latex_line_34 "(10) C: Benefit/cost ratio: (7) / (1) = (10), 5\% discount rate, assuming year 1 gains persist in perpetuity"

local latex_head_35 "\hline \\ [-1.8ex] \multicolumn{3}{l}{\textbf{Panel 4: Real internal rate of return (IRR)}} \\"
local latex_line_36 "`hphantom' A: Assuming dissipation of 100\% after year 2, at 5\% discount rate"
local latex_line_37 "`hphantom' B1: Assuming annual dissipation of 75\%"
local latex_line_38 "`hphantom' B2: Assuming annual dissipation of 50\%"
local latex_line_39 "`hphantom' B3: Assuming annual dissipation of 25\%"
local latex_line_40 "`hphantom' C: Assuming effects are sustained in perpetuity"

** Inputs
local nf ": di %15.0f" 			 // number format

local input_line_10 "``nf' `ngo_service''     	& ``nf' `ngo_service''"
local input_line_11 "``nf' `operation''       	& ``nf' `operation''"
local input_line_12 "``nf' `payment_fees''    	& ``nf' `payment_fees''"
local input_line_13 "``nf' `payment''         	& ``nf' `payment''"
local input_line_14 "``nf' `total_costs_0''   	& ``nf' `total_costs_0''"
local input_line_15 "``nf' `total_costs_1''   	& ``nf' `total_costs_1''"

local input_line_17 "``nf' `effect_PMT'' 	 	& ``nf' `effect_PMT_CTS''"
local input_line_18 "``nf' `npv_PMT_75'' 	 	& ``nf' `npv_PMT_CTS_75''"
local input_line_19 "``nf' `npv_PMT_50'' 	 	& ``nf' `npv_PMT_CTS_50''"
local input_line_20 "``nf' `npv_PMT_25'' 	  	& ``nf' `npv_PMT_CTS_25''"
local input_line_21 "``nf' `npv_PMT_0''  		& ``nf' `npv_PMT_CTS_0''"
local input_line_22 "``nf' `effect_PMT'' 	  	& ``nf' `effect_PMT_CTS''"
local input_line_23 "``nf' `totben_PMT_75''   	& ``nf' `totben_PMT_CTS_75''"
local input_line_24 "``nf' `totben_PMT_50''   	& ``nf' `totben_PMT_CTS_50''"
local input_line_25 "``nf' `totben_PMT_25''   	& ``nf' `totben_PMT_CTS_25''"
local input_line_26 "``nf' `totben_PMT_0''  	& ``nf' `totben_PMT_CTS_0''"

local input_line_28 "``nf' `base_cba_PMT_1''\%  & ``nf' `base_cba_PMT_CTS_1''\%"
local input_line_29 "``nf' `base_cba_PMT_07''\% & ``nf' `base_cba_PMT_CTS_07''\%"
local input_line_30 "``nf' `base_cba_PMT_10''\% & ``nf' `base_cba_PMT_CTS_10''\%"
local input_line_31 "``nf' `cba_PMT_75''\%   	& ``nf' `cba_PMT_CTS_75''\%"
local input_line_32 "``nf' `cba_PMT_50''\%      & ``nf' `cba_PMT_CTS_50''\%"
local input_line_33 "``nf' `cba_PMT_25''\%      & ``nf' `cba_PMT_CTS_25''\%"
local input_line_34 "``nf' `cba_PMT_0''\%     	& ``nf' `cba_PMT_CTS_0''\%"

local input_line_36 "``nf' `irr_PMT_100''\%     & ``nf' `irr_PMT_CTS_100''\%"
local input_line_37 "``nf' `irr_PMT_75''\%   	& ``nf' `irr_PMT_CTS_75''\%"
local input_line_38 "``nf' `irr_PMT_50''\%      & ``nf' `irr_PMT_CTS_50''\%"
local input_line_39 "``nf' `irr_PMT_25''\%      & ``nf' `irr_PMT_CTS_25''\%"
local input_line_40 "``nf' `irr_PMT_0''\%     	& ``nf' `irr_PMT_CTS_0''\%"


** -----| 6. Export latex file

preserve 

	clear
	insobs 50
	gen rnk = _n
	gen latex_text = ""
	
	
	local rr "replace latex_text ="  // line replace
	local rk "if rnk == " // line condition

	** header 
	`rr' "\begin{table}[htbp]\centering" 				 						`rk' 1
	`rr' "\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}" 							`rk' 2
	`rr' "\caption{`table_title'}" 												`rk' 3
	`rr' "\label{tab:`table_name'}" 											`rk' 4
	`rr' "\resizebox{1.01\textwidth}{!}{\begin{tabular}{l*{3}{c}}"  			`rk' 5
	`rr' "\hline\hline \\ [0.2ex]"  											`rk' 6
	`rr' "& Treatment Effect Only & Treatment and Spillover \\ [0.6ex]" 		`rk' 7
	`rr' "\hline \\ [-1.8ex]" 													`rk' 8

	** Panel 1
	`rr' "`latex_head_9' [1ex]" `rk' 9
	`rr' "`latex_line_10' & `input_line_10' \\ [0.4ex]" 						`rk' 10
	`rr' "`latex_line_11' & `input_line_11' \\ [0.4ex]" 						`rk' 11
	`rr' "`latex_line_12' & `input_line_12' \\ [0.4ex]" 						`rk' 12
	`rr' "`latex_line_13' & `input_line_13' \\ [0.4ex]" 						`rk' 13
	`rr' "`latex_line_14' & `input_line_14' \\ [0.4ex]" 						`rk' 14
	`rr' "`latex_line_15' & `input_line_15' \\ [1.5ex]" 						`rk' 15

	** Panel 2
	`rr' "`latex_head_16' [1ex]" `rk' 16
	`rr' "`latex_line_17' & `input_line_17' \\ [1ex]" 							`rk' 17
	`rr' "`latex_line_18' & `input_line_18' \\[0.4ex]" 							`rk' 18
	`rr' "`latex_line_19' & `input_line_19' \\ [0.4ex]" 						`rk' 19
	`rr' "`latex_line_20' & `input_line_20' \\ [0.4ex]" 						`rk' 20
	`rr' "`latex_line_21' & `input_line_21' \\ [2.0ex]" 						`rk' 21
	`rr' "`latex_line_22' & `input_line_22' \\ [0.4ex]" 						`rk' 22
	`rr' "`latex_line_23' & `input_line_23' \\ [0.4ex]" 		  				`rk' 23
	`rr' "`latex_line_24' & `input_line_24' \\ [0.4ex]" 		  				`rk' 24
	`rr' "`latex_line_25' & `input_line_25' \\ [0.4ex]" 		  				`rk' 25
	`rr' "`latex_line_26' & `input_line_26' \\ [1.5ex]" 						`rk' 26

	** Panel 3
	`rr' "`latex_head_27' [1ex]" `rk' 27
	`rr' "`latex_line_28' & `input_line_28' \\ [0.4ex]" 					`rk' 28
	`rr' "`latex_line_29' & `input_line_29' \\ [0.4ex]" 					`rk' 29
	`rr' "`latex_line_30' & `input_line_30' \\ [0.4ex]" 					`rk' 30
	`rr' "`latex_line_31' & `input_line_31' \\ [0.4ex]" 					`rk' 31
	`rr' "`latex_line_32' & `input_line_32' \\ [0.4ex]" 					`rk' 32
	`rr' "`latex_line_33' & `input_line_33' \\ [0.4ex]" 					`rk' 33
	`rr' "`latex_line_34' & `input_line_34' \\ [1.5ex]" 					`rk' 34

	** Panel 4 
	`rr' "`latex_head_35' [1ex]" 			 									`rk' 35
	`rr' "`latex_line_36' & `input_line_36' \\ [0.4ex]" 						`rk' 36
	`rr' "`latex_line_37' & `input_line_37' \\ [0.4ex]" 						`rk' 37
	`rr' "`latex_line_38' & `input_line_38' \\ [0.4ex]" 						`rk' 38
	`rr' "`latex_line_39' & `input_line_39' \\ [0.4ex]" 						`rk' 39
	`rr' "`latex_line_40' & `input_line_40' \\ [1.5ex]" 						`rk' 40

	** footer
	`rr' "%" 																	`rk' 41
	`rr' "\hline\hline" 														`rk' 42
	`rr' "\end{tabular}} %firsttabular" 										`rk' 43
	`rr'  " " 																	`rk' 44
	`rr'  "\vspace{3pt}" 														`rk' 45
	`rr'  " " 																	`rk' 46
	`rr' "\begin{tabular}{p{0.85\textwidth}}" 									`rk' 47
	`rr' "\footnotesize \textit{}" 												`rk' 48
	`rr' "\end{tabular}" 														`rk' 49
	`rr' "\end{table}" 															`rk' 50

	keep latex_text

	** save latex file in report_final folder
	outfile using "${output_balance}/table_`table_name'.tex", noquote wide replace

restore 
